@@ -162,7 +162,9 @@ module SiSU_AO
           : @opt.fns
           @@idx_arr[:sst]=[]
         end
-        ao=(@@idx_arr[:sst].empty?) ? read_idx_sst : @@idx_arr[:sst].dup #check
+        ao=(@@idx_arr[:sst].empty?) \
+        ? read_idx_sst
+        : @@idx_arr[:sst].dup #check
       rescue
         SiSU_Errors::Rescued.new($!,$@,@opt.cmd,@opt.fns).location do
           __LINE__.to_s + ':' + __FILE__
@@ -181,7 +183,9 @@ module SiSU_AO
           : @opt.fns
           @@idx_arr[:tex]=[]
         end
-        ao=(@@idx_arr[:tex].empty?) ? read_idx_raw : @@idx_arr[:tex].dup #check
+        ao=(@@idx_arr[:tex].empty?) \
+        ? read_idx_raw
+        : @@idx_arr[:tex].dup #check
       rescue
         SiSU_Errors::Rescued.new($!,$@,@opt.cmd,@opt.fns).location do
           __LINE__.to_s + ':' + __FILE__
@@ -200,7 +204,9 @@ module SiSU_AO
           : @opt.fns
           @@idx_arr[:html]=[]
         end
-        ao=(@@idx_arr[:html].empty?) ? read_idx_html : @@idx_arr[:html].dup
+        ao=(@@idx_arr[:html].empty?) \
+        ? read_idx_html
+        : @@idx_arr[:html].dup
       rescue
         SiSU_Errors::Rescued.new($!,$@,@opt.cmd,@opt.fns).location do
           __LINE__.to_s + ':' + __FILE__
@@ -219,7 +225,9 @@ module SiSU_AO
           : @opt.fns
           @@idx_arr[:xthml]=[]
         end
-        ao=(@@idx_arr[:xhtml].empty?) ? read_idx_xhtml : @@idx_arr[:xhtml].dup
+        ao=(@@idx_arr[:xhtml].empty?) \
+        ? read_idx_xhtml
+        : @@idx_arr[:xhtml].dup
       rescue
         SiSU_Errors::Rescued.new($!,$@,@opt.cmd,@opt.fns).location do
           __LINE__.to_s + ':' + __FILE__
@@ -238,7 +246,9 @@ module SiSU_AO
           : @opt.fns
           @@map_arr[:nametags]=[]
         end
-        ao=(@@map_arr[:nametags].empty?) ? read_map_nametags : @@map_arr[:nametags].dup
+        ao=(@@map_arr[:nametags].empty?) \
+        ? read_map_nametags
+        : @@map_arr[:nametags].dup
       rescue
         SiSU_Errors::Rescued.new($!,$@,@opt.cmd,@opt.fns).location do
           __LINE__.to_s + ':' + __FILE__
@@ -257,7 +267,9 @@ module SiSU_AO
           : @opt.fns
           @@map_arr[:ocn_htmlseg]=[]
         end
-        ao=(@@map_arr[:ocn_htmlseg].empty?) ? read_map_ocn_htmlseg : @@map_arr[:ocn_htmlseg].dup
+        ao=(@@map_arr[:ocn_htmlseg].empty?) \
+        ? read_map_ocn_htmlseg
+        : @@map_arr[:ocn_htmlseg].dup
       rescue
         SiSU_Errors::Rescued.new($!,$@,@opt.cmd,@opt.fns).location do
           __LINE__.to_s + ':' + __FILE__
@@ -273,8 +285,14 @@ module SiSU_AO
         tell=(@opt.act[:verbose][:set]==:on \
         || @opt.act[:verbose_plus][:set]==:on \
         || @opt.act[:maintenance][:set]==:on) \
-        ? SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],'Document Abstraction')
-        : SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],'Document Abstraction',"[#{@opt.f_pth[:lng_is]}] #{@opt.fno}")
+        ? SiSU_Screen::Ansi.new(
+            @opt.act[:color_state][:set],
+            'Document Abstraction'
+          )
+        : SiSU_Screen::Ansi.new(
+            @opt.act[:color_state][:set],
+            'Document Abstraction',"[#{@opt.f_pth[:lng_is]}] #{@opt.fno}"
+          )
         tell.blue_title_hi
       end
       fn=(@fnx && @fnx =~/\.ss[tmi]$/) \
@@ -293,9 +311,16 @@ module SiSU_AO
         cf=SiSU_Env::CreateFile.new(fn)
         if (@opt.act[:verbose][:set]==:on \
         || @opt.act[:verbose_plus][:set]==:on)
-          SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],@opt.fns,"~meta/#{@opt.fns}.meta").output
+            SiSU_Screen::Ansi.new(
+            @opt.act[:color_state][:set],
+            @opt.fns,
+            "~meta/#{@opt.fns}.meta"
+          ).output
         elsif @opt.act[:maintenance][:set]==:on
-          SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],"ao -> #{cf.meta}").txt_grey
+          SiSU_Screen::Ansi.new(
+            @opt.act[:color_state][:set],
+            "ao -> #{cf.meta}"
+          ).txt_grey
         end
       end
       ao.each {|s| ao_array << s}
@@ -435,7 +460,8 @@ module SiSU_AO
           if defined? o.ocn
             case o.is
             when :heading
-              filename_debug.puts "#{o.is.to_s} #{o.lv}~#{o.name} odv=#{o.odv} osp=#{o.osp} [#{o.ocn}] -->\n\t#{o.obj}"
+              filename_debug.puts
+                "#{o.is.to_s} #{o.lv}~#{o.name} odv=#{o.odv} osp=#{o.osp} [#{o.ocn}] -->\n\t#{o.obj}"
             end
           end
         end
@@ -505,17 +531,40 @@ module SiSU_AO
     end
     def song
       reset
-      data=@data
-      data=SiSU_AO_Insertions::Insertions.new(@md,data).expand_insertions?                                              # ao_expand_insertions.rb
-      data=SiSU_AO_MiscArrangeText::SI.new(@md,data).prepare_text                                                       # ao_misc_arrange.rb
-      data,metadata=SiSU_AO_DocumentStructureExtract::Build.new(@md,data).identify_parts                                # ao_doc_str.rb
-      data=SiSU_AO_Syntax::Markup.new(@md,data).songsheet                                                               # ao_syntax.rb
-      data,endnote_array=SiSU_AO_CharacterCheck::Check.new(data).character_check_and_oldstyle_endnote_array             # ao_character_check.rb
-      data=SiSU_AO_Images::Images.new(@md,data).images                                                                  # ao_images.rb
-      data,tags_map,ocn_html_seg_map=SiSU_AO_Numbering::Numbering.new(@md,data).numbering_song                          # ao_numbering.rb
-      data,book_index_rel,book_index_rel_html_seg,html_idx,xhtml_idx=SiSU_AO_BookIndex::BookIndex.new(@md,data,@env).indexing_song if @md.book_idx  # ao_idx.rb
-      data=SiSU_AO_Endnotes::Endnotes.new(@md,data,endnote_array).endnotes                                              # ao_endnotes.rb
-      outputdata=data
+      data_txt=@data
+      data_txt=
+        SiSU_AO_Insertions::Insertions.new(@md,data_txt).            # ao_expand_insertions.rb
+          expand_insertions?
+      data_txt=
+        SiSU_AO_MiscArrangeText::SI.new(@md,data_txt).               # ao_misc_arrange.rb
+          prepare_text
+      data_obj,
+        metadata=
+          SiSU_AO_DocumentStructureExtract::Build.new(@md,data_txt). # ao_doc_str.rb
+            identify_parts
+      data_obj=
+        SiSU_AO_Syntax::Markup.new(@md,data_obj).songsheet           # ao_syntax.rb
+      data_obj,
+        endnote_array=
+          SiSU_AO_CharacterCheck::Check.new(data_obj).               # ao_character_check.rb
+            character_check_and_oldstyle_endnote_array
+      data_obj=
+         SiSU_AO_Images::Images.new(@md,data_obj).images             # ao_images.rb
+      data_obj,
+        tags_map,
+        ocn_html_seg_map=
+          SiSU_AO_Numbering::Numbering.new(@md,data_obj).            # ao_numbering.rb
+            numbering_song
+      data_obj,
+        book_index_rel,
+        book_index_rel_html_seg,
+        html_idx,xhtml_idx=
+          SiSU_AO_BookIndex::BookIndex.new(@md,data_obj,@env).       # ao_idx.rb
+            indexing_song if @md.book_idx
+      data_obj=
+        SiSU_AO_Endnotes::Endnotes.new(@md,data_obj,endnote_array).  # ao_endnotes.rb
+          endnotes
+      outputdata=data_obj
       if (@md.opt.act[:ao][:set]==:on \
       || @md.opt.act[:maintenance][:set]==:on)
         SiSU_AO::Output.new(@fn,@md,outputdata).hard_output
