@@ -80,9 +80,9 @@ module SiSU_AO_CharacterCheck
             gsub(/(#{Mx[:en_a_o]})\s*\s+/,'\1 ').
             gsub(/(~\{\s*)\s+/,'\1 ').
             gsub(/ \/\//,"#{Mx[:br_line]}").
-            gsub(/<br>/,"#{Mx[:br_line]}").                              #needed by xml, xhtml etc.
+            gsub(/<br>/,"#{Mx[:br_line]}").                #needed by xml, xhtml etc.
             gsub(/\t/,' ').
-            gsub(/\342\200\231/u,"'"). #if dob =~/’/  #Avoid #&lsquo; &rsquo; #&ldquo; &rdquo;
+            gsub(/\342\200\231/u,"'"). #if dob =~/’/       #Avoid #&lsquo; &rsquo; #&ldquo; &rdquo;
             gsub(/\\copy(?:right)?\b/,'&#169;').
             gsub(/\\trademark\b|\\tm\b/,'&#174;')
           dob.obj=dob.obj + "\n"
@@ -91,8 +91,9 @@ module SiSU_AO_CharacterCheck
             when /\^~/                                     #% Note must do this first (earlier loop) and then enter gathered data into ~^\d+
               sub_dob=dob.obj.dup
               @endnote_array << sub_dob.gsub(/\n/,'').
-                gsub(/\^~\s+(.+)\s*/,%{#{Mx[:en_a_o]}#{endnote_no} \\1 #{Mx[:en_a_c]}}).
-                strip
+                gsub(/\^~\s+(.+)\s*/,
+                  %{#{Mx[:en_a_o]}#{endnote_no} \\1 #{Mx[:en_a_c]}}).
+                  strip
               endnote_no+=1
               dob=nil if dob.obj =~/\^~ .+/                #watch, removes 'binary' endnote now in endnote array for later insertion
             end
