@@ -77,33 +77,53 @@ module SiSU_AO_Insertions
       end
       file_type_names={}
       file_type_names[:gen],file_type_names[:src]=[],[]
-      file_type_names[:gen] <<= if cmd_list =~ /y/ then "~^ { document manifest }#{lnk[:manifest]}"
+      file_type_names[:gen] <<= if cmd_list =~ /y/
+        "~^ { document manifest }#{lnk[:manifest]}"
       end
-      file_type_names[:gen] <<= if cmd_list =~ /h/ then [" { html, segmented text }#{lnk[:html_toc]}"," { html, scroll, document in one }#{lnk[:html_doc]}"]
+      file_type_names[:gen] <<= if cmd_list =~ /h/
+        [
+          " { html, segmented text }#{lnk[:html_toc]}",
+          " { html, scroll, document in one }#{lnk[:html_doc]}",
+        ]
       end
-      file_type_names[:gen] <<= if cmd_list =~ /e/ then [" { epub }#{lnk[:epub]}"]
+      file_type_names[:gen] <<= if cmd_list =~ /e/
+        [" { epub }#{lnk[:epub]}"]
       end
-      file_type_names[:gen] <<= if cmd_list =~ /p/ then [" { pdf, landscape }#{lnk[:pdf_landscape]}"," { pdf, portrait }#{lnk[:pdf_portrait]}"]
+      file_type_names[:gen] <<= if cmd_list =~ /p/
+        [
+          " { pdf, landscape }#{lnk[:pdf_landscape]}",
+          " { pdf, portrait }#{lnk[:pdf_portrait]}",
+        ]
       end
-      file_type_names[:gen] <<= if cmd_list =~ /o/ then " { odf:odt, open document text }#{lnk[:odt]}"
+      file_type_names[:gen] <<= if cmd_list =~ /o/
+        " { odf:odt, open document text }#{lnk[:odt]}"
       end
-      file_type_names[:gen] <<= if cmd_list =~ /b/ then " { xhtml scroll }#{lnk[:xhtml]}"
+      file_type_names[:gen] <<= if cmd_list =~ /b/
+        " { xhtml scroll }#{lnk[:xhtml]}"
       end
-      file_type_names[:gen] <<= if cmd_list =~ /x/ then " { xml, sax }#{lnk[:xml_sax]}"
+      file_type_names[:gen] <<= if cmd_list =~ /x/
+        " { xml, sax }#{lnk[:xml_sax]}"
       end
-      file_type_names[:gen] <<= if cmd_list =~ /X/ then " { xml, dom }#{lnk[:xml_dom]}"
+      file_type_names[:gen] <<= if cmd_list =~ /X/
+        " { xml, dom }#{lnk[:xml_dom]}"
       end
-      file_type_names[:gen] <<= if cmd_list =~ /a/ then " { plain text utf-8 }#{lnk[:txt]}"
+      file_type_names[:gen] <<= if cmd_list =~ /a/
+        " { plain text utf-8 }#{lnk[:txt]}"
       end
-      file_type_names[:gen] <<= if cmd_list =~ /g/ then 'wiki.txt'
+      file_type_names[:gen] <<= if cmd_list =~ /g/
+        'wiki.txt'
       end
-      file_type_names[:gen] <<= if cmd_list =~ /w/ then " { concordance }#{lnk[:html_concordance]}"
+      file_type_names[:gen] <<= if cmd_list =~ /w/
+        " { concordance }#{lnk[:html_concordance]}"
       end
-      file_type_names[:gen] <<= if cmd_list =~ /N/ then " { dcc, document content certificate (digests) }#{lnk[:digest]}"
+      file_type_names[:gen] <<= if cmd_list =~ /N/
+        " { dcc, document content certificate (digests) }#{lnk[:digest]}"
       end
-      file_type_names[:src] <<= if source and cmd_shortcut =~ /s/ then " { markup source text }#{lnk[:source]}"
+      file_type_names[:src] <<= if source and cmd_shortcut =~ /s/
+        " { markup source text }#{lnk[:source]}"
       end
-      file_type_names[:src] <<= if cmd_shortcut =~ /S/ then " { markup source (zipped) pod }#{lnk[:sisupod]}"
+      file_type_names[:src] <<= if cmd_shortcut =~ /S/
+        " { markup source (zipped) pod }#{lnk[:sisupod]}"
       end
       file_type_names[:gen]=file_type_names[:gen].flatten
       file_type_names[:src]=file_type_names[:src].flatten
@@ -333,9 +353,9 @@ module SiSU_AO_Insertions
       tuned_file,tuned_file_tmp=[],[]
       codeblock_=false
       data.each do |para|
-        codeblock_=if para =~/^(?:code\{|[`]{3}\s+code)/
+        codeblock_=if para =~/^(?:code(?:\.[a-z][0-9a-z_]+)?\{|```[ ]+code(?:\.[a-z][0-9a-z_]+)?)/
           true
-        elsif para =~/^(?:\}code|[`]{3}(?:\s|$))/m
+        elsif para =~/^(?:\}code|```(?:\s|$))/m
           false
         else codeblock_
         end
