@@ -66,7 +66,7 @@ module SiSU_AO_Images
       require 'RMagick'
       include Magick
     rescue LoadError
-      SiSU_Utils::CodeMarker.new(__LINE__,__FILE__,:fuchsia).mark('RMagic NOT FOUND')
+      #SiSU_Utils::CodeMarker.new(__LINE__,__FILE__,:fuchsia).mark('RMagic NOT FOUND')
     end
     def initialize(md,data)
       @md,@data=md,data
@@ -83,10 +83,12 @@ module SiSU_AO_Images
           @rmgk=false
         end
       else
-        if (@md.opt.act[:verbose][:set]==:on \
-        || @md.opt.act[:verbose_plus][:set]==:on \
+        if (@md.opt.act[:verbose_plus][:set]==:on \
         || @md.opt.act[:maintenance][:set]==:on)
-          SiSU_Screen::Ansi.new(@md.opt.act[:color_state][:set],'*WARN* use of RMagick is not enabled in sisurc.yml').warn
+          SiSU_Screen::Ansi.new(
+            @md.opt.act[:color_state][:set],
+            '*WARN* use of RMagick is not enabled in sisurc.yml'
+          ).warn
         end
       end
       data.each do |dob|
@@ -100,7 +102,11 @@ module SiSU_AO_Images
                 img_col=img_row=nil
                 images=imgs.each do |image|
                   dir=SiSU_Env::InfoEnv.new(@md.fns)
-                  path_image=[dir.path.image_source_include_local,dir.path.image_source_include_remote,dir.path.image_source_include]
+                  path_image=[
+                    dir.path.image_source_include_local,
+                    dir.path.image_source_include_remote,
+                    dir.path.image_source_include
+                  ]
                   image_path=nil
                   path_image.each do |img_pth|
                     image_path=img_pth
@@ -111,10 +117,12 @@ module SiSU_AO_Images
                       img=Magick::ImageList.new("#{image_path}/#{image}")
                       img_col,img_row=img.columns,img.rows
                     else
-                      if (@md.opt.act[:verbose][:set]==:on \
-                      || @md.opt.act[:verbose_plus][:set]==:on \
+                      if (@md.opt.act[:verbose_plus][:set]==:on \
                       || @md.opt.act[:maintenance][:set]==:on)
-                        SiSU_Screen::Ansi.new(@md.opt.act[:color_state][:set],'*WARN* RMagick not present, will attempt to use imagemagick (identify) directly').warn
+                        SiSU_Screen::Ansi.new(
+                          @md.opt.act[:color_state][:set],
+                          '*WARN* RMagick not present, will attempt to use imagemagick (identify) directly'
+                        ).warn
                       end
                       imgk=SiSU_Env::SystemCall.new.imagemagick
                       gmgk=SiSU_Env::SystemCall.new.graphicksmagick
@@ -146,12 +154,18 @@ module SiSU_AO_Images
                       end
                     end
                     dob.obj=dob.obj.gsub(/(#{image})/,"#{image} #{img_col}x#{img_row}")
-                  else dob.obj=dob.obj.gsub(/#{Mx[:lnk_o]}\s*(\S+)\.(png|jpg|gif).+?#{Mx[:lnk_c]}(#{Mx[:url_o]}\S+?#{Mx[:url_c]}|image)/,'[ \1 (\2 missing) ]')
+                  else
+                    dob.obj=dob.obj.
+                      gsub(/#{Mx[:lnk_o]}\s*(\S+)\.(png|jpg|gif).+?#{Mx[:lnk_c]}(#{Mx[:url_o]}\S+?#{Mx[:url_c]}|image)/,
+                        '[ \1 (\2 missing) ]')
                   end
                 end
               else
                 images=dob.obj.scan(m) do |image|
-                  SiSU_Screen::Ansi.new(@md.opt.act[:color_state][:set],'*WARN* where image dimensions have not been provided RMagick or imagemagick is required',image).warn unless @md.opt.act[:quiet][:set]==:on
+                  SiSU_Screen::Ansi.new(
+                    @md.opt.act[:color_state][:set],
+                    '*WARN* where image dimensions have not been provided RMagick or imagemagick is required',image
+                  ).warn unless @md.opt.act[:quiet][:set]==:on
                 end
               end
             end
