@@ -69,11 +69,20 @@ module SiSU_AO_Metadata
       @tr=SiSU_Translate::Source.new(md,language)
     end
     def make_para(obj,ocn)
-      h={ obj: obj, ocn: 0 }
+      h={
+        obj: obj,
+        ocn: 0
+      }
       SiSU_AO_DocumentStructure::ObjectPara.new.paragraph(h)
     end
     def make_heading(obj,ocn,name,lv,ln)
-      h={ lv: lv, ln: ln, name: name, obj: obj, ocn: 0 }
+      h={
+        lv: lv,
+        ln: ln,
+        name: name,
+        obj: obj,
+        ocn: 0
+      }
       SiSU_AO_DocumentStructure::ObjectHeading.new.heading(h)
     end
     def metadata
