@@ -66,33 +66,43 @@ module SiSU_AO_MiscArrangeText
       @md,@data=md,data
     end
     def conditional_headings(para)
-      para=para.gsub(/^(:?A~)\s*$/,'\1~ @title @author').                                    #conditional header
-        gsub(/^((?:[1-9]|:?[A-D])~\S*)\s*$/,'\1~ [Note: heading marker::required title missing]~#')    #conditional header for incorporated document 2004w12
+      para=para.gsub(/^(:?A~)\s*$/,'\1~ @title @author').            #conditional header
+        gsub(/^((?:[1-9]|:?[A-D])~\S*)\s*$/,
+          '\1~ [Note: heading marker::required title missing]~#')    #conditional header for incorporated document 2004w12
       if para =~/^@\S+?:/
-        para=para.gsub(/^@(\S+?):(\s+|$)/,"#{Mx[:meta_o]}\\1#{Mx[:meta_c]}\\2").
-          gsub(/^@(\S+?):([+-])(\s+|$)/,"#{Mx[:meta_o]}\\1\\2#{Mx[:meta_c]}\\3")
+        para=para.gsub(/^@(\S+?):(\s+|$)/,
+            "#{Mx[:meta_o]}\\1#{Mx[:meta_c]}\\2").
+          gsub(/^@(\S+?):([+-])(\s+|$)/,
+            "#{Mx[:meta_o]}\\1\\2#{Mx[:meta_c]}\\3")
       end
       para
     end
-    def code_blocks(para)
+    def markup_blocks(para)
       def ticks(para)
         block_open,block_close,text=nil,nil,nil
-        if para =~/\A[`]{3}\s+.+?\n.+?\n[`]{3}(?:\s+[~-][#]|\s+\~\{.+?\}\~)?\s*\Z/m
-          block_open,text,block_close=/\A([`]{3}\s+.+?)\n(.+?)\n([`]{3}(\s+[~-][#]|\s+\~\{.+?\}\~)?)\s*\Z/m.match(para)[1..3]
-          ((para=~/^[`]{3}\s+table(?:~h)?\s+/) \
-          and (para !~/^[`]{3}\s+table(?:~h)?\s+c\d+/)) \
+        if para =~/\A```[ ]+(?:code(?:\.[a-z][0-9a-z_]+)?|box(?:\.[a-z_]+)?|poem|alt|group|block|table).*?\n.+?\n```(?:\s+[~-][#]|\s+\~\{.+?\}\~)?\s*\Z/m
+          @flag=:close
+          block_open,text,block_close=
+            /\A(```[ ]+(?:code(?:\.[a-z][0-9a-z_]+)?|box(?:\.[a-z_]+)?|poem|alt|group|block|table).*?)\n(.+?)\n(```([ ]+[~-][#]|\s+\~\{.+?\}\~)?)\s*\Z/m.
+            match(para)[1..3]
+          ((para=~/^```[ ]+table(?:~h)?\s+/) \
+          and (para !~/^```[ ]+table(?:~h)?\s+c\d+/)) \
           ? para
           : (para=[]; para << block_open << text << block_close)
-        elsif para =~/\A[`]{3}\s+.+?\n.*?\Z/m #look at, study
-          block_open,text=/\A([`]{3}(?:\s+.+?))\n(.*?)\Z/m.match(para)[1,2]
+        elsif para =~/\A```[ ]+(?:code(?:\.[a-z][0-9a-z_]+)?|box(?:\.[a-z_]+)?|poem|alt|group|block|table).*?\n.*?\Z/m #look at, study
+          @flag=:open
+          block_open,text=/\A(```(?:[ ]+.+?))\n(.*?)\Z/m.match(para)[1,2]
           para=[]
           if not text.to_s.empty?
             para << block_open << text
           else
             para << block_open
           end
-        elsif para =~/\A.+?\n[`]{3}(?:\s+[~-][#]|\s+\~\{.+?\}\~)?\s*\Z/m
-          text,block_close=/\A(.+?)\n([`]{3}(?:\s+[~-][#]|\s+\~\{.+?\}\~)?)\s*\Z/m.match(para)[1,2]
+        elsif para =~/\A.+?\n```(?:\s+[~-][#]|\s+\~\{.+?\}\~)?\s*\Z/m \
+        and @flag==:open
+          @flag=:close
+          text,block_close=
+            /\A(.+?)\n(```(?:\s+[~-][#]|\s+\~\{.+?\}\~)?)\s*\Z/m.match(para)[1,2]
           para=[]
           if not text.to_s.empty?
             para << text.to_s << block_close
@@ -103,22 +113,58 @@ module SiSU_AO_MiscArrangeText
         end
         para
       end
+      def ticks_remove(para)
+        unless @md.opt.act[:quiet][:set] ==:on
+          SiSU_Utils::CodeMarker.new(__LINE__,__FILE__,:fuchsia).
+           mark("ticks not recognized, ticks removed from pargraph\n#{para}")
+        end
+        para=para.gsub(/```[ ]+\S+[ ]*/m,'').
+          gsub(/```\s*/m,'').
+          strip
+      end
+      def ticks_quote(para)
+        @flag=:quote_open
+        text=para
+        para=[]
+        if text =~ /```[ ]+quote/m
+          para << '`:quote_open`'
+          text=text.gsub(/```[ ]+quote/m,'')
+        end
+        text=if text =~/(?:\n|\A)=\{.+?\}/m                               #exclude book index from indent markup
+          txt,bkidx,tail=/(.+?)((?:\n|\A)=\{.+?\}$)(.*)/m.match(text).captures
+          txt=txt.gsub(/(?:\n|\A)([^`\n]+)/m,'_1 \1')
+          txt + bkidx + tail
+        else text.gsub(/(?:\n|\A)([^`\n]+)/m,'_1 \1')
+        end
+        para << text.gsub(/```/m,'')
+        if text =~/```/m
+          @flag=:quote_close
+          para << '`:quote_close`'
+        end
+        para
+      end
       def curly_braces(para)
         block_open,block_close,text=nil,nil,nil
-        para=if para =~/\A(?:code|poem|alt|group|block|table)\{ .+?\n.+?\n\}(?:code|poem|alt|group|block|table)(?: [~-][#])?\s*\Z/m
-          block_open,text,block_close=/\A((?:code|poem|alt|group|block|table)\{ .+?)\n(.+?)\n(\}(?:code|poem|alt|group|block|table)(?: [~-][#])?)\s*\Z/m.match(para)[1..3]
+        para=if para =~/\A(?:code(?:\.[a-z][0-9a-z_]+)?|box(?:\.[a-z_]+)?|poem|alt|group|block|table)\{ .+?\n.+?\n\}(?:code|box|poem|alt|group|block|table)(?: [~-][#])?\s*\Z/m
+          block_open,text,block_close=
+            /\A((?:code(?:\.[a-z][0-9a-z_]+)?|box(?:\.[a-z_]+)?|poem|alt|group|block|table)\{ .+?)\n(.+?)\n(\}(?:code|box|poem|alt|group|block|table)(?: [~-][#])?)\s*\Z/m.
+            match(para)[1..3]
           para=[]
           para << block_open << text << block_close
-        elsif para =~/\A(?:code|poem|alt|group|block|table)\{ .+?\n.+?\Z/m
-          block_open,text=/\A((?:code|poem|alt|group|block|table)\{ .+?)\n(.+?)\Z/m.match(para)[1,2]
+        elsif para =~/\A(?:code(?:\.[a-z][0-9a-z_]+)?|box(?:\.[a-z_]+)?|poem|alt|group|block|table)\{ .+?\n.+?\Z/m
+          block_open,text=
+            /\A((?:code(?:\.[a-z][0-9a-z_]+)?|box(?:\.[a-z_]+)?|poem|alt|group|block|table)\{ .+?)\n(.+?)\Z/m.
+            match(para)[1,2]
           para=[]
           if not text.to_s.empty?
             para << block_open << text
           else
             para << block_open
           end
-        elsif para =~/\A.+?\n\}(?:code|poem|alt|group|block|table)(?: [~-][#])?\s*\Z/m
-          text,block_close=/\A(.+?)\n(\}(?:code|poem|alt|group|block|table)(?: [~-][#])?)\s*\Z/m.match(para)[1,2]
+        elsif para =~/\A.+?\n\}(?:code|box|poem|alt|group|block|table)(?: [~-][#])?\s*\Z/m
+          text,block_close=
+            /\A(.+?)\n(\}(?:code|box|poem|alt|group|block|table)(?: [~-][#])?)\s*\Z/m.
+            match(para)[1,2]
           para=[]
           if not text.to_s.empty?
             para << text.to_s << block_close
@@ -129,12 +175,23 @@ module SiSU_AO_MiscArrangeText
         end
         para
       end
-      para=para =~/^```/m \
-      ? ticks(para)
-      : para
-      para=(para =~/^(?:code|poem|alt|group|block|table)\{|^\}(?:code|poem|alt|group|block|table)/m) \
-      ? curly_braces(para)
-      : para
+      para=if (para =~/\A```[ ]+quote/m \
+      and @flag !=:open) \
+      or @flag==:quote_open
+        ticks_quote(para)
+      elsif para =~/\A```[ ]+(?:code(?:\.[a-z][0-9a-z_]+)?|box(?:\.[a-z_]+)?|poem|alt|group|block|table).*?\n.*?\Z/m \
+      or @flag==:open
+        ticks(para)
+      elsif para =~/```/m
+        ticks_remove(para)
+      else
+        para
+      end
+      para=if para =~/^(?:code(?:\.[a-z][0-9a-z_]+)?|box(?:\.[a-z_]+)?|poem|alt|group|block|table)\{|^\}(?:code|box|poem|alt|group|block|table)/m
+        curly_braces(para)
+      else
+        para
+      end
     end
     def prepare_text
       data=@data
@@ -149,7 +206,7 @@ module SiSU_AO_MiscArrangeText
       end
       data.each do |para|
         para=conditional_headings(para)
-        data_new << code_blocks(para)
+        data_new << markup_blocks(para)
       end
       data_new=data_new.flatten
     end
