@@ -63,20 +63,38 @@
 module SiSU_AO_Numbering
   class Numbering
     attr_accessor :obj,:osp,:ocn,:lv,:name,:index,:comment
+    @@segments_count=0
     def initialize(md,data)
       @md,@data=md,data
       @obj=@type=@ocn=@lv=@name=@index=@comment=nil
+      @chosen_seg_names=[]
+    end
+    def number_of_segments?
+      if @@segments_count==0
+        @data.each do |dob|
+          if dob.is ==  :heading \
+          and dob.lv == '1'
+            @@segments_count += 1
+          end
+        end
+        @@segments_count
+      else @@segments_count
+      end
     end
     def numbering_song
-      data=@data
-      data=number_plaintext_para(data)
-      data=auto_number_heading_ie_title(data.compact) #tr issue
-      data=ocn(data.compact) #watch
-      data=xml(data.compact)
-      data=minor_numbering(data.compact)
-      data,tags_map,ocn_html_seg_map=name_para_seg_filename(data)
-      data=set_heading_top(data) unless @md.set_heading_top
-      [data,tags_map,ocn_html_seg_map]
+      begin
+        data=@data
+        data=number_plaintext_para(data)
+        data=auto_number_heading_ie_title(data.compact) #tr issue
+        data=ocn(data.compact) #watch
+        data=xml(data.compact)
+        data=minor_numbering(data.compact)
+        data,tags_map,ocn_html_seg_map=name_para_seg_filename(data)
+        data=set_heading_top(data) unless @md.set_heading_top
+        [data,tags_map,ocn_html_seg_map]
+      ensure
+        @@segments_count=0
+      end
     end
     def set_tags(tags,tag)
       tags=if not tag.empty? \
@@ -121,7 +139,8 @@ module SiSU_AO_Numbering
       dob
     end
     def heading_tag_clean(heading_tag)
-      heading_tag=heading_tag.gsub(/[ ]+/,'_').
+      heading_tag=heading_tag.
+        gsub(/[ ]+/,'_').
         gsub(/["']/,'').
         gsub(/[\/]/,'-').
         gsub(/#{Mx[:fa_bold_o]}|#{Mx[:fa_bold_c]}/,'').
@@ -151,7 +170,6 @@ module SiSU_AO_Numbering
       data=data.compact
       data.each do |dob| #@md.seg_names << [additions to segment names]
         title_no=nil
-        dob=SiSU_AO_DocumentStructureExtract::Structure.new(@md,dob).structure_markup #must happen earlier, node info etc. require
         if dob.is ==:heading \
         && dob.autonum_ \
         and defined? @md.make.num_top \
@@ -167,7 +185,7 @@ module SiSU_AO_Numbering
             @subnumber=0 if dob.ln==no1
           end
           if dob.ln.to_s =~/^[0-6]/ \
-          and not dob.toc_ \
+          and not dob.use_ ==:dummy \
           and dob.obj !~/#{Mx[:fa_o]}(?:~#|-#)#{Mx[:fa_c]}/ # <-- fix
             if dob.ln==no1
               t_no1+=1; t_no2=0; t_no3=0
@@ -177,7 +195,10 @@ module SiSU_AO_Numbering
                 if dob.ln==no1
                   dob.name="#{title_no}" if not dob.name
                   dob.tags=set_tags(dob.tags,title_no)
-                  tag=dob.obj.gsub(/(Article|Clause|Section|Chapter)\s+/,"\\1_#{title_no}").downcase
+                  tag=dob.obj.
+                    gsub(/(Article|Clause|Section|Chapter)\s+/,
+                      "\\1_#{title_no}").
+                    downcase
                   tag=heading_tag_clean(tag)
                   dob.tags=set_tags(dob.tags,tag)
                   dob.obj=(dob.obj =~/(Article|Clause|Section)\s+/) \
@@ -279,6 +300,64 @@ module SiSU_AO_Numbering
       end
       @tuned_file=@tuned_file.flatten
     end
+    def leading_zeros_fixed_width_number(possible_seg_name)
+      if possible_seg_name.to_s =~/^([0-9]+?\.|[0-9]+)$/m       #!~/[.,:-]+/
+        possible_seg_name=possible_seg_name.to_s.
+          gsub(/\.$/,'')
+        nl=possible_seg_name.to_s.length
+        zero='0'
+        zeros_fixed_width=number_of_segments?.to_s.length
+        zero_width=(zeros_fixed_width - nl)
+        zero_width == 0 \
+        ? possible_seg_name.to_s
+        : zero*zero_width +
+          possible_seg_name.to_s
+      end
+    end
+    def auto_seg_name(possible_seg_name,heading_num_is,lv,type)
+      prefix=case type
+      when :auto    then Mx[:segname_prefix_auto_num_provide]
+      when :extract then Mx[:segname_prefix_auto_num_extract]
+      else               '_'*lv.to_i #should not occur
+      end
+      if possible_seg_name =~/^[0-9]+?\.$/m                #!~/[.,:-]+/
+        possible_seg_name=possible_seg_name.
+          gsub(/\.$/,'')
+      end
+      chosen_seg_name=if possible_seg_name.to_s =~/^[0-9]+[.]?$/m \
+      and possible_seg_name.to_i <= heading_num_is.to_i \
+      and lv == '1'
+        prefix + leading_zeros_fixed_width_number(possible_seg_name)
+      elsif possible_seg_name.to_s =~/^[0-9]+[.,:-]*$/m \
+      and lv == '1'
+        possible_seg_name=possible_seg_name.to_s.
+          gsub(/(?:[:,-]|\W)/,'.').
+          gsub(/\.$/,'')
+        prefix + possible_seg_name
+      elsif possible_seg_name.to_s =~
+      /^[0-9]+[.,:-][0-9]+[.,:-]*$/m \
+      and lv == '2'
+        possible_seg_name=possible_seg_name.to_s.
+          gsub(/(?:[:,-]|\W)/,'.').
+          gsub(/\.$/,'')
+        prefix + possible_seg_name
+      elsif possible_seg_name.to_s =~
+      /^[0-9]+[.,:-][0-9]+[.,:-][0-9][\d.,:-]*$/m \
+      and lv == '3'
+        possible_seg_name=possible_seg_name.to_s.
+          gsub(/(?:[:,-]|\W)/,'.').
+          gsub(/\.$/,'')
+        prefix + possible_seg_name
+      else Mx[:segname_prefix_auto_num_other]*lv.to_i + possible_seg_name.to_s
+      end
+      @chosen_seg_names << chosen_seg_name
+      if @chosen_seg_names.compact.uniq.length == @chosen_seg_names.compact.length #checks that all auto given seg names are unique
+        chosen_seg_name
+      else
+        SiSU_Utils::CodeMarker.new(__LINE__,__FILE__,:green).mark("duplicated auto segment name: #{type} #{chosen_seg_name} - #{@chosen_seg_names}; manually name level 1 segments '1~given_name'")
+        exit
+      end
+    end
     def name_para_seg_filename(data)                                                   #segment naming, remaining
       # paragraph name/numbering rules
       # manual naming overrides, manual naming may be
@@ -286,7 +365,7 @@ module SiSU_AO_Numbering
       #   numeric only (a number), if
       #     all segments have been named,
       #     the numbers used are over 1000 or
-      #     it is  not minded that auto-numbering uses a funny scheme for naming segments (not yet implemented)
+      #     it is not minded that auto-numbering uses a funny scheme for naming segments (not yet implemented)
       #       [for now a warning is printed for such documents on use of maintenance or very-verbose flag]
       # auto-naming takes the form of giving numbers to segments
       # the rules for which are as follows
@@ -307,15 +386,19 @@ module SiSU_AO_Numbering
         if dob.is==:heading \
         && dob.ln \
         and dob.ln.to_s =~/^[456]/
+          heading_num_is=/^\d+:(\d+);\d/m.match(dob.node)[1]
           if dob.ln==4 \
           and not dob.name \
           and not @md.set_heading_seg
             @md.set_heading_seg=true
           end
           if dob.name !~/^\S+/ \
-          and dob.obj =~/^\s*(?:\S+\s+)?([\d.,:-]+)/m      #heading starts with a recognised numeric or word followed by a recognised numerical construct, use that as name
+          and dob.obj =~/^\s*(?:\S+\s+)?([0-9][0-9.,:-]*)/m      #heading starts with a recognised numeric or word followed by a recognised numeric construct, use that as name
             possible_seg_name=$1
-            possible_seg_name=possible_seg_name.gsub(/(?:[:,-]|\W)/,'.').
+            possible_seg_name=
+              auto_seg_name(possible_seg_name,heading_num_is,dob.lv,:extract)
+            possible_seg_name=possible_seg_name.
+              gsub(/(?:[:,-]|\W)/,'.').
               gsub(/\.$/,'')
             if @md.seg_names.is_a?(Array) \
             and not @md.seg_names.include?(possible_seg_name)
@@ -337,13 +420,13 @@ module SiSU_AO_Numbering
           end
           if dob.ln==4 \
           and not dob.name                                 #if still no segment name, provide a numerical one
-            pf='_'                                         #pg='' #may use e.g. '' or '~' or '_'
-            segn_auto="#{pf}#{art_filename_auto.to_s}"
+            possible_seg_name=
+              auto_seg_name(art_filename_auto,heading_num_is,dob.lv,:auto)
             if @md.seg_names.is_a?(Array) \
-            and not @md.seg_names.include?(segn_auto)
-             dob.name=segn_auto
+            and not @md.seg_names.include?(possible_seg_name)
+             dob.name=possible_seg_name
              dob.tags=set_tags(dob.tags,dob.name)
-              @md.seg_names << segn_auto
+              @md.seg_names << possible_seg_name
             else puts 'segment name (numbering) error'
             end
             art_filename_auto+=1
@@ -363,11 +446,17 @@ module SiSU_AO_Numbering
           m=dob.ln.to_s
           dob_tmp=[]
           if @md.pagenew.inspect =~/#{m}/
-            dob_tmp << SiSU_AO_DocumentStructure::ObjectLayout.new.break(Hx[:br_page_new]) << dob
+            dob_tmp <<
+              SiSU_AO_DocumentStructure::ObjectLayout.new.break(Hx[:br_page_new]) <<
+              dob
           elsif @md.pagebreak.inspect =~/#{m}/
-            dob_tmp << SiSU_AO_DocumentStructure::ObjectLayout.new.break(Hx[:br_page]) << dob
+            dob_tmp <<
+              SiSU_AO_DocumentStructure::ObjectLayout.new.break(Hx[:br_page]) <<
+              dob
           elsif @md.pageline.inspect =~/#{m}/
-            dob_tmp << SiSU_AO_DocumentStructure::ObjectLayout.new.break(Hx[:br_page_line]) << dob
+            dob_tmp <<
+              SiSU_AO_DocumentStructure::ObjectLayout.new.break(Hx[:br_page_line]) <<
+              dob
           end
           unless dob_tmp.length > 0; dob
           else                       dob_tmp
@@ -382,12 +471,22 @@ module SiSU_AO_Numbering
           tags["#{dob.ocn}"]={ segname: @segname }
           ocn_html_seg[dob.ocn]=if (dob.is==:heading || dob.is==:heading_insert)
             if dob.ln =~/[0-3]/
-              { seg: nil, level: dob.ln }
-            else #elsif dob.ln =~/[4-6]/
-              { seg: @seg, level: dob.ln }
+              {
+                seg: nil,
+                level: dob.ln,
+              }
+            #elsif dob.ln =~/[4-6]/
+            else
+              {
+                seg: @seg,
+                level: dob.ln,
+              }
             end
           else
-            { seg: @seg, level: nil }
+            {
+              seg: @seg,
+              level: nil,
+            }
           end
         end
         dob.tags=dob.tags.uniq if defined? dob.tags
@@ -406,7 +505,8 @@ module SiSU_AO_Numbering
         if ocn \
         and ocn[:level].to_s=~/[1-3]/
           (1..4).each do |x|
-            if ocn_html_seg[i+x] and ocn_html_seg[i+x][:level]==4
+            if ocn_html_seg[i+x] \
+            and ocn_html_seg[i+x][:level]==4
               ocn[:seg]=ocn_html_seg[i+x][:seg]
             end
           end
@@ -435,7 +535,9 @@ module SiSU_AO_Numbering
               and defined? @md.title.full \
               and defined? @md.creator \
               and @md.creator
-                head=@md.title.main ? ([@lv='1',@obj=@md.title.main]) : ([@lv='1',@obj='[no title provided]'])
+                head=@md.title.main \
+                ? ([@lv='1',@obj=@md.title.main])
+                : ([@lv='1',@obj='[no title provided]'])
                 @tuned_file << head
               end
             end
@@ -480,7 +582,8 @@ module SiSU_AO_Numbering
           unless @md.set_header_title
             if t_o !~/^%{1,2}\s/m \
             and t_o !~/\A\s*\Z/m
-              @tuned_file << "#{Mx[:meta_o]}title#{Mx[:meta_c]} #{@md.heading_seg_first}"
+              @tuned_file <<
+                "#{Mx[:meta_o]}title#{Mx[:meta_c]} #{@md.heading_seg_first}"
               @md.title.main=@md.heading_seg_first
               @md.set_header_title=true
             end
