@@ -82,24 +82,23 @@ module  SiSU_CGI_PgSQL
         opt.lingual.to_s
       else 'multi'
       end
-      if defined? @rc['search'] \
+      @name_of[:db]=if defined? @rc['search'] \
       and defined? @rc['search']['sisu'] \
       and defined? @rc['search']['sisu']['action'] \
       and @rc['search']['sisu']['action'] =~/https?:\/\/\S+?\.cgi/ \
       and defined? @rc['search']['sisu']['db'] \
       and @rc['search']['sisu']['db'] =~/\S+/
-        @name_of[:db]=@rc['search']['sisu']['db']
+        @rc['search']['sisu']['db']
       else
-        @name_of[:db]=@env.path.stub_pwd #'sisu' #breaks if not present
-        false
+        @env.path.base_markup_dir_stub #'sisu' #breaks if not present
       end
-      @name_of[:host_url_cgi]="#{@env.url.webserv_base_cgi(opt)}/cgi-bin"
-      @name_of[:host_url_docs]=@env.url.webserv_files_from_db(opt)
-      @name_of[:cgi_script]=@env.url.cgi_sample_search_form_name(opt)
+      @name_of[:host_url_cgi]=%q{http://#{ENV['HTTP_HOST']}#{ENV['PATH_INFO']}}
+      @name_of[:host_url_docs]=%q{http://#{ENV['HTTP_HOST']}}
+      @name_of[:cgi_script]=%q{#{ENV['SCRIPT_NAME']}}
       @name_of[:user]=@db.psql.user(opt)
-      @cgi_file_name=@name_of[:cgi_script]
-      @image_src="#{@env.url.webserv_base_cgi(opt)}/_sisu/image_sys"
+      @image_src=%q{http://#{ENV['HTTP_HOST']}/_sisu/image_sys}
       @common=SiSU_CGI_SQL::CGI_Common.new(@webserv,opt,@image_src,@env)
+      @cgi_file_name=@env.url.cgi_sample_search_form_name(opt)
     end
     def pgsql
       serve=[]
@@ -128,13 +127,6 @@ module  SiSU_CGI_PgSQL
             default database name:     #{@cX.green}#{Db[:name_prefix]}#{@name_of[:db]}#{@cX.off} (#{@name_of[:db]})
             db user:                   #{@cX.green}#{@name_of[:user]}#{@cX.off}
               to modify use:           #{@cX.brown}sisu --db-pg --db-user='#{@name_of[:user]}'#{@cX.off}
-            cgi & db host on:          #{@cX.blue}#{@name_of[:host_url_cgi]}#{@cX.off}
-              to modify use:           #{@cX.brown}sisu --db-pg --webserv-search='#{@name_of[:host_url_cgi]}'#{@cX.off}
-            sisu output on:            #{@cX.blue}#{@name_of[:host_url_docs]}#{@cX.off}
-              to modify use:           #{@cX.brown}sisu --db-pg --webserv-output='#{@name_of[:host_url_docs]}'#{@cX.off}
-            cgi search form link name: #{@cX.green}#{@name_of[:cgi_script]}#{@cX.off}
-              to modify use:           #{@cX.brown}sisu --db-pg --cgi-search-form-name='#{@name_of[:cgi_script]}'#{@cX.off}
-            #{@cX.fuchsia}(settings priority: command line; sisurc.yml; else defaults)#{@cX.off}
 
             #{@cX.fuchsia}BASED ON ALREADY EXISTING databases#{@cX.off} (default database name: #{@db.psql.db})
             NOTE it is first necessary to createdb,
@@ -151,12 +143,12 @@ module  SiSU_CGI_PgSQL
                 #{@cX.brown}createdb #{@db.psql.db}#{@cX.off}
             [for a list of existing databases try 'psql --list']"
 
-            now you can use sisu to create the database tables and populate the database with documents
+            you can use sisu to create the database tables and populate the database with documents
 
             sisu --pg --dropall                              # removes existing postgresql db & tables
             sisu --pg --createall -v                         # creates postgresql db & tables
             sisu --pg --update -v *.sst  *.ssm               # populate the db
-            sisu --sample-search-form --pg                   # creates the postgresql search form
+            sisu --sample-search-form --db-pg                # creates the postgresql search form
                                                              # this should be done after creating the db
                                                              # to be searched
             sisu --webrick &                                 # starts ruby webrick web server
@@ -195,20 +187,20 @@ module  SiSU_CGI_PgSQL
       begin
         require 'cgi'
         require 'fcgi'
-        require 'dbi'
+        require 'pg'
       rescue LoadError
-        puts 'cgi, fcgi or dbi NOT FOUND (LoadError)'
+        puts 'cgi, fcgi or pg NOT FOUND (LoadError)'
       end
       @stub_default='#{@name_of[:db]}'
-      @image_src='#{@image_src}'
-      @hosturl_cgi='#{@name_of[:host_url_cgi]}'
-      @hosturl_files='#{@name_of[:host_url_docs]}'
+      @image_src="#{@image_src}"
+      @hosturl_cgi="#{@name_of[:host_url_cgi]}"
+      @hosturl_files="#{@name_of[:host_url_docs]}"
       @output_dir_structure_by='#{@name_of[:output_dir_structure]}'
       @lingual='#{@name_of[:lingual]}'
       @port='#{@db.psql.port}'
       @db_name_prefix='#{Db[:name_prefix]}'
       @user='#{@name_of[:user]}'  # check user name for access to pg database: e.g. www-data or '#{@env.user}'
-      @base='#{@name_of[:host_url_cgi]}/#{@name_of[:cgi_script]}'
+      @base="#{@name_of[:host_url_cgi]}#{@name_of[:cgi_script]}"
       WOK_SQL
     end
     def search_statement
@@ -277,10 +269,10 @@ module  SiSU_CGI_PgSQL
           %{<font color="#666666" size="2">#{sql_select_endnotes}</font>}
         end
         def contents
-          @conn.select_all(sql_select_body)
+          @conn.exec(sql_select_body)
         end
         def endnotes
-          @conn.select_all(sql_select_endnotes)
+          @conn.exec(sql_select_endnotes)
         end
       end
       WOK_SQL
@@ -292,8 +284,7 @@ module  SiSU_CGI_PgSQL
     end
     def dbi_connect
       <<-'WOK_SQL'
-          dbi="dbi:Pg:database=#{@db};port=#{@port}"
-          @conn=DBI.connect(dbi,@user)
+          @conn=PG::Connection.open(dbname: @db, port: @port, user: @user)
       WOK_SQL
     end
   end
