@@ -104,6 +104,8 @@ module SiSU_Style
           css_path.xml_sax
         when 'xml_dom'
           css_path.xml_dom
+        when 'xml_docbook'
+          css_path.xml_docbook
         else
           css_embed_content.html
         end
@@ -150,6 +152,11 @@ module SiSU_Style
           style << css.xml_dom
           style.close
           css_path.xml_dom
+        when 'xml_docbook'
+          style=File.new("#{css_pth}/#{@fn_css.xml_docbook}",'w')
+          style << css.xml_docbook
+          style.close
+          css_path.xml_docbook
         end
       end
     end
@@ -1248,7 +1255,7 @@ WOK
   }
 
   li {
-    background: url(../image/bullet_09.png) no-repeat 0px 6px;
+    background: url(../image_sys/bullet_09.png) no-repeat 0px 6px;
   }
 
   ul {
@@ -1273,7 +1280,7 @@ WOK
     text-align: left;
   }
   li.doc {
-    background: url(../image/bullet_09.png) no-repeat 0px 6px;
+    background: url(../image_sys/bullet_09.png) no-repeat 0px 6px;
     padding-left: 16px;
     margin-left: 10px;
     margin-right: 0px;
@@ -1285,7 +1292,7 @@ WOK
     color: #777777;
   }
   li.refcenter {
-    background: url(../image/bullet_09.png) no-repeat 0px 6px;
+    background: url(../image_sys/bullet_09.png) no-repeat 0px 6px;
     padding-left: 20px;
     margin-left: 10%;
     font-size: 9px;
@@ -3122,7 +3129,7 @@ WOK
     br { display: block; }
 WOK
     end
-    def docbook_xml                               #stylesheet for docbook
+    def xml_docbook                               #stylesheet for docbook
 <<WOK
 /* SiSU css docbook.xml default style */
     book {
