@@ -69,10 +69,11 @@ module SiSU_DbImport
   class Import < SiSU_DbText::Prepare
     include SiSU_Param
     include SiSU_Screen
+    include SiSU_DbAction
     @@dl=nil
     @@hname=nil
     attr_accessor :tp
-    def initialize(opt,conn,file_maint,sql_type='pg')
+    def initialize(opt,conn,file_maint,sql_type=:pg)
       @opt,@conn,@file_maint,@sql_type=opt,conn,file_maint,sql_type
       @cX=SiSU_Screen::Ansi.new(@opt.act[:color_state][:set]).cX
       @env=SiSU_Env::InfoEnv.new(@opt.fns)
@@ -90,8 +91,10 @@ module SiSU_DbImport
       @col[:ocn]=''
       @counter={}
       @db=SiSU_Env::InfoDb.new
-      if @sql_type=='sqlite'
-        @driver_sqlite3=(@conn.inspect.match(/^(.{10})/)[1]==@db.sqlite.conn_sqlite3.inspect.match(/^(.{10})/)[1]) \
+      if @sql_type==:sqlite
+        @driver_sqlite3=
+        (@conn.inspect.match(/^(.{10})/)[1] \
+        == @db.sqlite.conn_sqlite3.inspect.match(/^(.{10})/)[1]) \
         ? true
         : false
       end
@@ -100,7 +103,7 @@ module SiSU_DbImport
         @col[:lid] ||=0
         @col[:lid]=@driver_sqlite3 \
         ? @conn.execute( sql ).join.to_i
-        : @conn.execute( sql ) { |x| x.fetch_all.flatten[0] }
+        : @conn.exec( sql ).getvalue(0,0).to_i
       rescue
         puts "#{__FILE__}:#{__LINE__}" if @opt.act[:maintenance][:set]==:on
       end
@@ -109,7 +112,7 @@ module SiSU_DbImport
       begin
         @id_n=@driver_sqlite3 \
         ? @conn.execute( sql ).join.to_i
-        : @id_n=@conn.execute( sql ) { |x| x.fetch_all.flatten[0] }
+        : @conn.exec( sql ).getvalue(0,0).to_i
         @id_n ||=0
       rescue
         puts "#{__FILE__}:#{__LINE__}" if @opt.act[:maintenance][:set]==:on
@@ -126,19 +129,76 @@ module SiSU_DbImport
       if (@opt.act[:verbose][:set]==:on \
       || @opt.act[:verbose_plus][:set]==:on \
       || @opt.act[:maintenance][:set]==:on)
-        SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],"#{@db.psql.db}::#{@opt.fns}").puts_blue
+        SiSU_Screen::Ansi.new(
+          @opt.act[:color_state][:set],
+          "#{@db.psql.db}::#{@opt.fns}"
+        ).puts_blue
       end
-      SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],'Marshal Load',@fnc).puts_grey if @opt.act[:verbose][:set]==:on
-#%
+      SiSU_Screen::Ansi.new(
+        @opt.act[:color_state][:set],
+        'Marshal Load',
+        @fnc
+      ).puts_grey if @opt.act[:verbose][:set]==:on
       select_first_match=%{
         SELECT metadata_and_text.tid
         FROM metadata_and_text
         WHERE metadata_and_text.src_filename = '#{@md.fns}'
         AND metadata_and_text.language_document_char = '#{@opt.lng}'
       ;} # note, for .ssm: @md.fns (is set during runtime & is) != @opt.fns @md.opt.fns
-      file_exist=@sql_type=~/sqlite/ \
-      ? @conn.get_first_value(select_first_match)
-      : @conn.select_one(select_first_match)
+      file_exist=if @sql_type==:sqlite
+        begin
+          @conn.get_first_value(select_first_match)
+        rescue SQLite3::Exception => e
+          # not tested
+          puts "Exception occurred"
+          puts e
+          SiSU_Utils::CodeMarker.new(__LINE__,__FILE__,:yellow).mark(
+            "\n" \
+            + 'Attempting to initialize db' + "\n" \
+            + 'Creating db tables'
+          )
+          sdb={
+            create: SiSU_DbDBI::Create.new(@opt,@conn,@file_maint,@sql_type),
+            index: SiSU_DbDBI::Index.new(@opt,@conn,@file_maint,@sql_type),
+          }
+          db_action(sdb).create
+        end
+      else
+        begin
+          @conn.exec(select_first_match).field_values("tid")[0]
+        rescue PG::Error => e
+          err=[
+            e.result.error_field( PG::Result::PG_DIAG_SEVERITY ),
+            e.result.error_field( PG::Result::PG_DIAG_SQLSTATE ),
+            e.result.error_field( PG::Result::PG_DIAG_MESSAGE_PRIMARY ),
+            e.result.error_field( PG::Result::PG_DIAG_MESSAGE_DETAIL ),
+            e.result.error_field( PG::Result::PG_DIAG_MESSAGE_HINT ),
+            e.result.error_field( PG::Result::PG_DIAG_STATEMENT_POSITION ),
+            e.result.error_field( PG::Result::PG_DIAG_INTERNAL_POSITION ),
+            e.result.error_field( PG::Result::PG_DIAG_INTERNAL_QUERY ),
+            e.result.error_field( PG::Result::PG_DIAG_CONTEXT ),
+            e.result.error_field( PG::Result::PG_DIAG_SOURCE_FILE ),
+            e.result.error_field( PG::Result::PG_DIAG_SOURCE_LINE ),
+            e.result.error_field( PG::Result::PG_DIAG_SOURCE_FUNCTION ),
+          ]
+          p err
+          if err[2] =~/relation "\S+?" does not exist/ \
+          or err.inspect =~/relation "\S+?" does not exist/
+            SiSU_Utils::CodeMarker.new(__LINE__,__FILE__,:yellow).mark(
+              "\n" \
+              + err[2] + "\n" \
+              + 'Attempting to initialize db' + "\n" \
+              + 'Creating db tables'
+            )
+            sdb={
+              create: SiSU_DbDBI::Create.new(@opt,@conn,@file_maint,@sql_type),
+              index: SiSU_DbDBI::Index.new(@opt,@conn,@file_maint,@sql_type),
+            }
+            db_action(sdb).create
+            retry
+          end
+        end
+      end
       if not file_exist
         t_d=[]                                                              # transaction_data
         t_d << db_import_metadata
@@ -152,7 +212,7 @@ module SiSU_DbImport
           puts @conn.driver if defined? @conn.driver
         end
         begin                                                               #% sql
-          if @sql_type=~/sqlite/
+          if @sql_type==:sqlite
             @conn.transaction do |conn|
               t_d.each do |sql|
                 conn.execute(sql)
@@ -166,27 +226,11 @@ module SiSU_DbImport
             #@conn.execute("COMMIT")
           else
             #'do' works for postgresql
-            @conn.do("BEGIN")
+            @conn.exec("BEGIN")
               t_d.each do |sql|
-                @conn.do(sql)
+                @conn.exec(sql)
               end
-            @conn.do("COMMIT")
-          end
-        rescue DBI::DatabaseError => e
-          STDERR.puts "Error code: #{e.err}"
-          STDERR.puts "Error message: #{e.errstr}"
-          STDERR.puts "Error SQLSTATE: #{e.state}"
-          SiSU_Errors::Rescued.new($!,$@,@opt.cmd,@opt.fns).location do
-            __LINE__.to_s + ':' + __FILE__
-          end
-          sqlfn="#{@env.processing_path.sql}/#{@md.fnb}.sql"
-          sql=File.new(sqlfn,'w')
-          t_d.each {|i| sql.puts i}
-          p sqlfn
-          if @opt.act[:maintenance][:set]==:on
-            puts sql
-            p @conn.methods.sort
-            puts "#{__FILE__}:#{__LINE__}"
+            @conn.exec("COMMIT")
           end
         rescue
           SiSU_Errors::Rescued.new($!,$@,@opt.cmd,@opt.fns).location do
@@ -206,7 +250,7 @@ module SiSU_DbImport
       else
         if file_exist
           @db=SiSU_Env::InfoDb.new
-          puts "\n#{@cX.grey}file #{@cX.off} #{@cX.blue}#{@opt.fns}#{@cX.off} in language code #{cX.blue}#{@opt.lng}#{cX.off} #{@cX.grey}already exists in database#{@cX.off} #{@cX.blue}#{@db.psql.db}#{@cX.off} #{@cX.brown}update instead?#{@cX.off}"
+          puts "\nfile #{@opt.fns} in language code #{@opt.lng} already exists in database #{@db.psql.db}, use --update instead?"
         end
       end
     end
@@ -261,11 +305,9 @@ module SiSU_DbImport
         sql='SELECT MAX(tid) FROM metadata_and_text;'
         begin
           @@id_t ||=0
-          id_t=if @driver_sqlite3
-            @conn.execute( sql ).join.to_i # { |x| id_t=x.join.to_i }
-          else
-            @conn.execute( sql ) { |x| x.fetch_all.flatten[0] }
-          end
+          id_t=@driver_sqlite3 \
+          ? @conn.execute( sql ).join.to_i # { |x| id_t=x.join.to_i }
+          : @conn.exec( sql ).getvalue(0,0).to_i
           @@id_t=id_t if id_t
         rescue
           puts "#{__FILE__} #{__LINE__}" if @opt.act[:maintenance][:set]==:on
@@ -497,7 +539,7 @@ module SiSU_DbImport
               @env=SiSU_Env::InfoEnv.new(@md.fns)
               @base_url="#{@env.url.root}/#{@md.fnb}/#{@hname}.html"
               txt=endnotes(txt).extract_any
-              if @sql_type=~/pg/ \
+              if @sql_type==:pg \
               and txt.size > (SiSU_DbColumns::ColumnSize.new.document_clean - 1)             # examine pg build & remove limitation
                 puts "\n\nTOO LARGE (TXT - see error log)\n\n"
                 open("#{Dir.pwd}/pg_documents_error_log",'a') do |error|
@@ -544,6 +586,7 @@ module SiSU_DbImport
                   if inf[/#{Mx[:en_a_o]}(\d+)(.+?)#{Mx[:en_a_c]}/]
                     nr,txt,digest_clean=$1,$2.strip,0
                   end
+                  @id_n ||=0
                   @id_n+=1
                   txt=special_character_escape(txt)
                   body=SiSU_FormatShared::CSS_Format.new(@md,data).endnote(nr,txt)
