@@ -113,9 +113,9 @@ module SiSU_Embedded
     def audio
       #p @md.ec[:audio]
       src="#{@base_src_dir}/_sisu/mm/audio"
-      ldest="#{@env.path.webserv}/#{@env.path.stub_pwd}/_sisu/mm/audio"
+      ldest="#{@env.path.webserv}/#{@env.path.base_markup_dir_stub}/_sisu/mm/audio"
       @rhost.each do |remote_conn|
-        rdest="#{remote_conn[:name]}/#{@env.path.stub_pwd}/_sisu/mm/audio"
+        rdest="#{remote_conn[:name]}/#{@env.path.base_markup_dir_stub}/_sisu/mm/audio"
         if (@md.opt.act[:verbose][:set]==:on \
         || @md.opt.act[:verbose_plus][:set]==:on \
         || @md.opt.act[:maintenance][:set]==:on \
@@ -133,9 +133,9 @@ module SiSU_Embedded
     def multimedia
       #p @md.ec[:multimedia]
       src="#{@base_src_dir}/_sisu/mm/video"
-      ldest="#{@env.path.webserv}/#{@env.path.stub_pwd}/_sisu/mm/video"
+      ldest="#{@env.path.webserv}/#{@env.path.base_markup_dir_stub}/_sisu/mm/video"
       @rhost.each do |remote_conn|
-        rdest="#{remote_conn[:name]}/#{@env.path.stub_pwd}/_sisu/mm/video"
+        rdest="#{remote_conn[:name]}/#{@env.path.base_markup_dir_stub}/_sisu/mm/video"
         if (@md.opt.act[:verbose][:set]==:on \
         || @md.opt.act[:verbose_plus][:set]==:on \
         || @md.opt.act[:maintenance][:set]==:on \
