@@ -89,7 +89,9 @@ module SiSU_HTML
       begin
         songsheet
       ensure
-        SiSU_Env::CreateSite.new(@opt.cmd).cp_css
+        SiSU_Env::CreateSite.new(@opt).cp_css
+        SiSU_Env::CreateSite.new(@opt).cp_base_images
+        Dir.chdir(@opt.f_pth[:pth])
       end
     end
     def songsheet
@@ -109,11 +111,23 @@ module SiSU_HTML
           (@opt.act[:verbose][:set]==:on \
           || @opt.act[:verbose_plus][:set]==:on \
           || @opt.act[:maintenance][:set]==:on) \
-          ? SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],'HTML',tool).green_hi_blue
-          : SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],'HTML',tool).green_title_hi
+          ? SiSU_Screen::Ansi.new(
+              @opt.act[:color_state][:set],
+              'HTML',
+              tool
+            ).green_hi_blue
+          : SiSU_Screen::Ansi.new(
+              @opt.act[:color_state][:set],
+              'HTML',
+              tool
+            ).green_title_hi
           if (@opt.act[:verbose_plus][:set]==:on \
           || @opt.act[:maintenance][:set]==:on)
-            SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],@opt.fns,"file://#{primary_output_file}").flow
+            SiSU_Screen::Ansi.new(
+              @opt.act[:color_state][:set],
+              @opt.fns,
+              "file://#{primary_output_file}"
+            ).flow
           end
         end
         data=nil
@@ -176,7 +190,7 @@ module SiSU_HTML
       @links_guide_toc=[]
       def initialize(data,md)
         @data,@md=data,md
-        @links_guide_=SiSU_Env::CreateSite.new(@md.opt.cmd).html_quick_ref?
+        @links_guide_=SiSU_Env::CreateSite.new(@md.opt).html_quick_ref?
       end
       def toc
         @links_guide_toc=[]
@@ -252,7 +266,10 @@ module SiSU_HTML
         if (@md.opt.act[:verbose][:set]==:on \
         || @md.opt.act[:verbose_plus][:set]==:on \
         || @md.opt.act[:maintenance][:set]==:on)
-          SiSU_Screen::Ansi.new(@md.opt.act[:color_state][:set],'Toc').txt_grey
+          SiSU_Screen::Ansi.new(
+            @md.opt.act[:color_state][:set],
+            'Toc'
+          ).txt_grey
         end
         toc=nil
         @@firstseg=nil
@@ -591,7 +608,10 @@ WOK
         if (@md.opt.act[:verbose][:set]==:on \
         || @md.opt.act[:verbose_plus][:set]==:on \
         || @md.opt.act[:maintenance][:set]==:on)
-          SiSU_Screen::Ansi.new(@md.opt.act[:color_state][:set],'Scroll & Segtoc').txt_grey
+          SiSU_Screen::Ansi.new(
+            @md.opt.act[:color_state][:set],
+            'Scroll & Segtoc'
+          ).txt_grey
         end
         format_head_toc=SiSU_HTML_Format::HeadToc.new(@md)
         dochead=format_head_toc.head
