@@ -126,7 +126,14 @@ module SiSU_FormatShared
               u=u.gsub(/^\.\.\//,'')
               "#{@env.url.root}/#{u}"
             else
-              "#{@env.url.root}/#{@md.fnb}/#{map_nametags[u][:segname]}#{Sfx[:html]}##{u}"
+              if not map_nametags[u].nil?
+                @env.url.root + '/' \
+                + @md.fnb + '/' \
+                + map_nametags[u][:segname] \
+                + Sfx[:html] \
+                + '#' + u
+              else ''
+              end
             end
             link=m[/(.+)/m]
             png=m.scan(/\S+/)[0].strip
