@@ -143,7 +143,8 @@
         end
         txt_obj={ txt: title }
         format_toc=SiSU_HTML_Format::FormatToc.new(@md,txt_obj)
-        toc_mini=if txt.name =~/^meta/ and txt.obj=~/Document Information/
+        toc_mini=if txt.name =~/^meta/ \
+        and txt.obj=~/Document Information/
           format_toc.mini_tail
         else format_toc.mini_lev1
         end
