@@ -417,7 +417,10 @@ WOK
           end
         end
       else
-        SiSU_Screen::Ansi.new(@md.opt.act[:color_state][:set],"*WARN* category not found: #{category}").warn unless @md.opt.act[:quiet][:set]==:on
+        SiSU_Screen::Ansi.new(
+          @md.opt.act[:color_state][:set],
+          "*WARN* category not found: #{category}"
+        ).warn unless @md.opt.act[:quiet][:set]==:on
       end
       adverts.join
     end
