@@ -75,13 +75,13 @@ module SiSU
   begin
     require 'uri'
   rescue LoadError
-    SiSU_Utils::CodeMarker.new(__LINE__,__FILE__,:fuchsia).error('uri NOT FOUND (LoadError)')
+    SiSU_Utils::CodeMarker.new(__LINE__,__FILE__,:fuchsia).
+      error('uri NOT FOUND (LoadError)')
   end
   class HubMaster
-    def initialize(argv)
-      pwd_the=Dir.pwd
+    def initialize(argv,call_path)
       begin                                            #% select what to do (set options & start processing (files selected if any))
-        opt=SiSU_Commandline::Options.new(argv)        #  command line selection of what to do, files & operations set
+        opt=SiSU_Commandline::Options.new(argv,call_path) #  command line selection of what to do, files & operations set
         SiSU::Processing.new(opt).actions              #  do it
       rescue
         cmd=(opt ? opt.cmd : '')
@@ -89,7 +89,23 @@ module SiSU
           __LINE__.to_s + ':' + __FILE__
         end
       ensure
-        Dir.chdir(pwd_the)
+        Dir.chdir(call_path)
+      end
+    end
+  end
+  class HubClose
+    def initialize(call_path)
+      begin
+        @env=SiSU_Env::InfoEnv.new
+      rescue
+      ensure
+        if FileTest.directory?(@env.processing_path.processing) \
+        and @env.processing_path.processing_base_tmp =~/^\/tmp\/\S+/
+          FileUtils::cd(@env.processing_path.processing_base_tmp) do
+            FileUtils::rm_rf('.')
+          end
+        end
+        Dir.chdir(call_path)
       end
     end
   end
@@ -111,6 +127,7 @@ module SiSU
         @opt.pth=@opt.f_pths[i][:pth]
         @opt.lng=@opt.f_pths[i][:lng]
         Dir.chdir(@opt.f_pth[:pth]) #watch
+        SiSU_Env::FilenameLanguageCodeInsert.new(@opt,@opt.lng).language_code_insert # ... track
         @env=SiSU_Env::InfoEnv.new(fno)
         yield
       end
@@ -159,7 +176,11 @@ module SiSU
         end
       end
       if files_translated_idx.flatten.length > 1
-      SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],'Manifest re-run on (currently generated) translated files',"").grey_title_hi unless @opt.act[:quiet][:set] ==:on
+        SiSU_Screen::Ansi.new(
+          @opt.act[:color_state][:set],
+          'Manifest re-run on (currently generated) translated files',
+          ''
+        ).grey_title_hi unless @opt.act[:quiet][:set] ==:on
         files_translated_idx.flatten.each do |i|
           @opt.fns=@opt.files[i]
           @opt.f_pth=@opt.f_pths[i]
@@ -191,22 +212,26 @@ module SiSU
       @@n_do=0
     end
     def remote_put_base_site_rsync                         # -CR
-      SiSU_Utils::CodeMarker.new(__LINE__,__FILE__).mark(:cyan) if @opt.act[:maintenance][:set] ==:on
+      SiSU_Utils::CodeMarker.new(__LINE__,__FILE__).mark(:cyan) \
+        if @opt.act[:maintenance][:set] ==:on
       require_relative 'remote'                        # remote.rb
       SiSU_Remote::Put.new(@opt).rsync_base
     end
     def remote_put_base_site_rsync_match                   # -CCRZ
-      SiSU_Utils::CodeMarker.new(__LINE__,__FILE__).mark(:cyan) if @opt.act[:maintenance][:set] ==:on
+      SiSU_Utils::CodeMarker.new(__LINE__,__FILE__).mark(:cyan) \
+        if @opt.act[:maintenance][:set] ==:on
       require_relative 'remote'                        # remote.rb
       SiSU_Remote::Put.new(@opt).rsync_base_sync
     end
     def remote_put_base_site                               # -Cr
-      SiSU_Utils::CodeMarker.new(__LINE__,__FILE__).mark(:cyan) if @opt.act[:maintenance][:set] ==:on
+      SiSU_Utils::CodeMarker.new(__LINE__,__FILE__).mark(:cyan) \
+        if @opt.act[:maintenance][:set] ==:on
       require_relative 'remote'                        # remote.rb
       SiSU_Remote::Put.new(@opt).scp_base
     end
     def remote_put_base_site_all                           # -CCr
-      SiSU_Utils::CodeMarker.new(__LINE__,__FILE__).mark(:cyan) if @opt.act[:maintenance][:set] ==:on
+      SiSU_Utils::CodeMarker.new(__LINE__,__FILE__).mark(:cyan) \
+        if @opt.act[:maintenance][:set] ==:on
       require_relative 'remote'                        # remote.rb
       SiSU_Remote::Put.new(@opt).scp_base_all
     end
@@ -217,7 +242,10 @@ module SiSU
     def termsheet                                          # -t
       system("sisu_termsheet #{@opt.cmd} #{@opt.fns}\n")
       @@n_do=@@n_do+1
-      SiSU_Screen::Ansi.new(@opt.cmd,@@n_do,'Termsheet(s) processed').term_sheet_title unless @opt.act[:quiet][:set] ==:on
+      SiSU_Screen::Ansi.new(
+        @opt.cmd,@@n_do,
+        'Termsheet(s) processed'
+      ).term_sheet_title unless @opt.act[:quiet][:set] ==:on
     end
     def webrick                                            # -W
       prt=SiSU_Env::InfoEnv.new(@fns).port.webrick_port
@@ -254,7 +282,8 @@ module SiSU
       require 'fileutils'
         include FileUtils
     rescue LoadError
-      SiSU_Utils::CodeMarker.new(__LINE__,__FILE__,:fuchsia).error('fileutils NOT FOUND (LoadError)')
+      SiSU_Utils::CodeMarker.new(__LINE__,__FILE__,:fuchsia).
+        error('fileutils NOT FOUND (LoadError)')
     end
     @@env=nil
     attr_accessor :op
@@ -262,19 +291,37 @@ module SiSU
       @opt=opt
       @@env=@env=SiSU_Env::InfoEnv.new
       @msg,@msgs='',nil
-      @tell=lambda { SiSU_Screen::Ansi.new(@opt.cmd,@msg,"#{@msgs.inspect if @msgs}") }
+      @tell=lambda {
+        SiSU_Screen::Ansi.new(@opt.cmd,@msg,"#{@msgs.inspect if @msgs}")
+      }
+    end
+    def remove_skipped_files_if_any_from_processing_files_array
+      if @remove_faulty_markup_files_array.length > 0
+        @opt.files = (@opt.files - @remove_faulty_markup_files_array)
+      end
+    end
+    def print_error_message_if_files_skipped
+      if @remove_faulty_markup_files_array.length > 0
+        puts '---'
+        STDERR.puts 'ERROR with file(s), did not process: ' +
+          @remove_faulty_markup_files_array.join(',')
+      end
     end
     def do_loops
+      @remove_faulty_markup_files_array=[]
       if @opt.act[:zap][:set]==:on                     #% --zap, -Z
         do_loop_files_on_given_option_pre
       end
       do_each_file_loop_options
+      remove_skipped_files_if_any_from_processing_files_array
       do_loop_files_on_given_option_post
+      print_error_message_if_files_skipped
     end
     def do_each_file_loop_options
       @opt.files.each_with_index do |fno,i|
         @opt.fno=fno
-        @opt.fns=fno.gsub(/(?:https?|file):\/\/\S+\/(\S+)\.sst$/,'\1.-sst').
+        @opt.fns=fno.
+          gsub(/(?:https?|file):\/\/\S+\/(\S+)\.sst$/,'\1.-sst').
           gsub(/\.ssm$/,'.ssm.sst')
         @opt.f_pth=@opt.f_pths[i]
         if @opt.fns !~/\.-sst$/
@@ -290,121 +337,127 @@ module SiSU
         end
         @env=SiSU_Env::InfoEnv.new(@opt.fns)
         if @opt.act[:ao][:set]==:on                   #% --ao --dal, -m
+          $process_document = :ok
           unless @opt.act[:po4a][:set]==:on            # --po4a, -P
             if @opt.fno =~ /\.ssm$/
-              require_relative 'composite'             # composite.rb #pre-processing
+              require_relative 'ao_composite'          # ao_composite.rb #pre-processing
               SiSU_Assemble::Composite.new(@opt).read
             end
             require_relative 'ao'                      # -m     ao.rb
             SiSU_AO::Source.new(@opt).read
           end
         end
-        if @opt.act[:qrcode][:set]==:on                #% --qrcode, -Q
-          require_relative 'qrcode'                    #  qrcode.rb
-          SiSU_QRcode::Source.new(@opt).read
-        end
-        if @opt.act[:hash_digests][:set]==:on          #% --hash-digests, -N digest tree
-          require_relative 'digests'                   #  digests.rb
-          SiSU_DigestView::Source.new(@opt).read
-        end
-        if @opt.act[:txt][:set]==:on                   #% --txt, -t -a
-          require_relative 'txt_plain'                 #  txt_plain.rb
-          SiSU_Txt_Plain::Source.new(@opt).read
-        end
-        if @opt.act[:txt_textile][:set]==:on           #% --textile
-          require_relative 'txt_textile'               #  txt_textile.rb
-          SiSU_Txt_Textile::Source.new(@opt).read
-        end
-        if @opt.act[:txt_asciidoc][:set]==:on          #% --asciidoc
-          require_relative 'txt_asciidoc'              #  txt_asciidoc.rb
-          SiSU_Txt_AsciiDoc::Source.new(@opt).read
-        end
-        if @opt.act[:txt_markdown][:set]==:on          #% --markdown
-          require_relative 'txt_markdown'              #  txt_markdown.rb
-          SiSU_Txt_Markdown::Source.new(@opt).read
-        end
-        if @opt.act[:txt_rst][:set]==:on               #% --rst, --rest
-          require_relative 'txt_rst'                   #  txt_rst.rb
-          SiSU_Txt_rST::Source.new(@opt).read
-        end
-        if @opt.act[:html][:set]==:on                  #% --html, -h -H
-          require_relative 'html'                      #  html.rb
-          SiSU_HTML::Source.new(@opt).read
+        if $process_document == :ok
+          if @opt.act[:qrcode][:set]==:on                #% --qrcode, -Q
+            require_relative 'qrcode'                    #  qrcode.rb
+            SiSU_QRcode::Source.new(@opt).read
+          end
+          if @opt.act[:hash_digests][:set]==:on          #% --hash-digests, -N digest tree
+            require_relative 'digests'                   #  digests.rb
+            SiSU_DigestView::Source.new(@opt).read
+          end
+          if @opt.act[:txt][:set]==:on                   #% --txt, -t -a
+            require_relative 'txt_plain'                 #  txt_plain.rb
+            SiSU_Txt_Plain::Source.new(@opt).read
+          end
+          if @opt.act[:txt_textile][:set]==:on           #% --textile
+            require_relative 'txt_textile'               #  txt_textile.rb
+            SiSU_Txt_Textile::Source.new(@opt).read
+          end
+          if @opt.act[:txt_asciidoc][:set]==:on          #% --asciidoc
+            require_relative 'txt_asciidoc'              #  txt_asciidoc.rb
+            SiSU_Txt_AsciiDoc::Source.new(@opt).read
+          end
+          if @opt.act[:txt_markdown][:set]==:on          #% --markdown
+            require_relative 'txt_markdown'              #  txt_markdown.rb
+            SiSU_Txt_Markdown::Source.new(@opt).read
+          end
+          if @opt.act[:txt_rst][:set]==:on               #% --rst, --rest
+            require_relative 'txt_rst'                   #  txt_rst.rb
+            SiSU_Txt_rST::Source.new(@opt).read
+          end
+          if @opt.act[:html][:set]==:on                  #% --html, -h -H
+            require_relative 'html'                      #  html.rb
+            SiSU_HTML::Source.new(@opt).read
+          else
+            if @opt.act[:html_seg][:set]==:on            #% --html-seg (-h -H)
+              require_relative 'html'                    #  html.rb
+              SiSU_HTML::Source.new(@opt).read
+            end
+            if @opt.act[:html_scroll][:set]==:on         #% --html-scroll (-h -H)
+              require_relative 'html'                    #  html.rb
+              SiSU_HTML::Source.new(@opt).read
+            end
+          end
+          if @opt.act[:concordance][:set]==:on           #% --concordance, -w
+            require_relative 'html_concordance'          #  html_concordance.rb
+            SiSU_Concordance::Source.new(@opt).read
+          end
+          if @opt.act[:epub][:set]==:on                  #% --epub, -e
+            require_relative 'xhtml_epub2'               # xhtml_epub2.rb
+            SiSU_XHTML_EPUB2::Source.new(@opt).read
+          end
+          if @opt.act[:odt][:set]==:on                   #% --odt, -o opendocument
+            require_relative 'xml_odf_odt'               #  xml_odf_odt.rb
+            SiSU_XML_ODF_ODT::Source.new(@opt).read
+          end
+          if @opt.act[:xhtml][:set]==:on                 #% --xhtml, -b xhtml
+            require_relative 'xhtml'                     #  xhtml.rb
+            SiSU_XHTML::Source.new(@opt).read
+          end
+          if @opt.act[:xml_scaffold_structure_sisu][:set]==:on #% --xml-scaffold --xml-scaffold-sisu
+            require_relative 'xml_scaffold_structure_sisu' #  xml_scaffold_structure_sisu.rb
+            SiSU_XML_Scaffold_Structure_Sisu::Source.new(@opt).read
+          end
+          if @opt.act[:xml_scaffold_structure_collapse][:set]==:on #% --xml-scaffold-collapse
+            require_relative 'xml_scaffold_structure_collapsed' # xml_scaffold_structure_collapsed.rb
+            SiSU_XML_Scaffold_Structure_Collapse::Source.new(@opt).read
+          end
+          if @opt.act[:xml_docbook_book][:set]==:on      #% --xml-docbook
+            require_relative 'xml_docbook5'              # xml_docbook5.rb
+            SiSU_XML_Docbook_Book::Source.new(@opt).read
+          end
+          if @opt.act[:xml_fictionbook][:set]==:on       #% --xml-fictionbook
+            require_relative 'xml_fictionbook2'          # xml_fictionbook2.rb
+            SiSU_XML_Fictionbook::Source.new(@opt).read
+          end
+          if @opt.act[:xml_sax][:set]==:on               #% --xml-sax, -x xml sax type
+            require_relative 'xml_sax'                   #  xml_sax.rb
+            SiSU_XML_SAX::Source.new(@opt).read
+          end
+          if @opt.act[:xml_dom][:set]==:on               #% --xml-dom, -X xml dom type
+            require_relative 'xml_dom'                   #  xml_dom.rb
+            SiSU_XML_DOM::Source.new(@opt).read
+          end
+          if @opt.act[:pdf][:set]==:on \
+          or @opt.act[:pdf_p][:set]==:on \
+          or @opt.act[:pdf_l][:set]==:on                 #% --pdf-l --pdf, -p latex/ texpdf
+            require_relative 'texpdf'                    #  texpdf.rb
+            SiSU_TeX::Source.new(@opt).read
+          end
+          if @opt.act[:manpage][:set]==:on               #% --manpage, -i
+            require_relative 'manpage'                   #  manpage.rb
+            SiSU_Manpage::Source.new(@opt).read
+          end
+          if @opt.act[:texinfo][:set]==:on               #% --texinfo, -I
+            require_relative 'texinfo'                   #  texinfo.rb
+            SiSU_TexInfo::Source.new(@opt).read
+          end
+          if @opt.act[:sqlite_discrete][:set]==:on       #% --sqlite, -d DB sqlite
+            require_relative 'dbi_discrete'              #  dbi_discrete.rb
+            SiSU_DBI_Discrete::SQL.new(@opt).build
+          end
+          if @opt.act[:manifest][:set]==:on              #% --manifest, -y
+            require_relative 'manifest'                  #  manifest.rb
+            ((@opt.act[:sisupod][:set]==:on \
+            || @opt.act[:share_source][:set]==:on) \
+            && @opt.files.length < 2 ) \
+            ? nil
+            : SiSU_Manifest::Source.new(@opt).read
+          end
         else
-          if @opt.act[:html_seg][:set]==:on            #% --html-seg (-h -H)
-            require_relative 'html'                    #  html.rb
-            SiSU_HTML::Source.new(@opt).read
-          end
-          if @opt.act[:html_scroll][:set]==:on         #% --html-scroll (-h -H)
-            require_relative 'html'                    #  html.rb
-            SiSU_HTML::Source.new(@opt).read
-          end
-        end
-        if @opt.act[:concordance][:set]==:on           #% --concordance, -w
-          require_relative 'concordance'               #  concordance.rb
-          SiSU_Concordance::Source.new(@opt).read
-        end
-        if @opt.act[:epub][:set]==:on                  #% --epub, -e
-          require_relative 'xhtml_epub2'               # xhtml_epub2.rb
-          SiSU_XHTML_EPUB2::Source.new(@opt).read
-        end
-        if @opt.act[:odt][:set]==:on                   #% --odt, -o opendocument
-          require_relative 'xml_odf_odt'               #  xml_odf_odt.rb
-          SiSU_XML_ODF_ODT::Source.new(@opt).read
-        end
-        if @opt.act[:xhtml][:set]==:on                 #% --xhtml, -b xhtml
-          require_relative 'xhtml'                     #  xhtml.rb
-          SiSU_XHTML::Source.new(@opt).read
-        end
-        if @opt.act[:xml_scaffold_structure_sisu][:set]==:on #% --xml-scaffold --xml-scaffold-sisu
-          require_relative 'xml_scaffold_structure_sisu' #  xml_scaffold_structure_sisu.rb
-          SiSU_XML_Scaffold_Structure_Sisu::Source.new(@opt).read
-        end
-        if @opt.act[:xml_scaffold_structure_collapse][:set]==:on #% --xml-scaffold-collapse
-          require_relative 'xml_scaffold_structure_collapsed' # xml_scaffold_structure_collapsed.rb
-          SiSU_XML_Scaffold_Structure_Collapse::Source.new(@opt).read
-        end
-        if @opt.act[:xml_docbook_book][:set]==:on      #% --xml-docbook
-          require_relative 'xml_docbook5'              # xml_docbook5.rb
-          SiSU_XML_Docbook_Book::Source.new(@opt).read
-        end
-        if @opt.act[:xml_fictionbook][:set]==:on       #% --xml-fictionbook
-          require_relative 'xml_fictionbook2'          # xml_fictionbook2.rb
-          SiSU_XML_Fictionbook::Source.new(@opt).read
-        end
-        if @opt.act[:xml_sax][:set]==:on               #% --xml-sax, -x xml sax type
-          require_relative 'xml_sax'                   #  xml_sax.rb
-          SiSU_XML_SAX::Source.new(@opt).read
-        end
-        if @opt.act[:xml_dom][:set]==:on               #% --xml-dom, -X xml dom type
-          require_relative 'xml_dom'                   #  xml_dom.rb
-          SiSU_XML_DOM::Source.new(@opt).read
-        end
-        if @opt.act[:pdf][:set]==:on \
-        or @opt.act[:pdf_p][:set]==:on \
-        or @opt.act[:pdf_l][:set]==:on                 #% --pdf-l --pdf, -p latex/ texpdf
-          require_relative 'texpdf'                    #  texpdf.rb
-          SiSU_TeX::Source.new(@opt).read
-        end
-        if @opt.act[:manpage][:set]==:on               #% --manpage, -i
-          require_relative 'manpage'                   #  manpage.rb
-          SiSU_Manpage::Source.new(@opt).read
-        end
-        if @opt.act[:texinfo][:set]==:on               #% --texinfo, -I
-          require_relative 'texinfo'                   #  texinfo.rb
-          SiSU_TexInfo::Source.new(@opt).read
-        end
-        if @opt.act[:sqlite_discrete][:set]==:on       #% --sqlite, -d DB sqlite
-          require_relative 'dbi_discrete'              #  dbi_discrete.rb
-          SiSU_DBI_Discrete::SQL.new(@opt).build
-        end
-        if @opt.act[:manifest][:set]==:on              #% --manifest, -y
-          require_relative 'manifest'                  #  manifest.rb
-          ((@opt.act[:sisupod][:set]==:on \
-          || @opt.act[:share_source][:set]==:on) \
-          && @opt.files.length < 2 ) \
-          ? nil
-          : SiSU_Manifest::Source.new(@opt).read
+          @remove_faulty_markup_files_array << fno
+          $process_document=:ok
         end
       end
     end
@@ -472,7 +525,8 @@ module SiSU
         ensure
           path_pod=@env.processing_path.processing_sisupod(@opt).paths
           unless @opt.act[:maintenance][:set]==:on
-            FileUtils::rm_rf("#{path_pod[:sisupod]}/*") if FileTest.directory?(path_pod[:sisupod])
+            FileUtils::rm_rf("#{path_pod[:sisupod]}/*") \
+              if FileTest.directory?(path_pod[:sisupod])
           end
         end
       end
@@ -498,7 +552,7 @@ module SiSU
             case @opt.fns
             when /\.(termsheet.rb)$/
               SiSU::Operations.new(@opt).termsheet
-            else                                 #print "not processed --> ", fns, "\n"
+            else                                       #print "not processed --> ", fns, "\n"
             end
           else SiSU::Operations.new(@opt).not_found
           end
@@ -508,13 +562,13 @@ module SiSU
       if @opt.act[:psql][:set]==:on                    #% --pg, -D DB postgresql
         require_relative 'dbi'
         OptionLoopFiles.new(@opt).loop_files_on_given_option do
-          SiSU_DBI::SQL.new(@opt).connect            # -D -d  dbi.rb
+          SiSU_DBI::SQL.new(@opt).connect              # -D -d  dbi.rb
         end
       end
       if @opt.act[:sqlite][:set]==:on                  #% --sqlite, -d DB sqlite
         require_relative 'dbi'
         OptionLoopFiles.new(@opt).loop_files_on_given_option do
-          SiSU_DBI::SQL.new(@opt).connect            # -D -d  dbi.rb
+          SiSU_DBI::SQL.new(@opt).connect              # -D -d  dbi.rb
         end
       end
       if @opt.act[:manifest][:set]==:on                #% --manifest, -y
@@ -559,7 +613,10 @@ module SiSU
         if (@opt.act[:verbose][:set]==:on \
         || @opt.act[:verbose_plus][:set]==:on \
         || @opt.act[:maintenance][:set]==:on)
-          SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],' ' + File.dirname(__FILE__)).grey
+          SiSU_Screen::Ansi.new(
+            @opt.act[:color_state][:set],
+            ' ' + File.dirname(__FILE__)
+          ).grey
         end
       end
       if @opt.act[:ao][:set]==:on \
@@ -572,20 +629,12 @@ module SiSU
         path[:xsd]=path[:xml] + '/rng'
         re_p3=/(sisupod(?:\.txz)?|\S+?\.ss[mt]\.txz|[^\/]+?\.ssp)$/
         unless @opt.files.join(',') =~ re_p3 #do not mix pods with source markup files in command line
-        # unless ( FileTest.directory?(path[:css]) \
-        # and FileTest.directory?(path[:xsd]) )
-        #   @opt.cmd=@opt.cmd +='C' unless @opt.cmd =~/C/ #FIX
-        # end
           if @opt.act[:maintenance][:set] ==:on
             $VERBOSE=false                               #debug $VERBOSE=true
           end
         end
         re_p2=/(sisupod(?:\.zip)?|\S+?\.ss[mt]\.zip)$/
         unless @opt.files.join(',') =~ re_p2 #do not mix pods with source markup files in command line
-        # unless ( FileTest.directory?(path[:css]) \
-        # and FileTest.directory?(path[:xsd]) )
-        #   @opt.cmd=@opt.cmd +='C' unless @opt.cmd =~/C/ #FIX
-        # end
           if @opt.act[:maintenance][:set] ==:on
             $VERBOSE=false                               #debug $VERBOSE=true
           end
@@ -656,7 +705,8 @@ module SiSU
         begin
           require 'profile'
         rescue LoadError
-          SiSU_Utils::CodeMarker.new(__LINE__,__FILE__,:fuchsia).error('profile NOT FOUND (LoadError)')
+          SiSU_Utils::CodeMarker.new(__LINE__,__FILE__,:fuchsia).
+            error('profile NOT FOUND (LoadError)')
         end
       end
       action_on_file_ =if @opt.act[:rsync][:set]==:on \
@@ -751,8 +801,10 @@ module SiSU
           and @@env.user \
           and FileTest.directory?(@@env.processing_path.processing) \
           and @@env.processing_path.processing =~/#{@@env.user}$/ #clean temporary processing directory of content as is located in public area
-            FileUtils::cd(@@env.processing_path.processing_base_tmp) do
-              FileUtils::rm_rf(@@env.user) unless @opt.act[:maintenance][:set] ==:on
+            if @@env.processing_path.processing_base_tmp =~/^\/tmp\/\S+/
+              FileUtils::cd(@@env.processing_path.processing_base_tmp) do
+                FileUtils::rm_rf('.') unless @opt.act[:maintenance][:set] ==:on
+              end
             end
           end
         elsif action_on_file_ == :true \
