@@ -88,15 +88,29 @@ module SiSU_Manifest
         browser=@env.program.console_web_browser
 #       webserv_url=@env.path.url.output_tell #fix in sysenv
         unless @opt.act[:quiet][:set]==:on
-          url_html="file://#{@md.file.output_path.manifest.dir}/#{@md.file.base_filename.manifest}"
+          url_html='file://' \
+          + @md.file.output_path.manifest.dir + '/' \
+          + @md.file.base_filename.manifest
           (@opt.act[:verbose][:set]==:on \
           || @opt.act[:verbose_plus][:set]==:on \
           || @opt.act[:maintenance][:set]==:on) \
-          ? SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],'Manifest',"#{xbrowser} #{url_html}").green_hi_blue
-          : SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],'Manifest',"[#{@opt.f_pth[:lng_is]}]", "#{url_html}").grey_title_grey_blue
+          ? SiSU_Screen::Ansi.new(
+              @opt.act[:color_state][:set],
+              'Manifest',
+              "#{xbrowser} #{url_html}"
+            ).green_hi_blue
+          : SiSU_Screen::Ansi.new(
+              @opt.act[:color_state][:set],
+              'Manifest',
+              "[#{@opt.f_pth[:lng_is]}]",
+              "#{url_html}"
+            ).grey_title_grey_blue
           if (@md.opt.act[:verbose][:set]==:on \
           || @md.opt.act[:verbose_plus][:set]==:on)
-            SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],"#{browser} #{url_html}").grey_tab
+            SiSU_Screen::Ansi.new(
+              @opt.act[:color_state][:set],
+              "#{browser} #{url_html}"
+            ).grey_tab
           end
         end
         data=SiSU_HTML::Source::HTML_Environment.new(@particulars).tuned_file_instructions
@@ -106,7 +120,8 @@ module SiSU_Manifest
           __LINE__.to_s + ':' + __FILE__
         end
       ensure
-        SiSU_Env::CreateSite.new(@opt.cmd).cp_css
+        SiSU_Env::CreateSite.new(@opt).cp_css
+        Dir.chdir(@opt.f_pth[:pth])
       end
     end
     private
@@ -123,7 +138,7 @@ module SiSU_Manifest
         ? './image'
         : %{#{@f.path_rel_links.html_scroll_2}_sisu/image_sys}
         @base_path=@f.output_path.manifest.dir
-        @@dg ||=SiSU_Env::InfoEnv.new.digest.type
+        @@dg ||=SiSU_Env::InfoEnv.new(md.fns,md).digest(md.opt).type
         @dg=@@dg
         l=SiSU_Env::StandardiseLanguage.new(md.opt.lng).language
         @language=l[:n]
@@ -165,18 +180,32 @@ module SiSU_Manifest
       end
       def summarize_sources(id,file,pth,rel,url)
         sys=SiSU_Env::SystemCall.new
-        dgst=(@dg =~/^sha(?:2|256)$/) \
-        ? sys.sha256("#{pth}/#{file}")
-        : sys.md5("#{pth}/#{file}")
+        dgst=case @dg
+        when :sha512
+          sys.sha512("#{pth}/#{file}")
+        when :sha256
+          sys.sha256("#{pth}/#{file}")
+        when :md5
+          sys.md5("#{pth}/#{file}")
+        else
+        end
         if (@md.opt.act[:verbose][:set]==:on \
         || @md.opt.act[:verbose_plus][:set]==:on \
         || @md.opt.act[:maintenance][:set]==:on)
-          SiSU_Screen::Ansi.new(@md.opt.act[:color_state][:set],"#{dgst[1]} #{file}").warn
+          SiSU_Screen::Ansi.new(
+            @md.opt.act[:color_state][:set],
+            "#{dgst[1]} #{file}"
+          ).warn
         end
         size=(File.size("#{pth}/#{file}")/1024.00).to_s
         kb=/([0-9]+\.[0-9]{0,1})/m.match(size)[1]
         @manifest[:txt] << "#{file} #{id} #{kb}\n"
-        @manifest[:html] << %{<tr><th class="left"><p class="norm"><a href="#{rel}/#{file}">#{id}</a></p></th><td class="right"><p class="tiny"><a href="#{rel}/#{file}">#{file}</a> &nbsp;&nbsp;#{dgst[1]}#{url_make(url,file,:src)}</p></td><td class="right"><p class="right">#{kb}</p></td></tr>\n} if kb and kb =~/\d+/
+        @manifest[:html] << %{<tr>} \
+        + %{<th class="left"><p class="norm"><a href="#{rel}/#{file}">#{id}</a></p></th>} \
+        + %{<td class="right"><p class="tiny"><a href="#{rel}/#{file}">#{file}</a> &nbsp;&nbsp;#{dgst[1]}#{url_make(url,file,:src)}</p></td>} \
+        + %{<td class="right"><p class="right">#{kb}</p></td>} \
+        + %{</tr>\n} \
+          if kb and kb =~/\d+/
       end
       def published_manifests?
         @f=SiSU_Env::FileOp.new(@md) #.base_filename
