@@ -95,11 +95,23 @@ module SiSU_Manpage
         || @opt.act[:verbose_plus][:set]==:on \
         || @opt.act[:maintenance][:set]==:on) \
         && @opt.cmd !~/q/ \
-        ? SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],'Manpage',tool).green_hi_blue
-        : SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],'Manpage',tool).green_title_hi
+        ? SiSU_Screen::Ansi.new(
+            @opt.act[:color_state][:set],
+            'Manpage',
+            tool
+          ).green_hi_blue
+        : SiSU_Screen::Ansi.new(
+            @opt.act[:color_state][:set],
+            'Manpage',
+            tool
+          ).green_title_hi
         if (@opt.act[:verbose_plus][:set]==:on \
         || @opt.act[:maintenance][:set]==:on)
-          SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],@opt.fns,"#{@md.file.output_path.manpage.dir}/#{@md.file.base_filename.manpage}").flow
+          SiSU_Screen::Ansi.new(
+            @opt.act[:color_state][:set],
+            @opt.fns,
+            "#{@md.file.output_path.manpage.dir}/#{@md.file.base_filename.manpage}"
+          ).flow
         end
         @ao_array=SiSU_AO::Source.new(@opt).get # ao file drawn here
         SiSU_Manpage::Source::Scroll.new(@md,@ao_array).songsheet
@@ -108,6 +120,7 @@ module SiSU_Manpage
           __LINE__.to_s + ':' + __FILE__
         end
       ensure
+        Dir.chdir(@opt.f_pth[:pth])
       end
     end
     private
@@ -337,7 +350,7 @@ WOK
               paranum=dob.obj[@regx,3]
               @p_num=SiSU_ManpageFormat::ParagraphNumber.new(paranum)
             end
-            x=SiSU_ManpageFormat::FormatTextObject.new(@md,dob)
+            SiSU_ManpageFormat::FormatTextObject.new(@md,dob) #check
             if dob.is==:heading
               manpage_structure(dob)
             elsif dob.is==:para
