@@ -69,11 +69,27 @@ module SiSU_Commandline
   end
   require_relative 'sysenv'                             # sysenv.rb
   require_relative 'param_make'                         # param_make.rb
-  @@sisu_call_origin_path=nil
   class HeaderCommon
-    def sisu_document_make_instructions
-      @pagenew=@pagebreak=@pageline=@toc=@lv1=@lv2=@lv3=@lv4=@lv5=@lv6=@num_top=@i18n=@man_section=@emphasis_set_to=@bold_match_list=@italics_match_list=@substitution_match_list=@footer_links=@home_button_links=@links=nil
-      make_instruct_array=SiSU_Env::GetInit.new.sisu_document_make.makefile_read
+    def sisu_document_make_instructions(make_instruct_array=:nil)
+      @pagenew=
+        @pagebreak=
+        @pageline=
+        @toc=
+        @lv1=@lv2=@lv3=@lv4=@lv5=@lv6=
+        @num_top=
+        @i18n=
+        @man_section=
+        @emphasis_set_to=
+        @bold_match_list=
+        @italics_match_list=
+        @substitution_match_list=
+        @footer_links=
+        @home_button_links=
+        @links=
+        nil
+      make_instruct_array=make_instruct_array==:nil \
+      ? SiSU_Env::GetInit.new.sisu_document_make.makefile_read
+      : make_instruct_array
       @makeset=false
       if make_instruct_array
         make_instruct_array.each do |para|                                     #% scan document
@@ -140,20 +156,20 @@ module SiSU_Commandline
     end
   end
   class Options
-    attr_accessor :cmd,:mod,:act,:dir_structure_by,:lingual,:f_pths,:files,:files_mod,:base_path,:base_stub,:sub_location,:paths,:lngs,:f_pth,:pth,:fno,:fns,:fnb,:fnc,:fng,:fncb,:lng,:lng_base,:what,:make_instructions,:make_instructions_pod
+    attr_accessor :cmd,:mod,:act,:dir_structure_by,:lingual,:f_pths,:files,:files_mod,:call_path,:base_path,:base_stub,:sub_location,:image_src_path,:paths,:lngs,:f_pth,:pth,:fno,:fns,:fnb,:fnc,:fng,:fncb,:lng,:lng_base,:what,:make_instructions,:make_instructions_pod
     @@act=nil
-    def initialize(a)
-      @cmd,@f_pth,@pth,@fno,@fns,@fnb,@fnc,@fng,@fncb,@what,@lng,@lng_base,@base_path,@base_stub,@sub_location='','','','','','','','','','','','','',''
+    def initialize(a,call_path)
+      @cmd=@f_pth=@pth=@fno=@fns=@fnb=@fnc=@fng=@fncb=@what=@lng=@lng_base=@call_path=@base_path=@base_stub=@image_src_path=@sub_location=''
       @f_pths,@files,@files_mod,@paths,@mod,@act=Array.new(5){[]}
       @env=SiSU_Env::InfoEnv.new
       @lng_base=@env.language_default_set
       @dir_structure_by=SiSU_Env::EnvCall.new.output_dir_structure.by?
       @lingual=SiSU_Env::EnvCall.new.mono_multi_lingual?
-      @@sisu_call_origin_path ||=Dir.pwd
-      @base_path=@@sisu_call_origin_path
-      r=Px[:lng_lst_rgx]
-      u=/.+?\/([^\/]+)(?:\/(?:#{r})$|$)/
-      @base_stub=@base_path.gsub(u,'\1')
+      @call_path=call_path
+      pth=SiSU_Utils::Path.new(call_path)
+      @base_path=pth.base_markup
+      @base_stub=pth.base_markup_stub
+      @image_src_path=pth.image_src
       @a=sisu_glob_rules(a)
       @a.freeze
       @make_instructions=HeaderCommon.new.sisu_document_make_instructions
@@ -261,14 +277,17 @@ module SiSU_Commandline
         @lngs = q[:lngs]
         if @files.length > 0 \
         and @cmd.empty? \
-        and @mod.length==0 #% if no other action called on filename given, default is sisu --v4 -0 [filename(s)] configured as flag default
+        and @mod.length==0 #% if no other action called on filename given, default is sisu --v5 -0 [filename(s)] configured as flag default
           shortcut=SiSU_Env::InfoProcessingFlag.new
-          @mod=['--v4']
-          @cmd=shortcut.cf_0 + 'm'
+          @mod=['--v5']
+          @cmd=shortcut.cf_0 + ' --dal'
         end
         if @cmd =~/[vVM]/ \
         && @cmd !~/-[ku]*v[ku]*$/
-          SiSU_Screen::Ansi.new(@cmd,"\tsisu " + @cmd +  ' ' + @mod.join(' ') + ' ' + @files.join(' ') + "\n").print_brown
+          SiSU_Screen::Ansi.new(
+            @cmd,
+            "\tsisu " + @cmd +  ' ' + @mod.join(' ') + ' ' + @files.join(' ') + "\n"
+          ).print_brown
         end
       end
       @@act ? @act=@@act : @@act=@act=opt_act
@@ -316,7 +335,8 @@ module SiSU_Commandline
             FileUtils::mkdir_p(pt.to_s)
             pod_make_path=fullname + '/sisupod/doc/_sisu'
             make_instruct_array=sisu_document_make_pod.makefile_read(pod_make_path)
-            @make_instructions_pod=HeaderCommon.new(make_instruct_array).sisu_document_make_instructions
+            @make_instructions_pod=
+              HeaderCommon.new.sisu_document_make_instructions(make_instruct_array)
             Dir.chdir(pt.realpath)
             system("
               chdir #{fullname}
@@ -410,7 +430,7 @@ module SiSU_Commandline
               lng: lng_is,
               lng_is: lng_is,
               url_base: nil,
-              url: nil
+              url: nil,
             }
           else  puts "file not found: #{x}"
           end
@@ -422,7 +442,16 @@ module SiSU_Commandline
           puts "#{x} in #{a.join(' ')}?"
         end
       end
-      { cmd: c, mod: m, what: w, paths: pth, files: f, f_pths: f_pths, lng: lng_is, lngs: lngs }
+      {
+        cmd: c,
+        mod: m,
+        what: w,
+        paths: pth,
+        files: f,
+        f_pths: f_pths,
+        lng: lng_is,
+        lngs: lngs,
+      }
     end
     def expand_numeric_shortcuts(a)
       shortcut=SiSU_Env::InfoProcessingFlag.new
@@ -430,7 +459,7 @@ module SiSU_Commandline
       a.each do |x|
         y=case x
         when /0/
-          (x=~/^-1\S+/) \
+          (x=~/^-0\S+/) \
           ? x.gsub(/^-0(\S+)/,shortcut.cf_0 + ' -\1')
           : x.gsub(/^-0/,shortcut.cf_0 + ' ')
         when /1/
@@ -508,6 +537,7 @@ module SiSU_Commandline
             mod << s
           when /^--(?:epub)$/                                                       then c=c+'e'
           when /^--(?:od[ft])$/                                                     then c=c+'o'
+          when /^--docbook$/                                                     then c=c+'d'
           when /^--(?:pdf)$/                                                        then c=c+'p'
           when /^--pdf-(?:a4|a5|b5|legal|letter)$/                                  then c=c+'p'
           when /^--pdf-(?:p|l|portrait|landscape)$/                                 then c=c+'L'
@@ -520,13 +550,11 @@ module SiSU_Commandline
           when /^--(?:xml-sax)$/                                                    then c=c+'x'
           when /^--(?:xml-dom)$/                                                    then c=c+'X'
           when /^--(?:images)$/                                                     then c=c+'j'
-          when /^--(?:hash-digests)$/                                               then c=c+'N'
+          when /^--(?:digests?|hash-digests)$/                                      then c=c+'N'
           when /^--(?:po4a|pot?)$/                                                  then c=c+'P'
           when /^--(?:termsheet)$/                                                  then c=c+'T'
           when /^--(?:manifest)$/                                                   then c=c+'y'
           when /^--(?:qrcode)$/                                                     then c=c+'Q'
-          when /^--(?:sqlite)$/                                                     then c=c+'d'
-          when /^--(?:pg|pg?sql|postgresql)$/                                       then c=c+'D'
           when /^--(?:remote|rsync)$/                                               then c=c+'R'
           when /^--(?:scp)$/                                                        then c=c+'r'
           when /^--(?:source)$/                                                     then c=c+'s'
@@ -558,8 +586,7 @@ module SiSU_Commandline
         extra+=if cmd =~/[abegHhIiLNOoPpQTtwXxyz]/ \
         and cmd !~/[mn]/
           'm'                        #% add ao
-        elsif ((cmd =~/[Dd]/ \
-        or (mod.inspect =~/--(?:(?:sq)?lite|pg(?:sql)?)/)) \
+        elsif ((mod.inspect =~/--(?:(?:sq)?lite|pg(?:sql)?)/) \
         and mod.inspect !~/(?:remove|(?:(?:re)?create(?:all)?|dropall|drop)$)/) \
         and cmd !~/[mn]/
           'm'                        #% add ao
@@ -567,18 +594,17 @@ module SiSU_Commandline
         end
       end
       if cmd !~/j/
-        extra+=if cmd =~/[bHhwXxyz]/ \
+        extra+=if cmd =~/[bdHhwXxyz]/ \
         and cmd !~/[j]/
           'j'                        #% copy images
         else ''
         end
       end
       if cmd !~/y/
-        extra+=if cmd =~/[abeHhIiNopQSstwXxz]/ \
+        extra+=if cmd =~/[abdeHhIiNopQSstwXxz]/ \
         and cmd !~/y/
           'ym'                       #% add manifest
-        elsif (cmd =~/[Dd]/ \
-        or mod.inspect =~/--(?:(?:sq)?lite|pg(?:sql)?)/) \
+        elsif mod.inspect =~/--(?:(?:sq)?lite|pg(?:sql)?)/ \
         and files[0] !~/^remove$/ \
         and cmd !~/y/
           'ym'                       #% add manifest
@@ -666,10 +692,10 @@ module SiSU_Commandline
           { set: :filetype }
         else { set: :na }
         end
-        act[:ocn]=if mod.inspect =~/"--ocn"|"--inc-ocn"/
+        act[:ocn]=if mod.inspect =~/"--ocn"|"--inc-ocn"|"--numbering"|"--inc-numbering"/
           { bool: true, set: :on }
-        elsif mod.inspect =~/"--no-ocn"|"--exc-ocn"/ \
-        || act[:switch][:off].inspect =~/"ocn"/
+        elsif mod.inspect =~/"--no-ocn"|"--exc-ocn"|"--no-numbering"|"--exc-numbering"/ \
+        || act[:switch][:off].inspect =~/"ocn"|"--numbering"/
           { bool: false, set: :off }
         else { bool: true, set: :na }
         end
@@ -866,11 +892,11 @@ module SiSU_Commandline
         ? { bool: true, set: :on }
         : { bool: false, set: :na }
         act[:odt]=if cmd =~/o/ \
-        or mod.inspect =~/"--odt"|"--odf"|"--odt-ocn"|"--odf-ocn"/
-          act[:odt_ocn]=if (mod.inspect =~/"--odt-ocn"|"--odf-ocn"/ \
-          or mod.inspect =~/"--ocn"|"--inc-ocn"/)
+        or mod.inspect =~/"--odt"|"--odf"|"--odt-(?:ocn|numbering)"|"--odf-(?:ocn|numbering)"/
+          act[:odt_ocn]=if (mod.inspect =~/"--odt-(?:ocn|numbering)"|"--odf-(?:ocn|numbering)"/ \
+          or mod.inspect =~/"--ocn"|"--inc-ocn"|"--numbering"|"--inc-numbering"/)
             { bool: true, set: :on }
-          elsif mod.inspect =~/"--no-ocn"|"--exc-ocn"/
+          elsif mod.inspect =~/"--no-ocn"|"--exc-ocn"|"--no-numbering"|"--exc-numbering"/
             { bool: false, set: :off }
           else
             { bool: false, set: :na }
@@ -887,7 +913,8 @@ module SiSU_Commandline
         || mod.inspect =~/"--xml-dom"/) \
         ? { bool: true, set: :on }
         : { bool: false, set: :na }
-        act[:xml_docbook_book]=mod.inspect =~/"--docbook"|"--docbook-book"|"--xml-docbook"|"--xml-docbook_book"/ \
+        act[:xml_docbook_book]=(cmd =~/d/ \
+        || mod.inspect =~/"--docbook"|"--docbook-book"|"--xml-docbook"|"--xml-docbook_book"/) \
         ? { bool: true, set: :on }
         : { bool: false, set: :na }
         act[:xml_fictionbook]=(cmd =~/f/ \
@@ -905,11 +932,11 @@ module SiSU_Commandline
         ? { bool: true, set: :on }
         : { bool: false, set: :na }
         act[:txt]=if cmd =~/[at]/ \
-        or mod.inspect =~/"--txt"|"--text"|"--plaintext"|"--txt-ocn"|"--text-ocn"|"--plaintext-ocn"/
-          act[:txt_ocn]=if (mod.inspect =~/"--txt-ocn"|"--text-ocn"|"--plaintext-ocn"/ \
-          or mod.inspect =~/"--ocn"|"--inc-ocn"/)
+        or mod.inspect =~/"--txt"|"--text"|"--plaintext"|"--txt-(?:ocn|numbering)"|"--text-(?:ocn|numbering)"|"--plaintext-(?:ocn|numbering)"/
+          act[:txt_ocn]=if (mod.inspect =~/"--txt-(?:ocn|numbering)"|"--text-(?:ocn|numbering)"|"--plaintext-(?:ocn|numbering)"/ \
+          or mod.inspect =~/"--ocn"|"--inc-ocn"|"--numbering"|"--inc-numbering"/)
             { bool: true, set: :on }
-          elsif mod.inspect =~/"--no-ocn"|"--exc-ocn"/
+          elsif mod.inspect =~/"--no-ocn"|"--exc-ocn"|"--no-numbering"|"--exc-numbering"/
             { bool: false, set: :off }
           else
             { bool: false, set: :na }
@@ -938,19 +965,134 @@ module SiSU_Commandline
         || mod.inspect =~/"--texinfo"/) \
         ? { bool: true, set: :on }
         : { bool: false, set: :na }
-        act[:psql]=(cmd =~/D/ \
-        || mod.inspect =~/"--pg"|"--pgsql"/) \
-        ? { bool: true, set: :on }
-        : { bool: false, set: :na }
-        act[:sqlite]=(cmd =~/d/ \
-        || mod.inspect =~/"--sqlite"/) \
-        && (mod.inspect =~/"--createdb"|"--create(?:all)?"|"--dropall"|"--recreate(?:all)?"|"--import"|"--update"|"--remove"/) \
-        ? { bool: true, set: :on }
-        : { bool: false, set: :na }
-        act[:sqlite_discrete]=(cmd =~/d/ \
-        || mod.inspect =~/"--sql"|"--sqlite"/) \
-        && (mod.inspect =~/"--both"/ \
-        || mod.inspect !~/"--createdb"|"--create(?:all)?"|"--dropall"|"--recreate(?:all)?"|"--import"|"--update"|"--remove"/) \
+        act[:psql]=if mod.inspect =~/"--pg-\S+"/ \
+        or ((mod.inspect =~/"--pg"/) \
+        && (mod.inspect \
+        =~/"--createdb"|"--create(?:all)?"|"--dropall"|"--recreate(?:all)?"|"--import"|"--update"|"--remove"/))
+          act[:psql_createdb]=if mod.inspect \
+          =~/"--pg-createdb"|"--createdb"/
+            { bool: true, set: :on }
+          else
+            { bool: false, set: :na }
+          end
+          if mod.inspect \
+          =~/"--pg-recreate(?:all)?"|"--recreate(?:all)?"/
+            act[:psql_drop]={ bool: true, set: :on }
+            act[:psql_create]={ bool: true, set: :on }
+          else
+            act[:psql_drop]=if mod.inspect \
+            =~/"--pg-dropall"|"--dropall"/
+              { bool: true, set: :on }
+            else
+              { bool: false, set: :na }
+            end
+            act[:psql_create]=if mod.inspect \
+            =~/"--pg-create(?:all)?"|"--create(?:all)?"/
+              { bool: true, set: :on }
+            else
+              { bool: false, set: :na }
+            end
+          end
+          act[:psql_import]=if mod.inspect \
+          =~/"--pg-import"|"--import"/
+            { bool: true, set: :on }
+          else
+            { bool: false, set: :na }
+          end
+          act[:psql_update]=if mod.inspect \
+          =~/"--pg-update"|"--update"/
+            act[:psql_remove]={ bool: true, set: :on }
+            { bool: true, set: :on }
+          else
+            act[:psql_remove]=if mod.inspect \
+            =~/"--pg-remove"|"--remove"/
+              { bool: true, set: :on }
+            else
+              { bool: false, set: :na }
+            end
+            { bool: false, set: :na }
+          end
+          { bool: true, set: :on }
+        else
+          act[:psql_createdb]=
+            { bool: false, set: :na }
+          act[:psql_drop]=
+            { bool: false, set: :na }
+          act[:psql_create]=
+            { bool: false, set: :na }
+          act[:psql_import]=
+            { bool: false, set: :na }
+          act[:psql_update]=
+            { bool: false, set: :na }
+          act[:psql_remove]=
+            { bool: false, set: :na }
+          { bool: false, set: :na }
+        end
+        act[:sqlite]=if (mod.inspect =~/"--sqlite-\S+"/) \
+        or ((mod.inspect =~/"--sqlite"/) \
+        && (mod.inspect \
+        =~/"--createdb"|"--create(?:all)?"|"--dropall"|"--recreate(?:all)?"|"--import"|"--update"|"--remove"/))
+          act[:sqlite_createdb]=if mod.inspect \
+          =~/"--sqlite-createdb"|"--createdb"/
+            { bool: true, set: :on }
+          else
+            { bool: false, set: :na }
+          end
+          if mod.inspect \
+          =~/"--sqlite-recreate(?:all)?"|"--recreate(?:all)?"/
+            act[:sqlite_drop]={ bool: true, set: :on }
+            act[:sqlite_create]={ bool: true, set: :on }
+          else
+            act[:sqlite_create]=if mod.inspect \
+            =~/"--sqlite-create(?:all)?"|"--create(?:all)?"/
+              { bool: true, set: :on }
+            else
+              { bool: false, set: :na }
+            end
+            act[:sqlite_drop]=if mod.inspect \
+            =~/"--sqlite-dropall"|"--dropall"/
+              { bool: true, set: :on }
+            else
+              { bool: false, set: :na }
+            end
+          end
+          act[:sqlite_import]=if mod.inspect \
+          =~/"--sqlite-import"|"--import"/
+            { bool: true, set: :on }
+          else
+            { bool: false, set: :na }
+          end
+          act[:sqlite_update]=if mod.inspect \
+          =~/"--sqlite-update"|"--update"/
+            act[:sqlite_remove]={ bool: true, set: :on }
+            { bool: true, set: :on }
+          else
+            act[:sqlite_remove]=if mod.inspect \
+            =~/"--sqlite-remove"|"--sqlite-remove"/
+              { bool: true, set: :on }
+            else
+              { bool: false, set: :na }
+            end
+            { bool: false, set: :na }
+          end
+          { bool: true, set: :on }
+        else
+          act[:sqlite_createdb]=
+            { bool: false, set: :na }
+          act[:sqlite_drop]=
+            { bool: false, set: :na }
+          act[:sqlite_create]=
+            { bool: false, set: :na }
+          act[:sqlite_import]=
+            { bool: false, set: :na }
+          act[:sqlite_update]=
+            { bool: false, set: :na }
+          act[:sqlite_remove]=
+            { bool: false, set: :na }
+          { bool: false, set: :na }
+        end
+        act[:sqlite_discrete]=mod.inspect =~/"--sql"|"--sqlite"/ \
+        && (mod.inspect !~/"--createdb"|"--create(?:all)?"|"--dropall"|"--recreate(?:all)?"|"--import"|"--update"|"--remove"/) \
         ? { bool: true, set: :on }
         : { bool: false, set: :na }
         act[:harvest]=(mod.inspect =~/"--harvest"/) \
@@ -965,9 +1107,27 @@ module SiSU_Commandline
         ? { bool: true, set: :on }
         : { bool: false, set: :na }
         act[:hash_digests]=(cmd =~/N/ \
-        || mod.inspect =~/"--hash-digests"/) \
+        || mod.inspect =~/"--digests?"|"--hash-digests"/) \
         ? { bool: true, set: :on }
         : { bool: false, set: :na }
+        act[:pdf_font_size]=if mod.inspect =~/"--(?:pdf-)?font-?size[=-](\d{1,2})(?:pt)?"/
+          $1
+        else :na
+        end
+        act[:pdf_hyperlink_colors]=if mod.inspect =~/"--pdf-hyperlinks-(?:mono(?:chrome)?|no-color)"/
+          :mono
+        elsif mod.inspect =~/"--pdf-hyperlinks-color"/
+          :color
+        else :na
+        end
+        act[:hash_digest_algo]=if mod.inspect =~/"--hash-(?:sha)?512"/
+          :sha512
+        elsif mod.inspect =~/"--hash-(?:sha)?256"/
+          :sha256
+        elsif mod.inspect =~/"--hash-md5"/
+          :md5
+        else :na
+        end
         act[:sample_search_form]=(cmd =~/F/ \
         || mod.inspect =~/"--sample-search-form"/) \
         ? { bool: true, set: :on }
