@@ -8,7 +8,8 @@
  * Author: Ralph Amissah
 
  * Copyright: (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-   2007, 2008, 2009, 2010, 2011, 2012, 2013 Ralph Amissah, All Rights Reserved.
+   2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014 Ralph Amissah,
+   All Rights Reserved.
 
  * License: GPL 3 or later:
 
@@ -66,35 +67,35 @@ module SiSU_Translate
     def initialize(md,doc_lang,trans_str='')
       @md,@doc_lang,@trans_str=md,doc_lang,trans_str
       @lang_class=case @doc_lang
-      when /American/i;                  English.new(md,doc_lang,trans_str)    # tag depreciated, see iso 639-2
-      when /English/i;                   English.new(md,doc_lang,trans_str)
-      when /French/i;                    French.new(md,doc_lang,trans_str)
-      when /German/i;                    German.new(md,doc_lang,trans_str)
-      when /Italian/i;                   Italian.new(md,doc_lang,trans_str)
-      when /Spanish/i;                   Spanish.new(md,doc_lang,trans_str)
-      when /Portuguese Brazil|Brazilian(?: Portuguese)?/i;
-                                         Portuguese.new(md,doc_lang,trans_str) # tag depreciated, see iso 639-2
-      when /Portuguese/i;                Portuguese.new(md,doc_lang,trans_str)
-      when /Swedish/i;                   Swedish.new(md,doc_lang,trans_str)
-      when /Danish/i;                    Danish.new(md,doc_lang,trans_str)
-      when /Finnish/i;                   Finnish.new(md,doc_lang,trans_str)
-      when /Norwegian/i;                 Norwegian.new(md,doc_lang,trans_str)
-      when /Icelandic/i;                 Icelandic.new(md,doc_lang,trans_str)
-      when /Dutch/i;                     Dutch.new(md,doc_lang,trans_str)
-      when /Estonian/i;                  Estonian.new(md,doc_lang,trans_str)
-      when /Hungarian/i;                 Hungarian.new(md,doc_lang,trans_str)
-      when /Polish/i;                    Polish.new(md,doc_lang,trans_str)
-      when /Romanian/i;                  Romanian.new(md,doc_lang,trans_str)
-      when /Russian/i;                   Russian.new(md,doc_lang,trans_str)
-      when /Greek/i;                     Greek.new(md,doc_lang,trans_str)
-      when /Ukranian/i;                  Ukranian.new(md,doc_lang,trans_str)
-      when /Turkish/i;                   Turkish.new(md,doc_lang,trans_str)
-      when /Slovenian/i;                 Slovenian.new(md,doc_lang,trans_str)
-      when /Croatian/i;                  Croatian.new(md,doc_lang,trans_str)
-      when /Slovak(?:ian)?/i;            Slovak.new(md,doc_lang,trans_str)
-      when /Czech/i;                     Czech.new(md,doc_lang,trans_str)
-      when /Bulgarian/i;                 Bulgarian.new(md,doc_lang,trans_str)
-      else                               English.new(md,doc_lang,trans_str)
+      when /American/i       then English.new(md,doc_lang,trans_str)    # tag depreciated, see iso 639-2
+      when /English/i        then English.new(md,doc_lang,trans_str)
+      when /French/i         then French.new(md,doc_lang,trans_str)
+      when /German/i         then German.new(md,doc_lang,trans_str)
+      when /Italian/i        then Italian.new(md,doc_lang,trans_str)
+      when /Spanish/i        then Spanish.new(md,doc_lang,trans_str)
+      when /Portuguese Brazil|Brazilian(?: Portuguese)?/i
+                                  Portuguese.new(md,doc_lang,trans_str) # tag depreciated, see iso 639-2
+      when /Portuguese/i     then Portuguese.new(md,doc_lang,trans_str)
+      when /Swedish/i        then Swedish.new(md,doc_lang,trans_str)
+      when /Danish/i         then Danish.new(md,doc_lang,trans_str)
+      when /Finnish/i        then Finnish.new(md,doc_lang,trans_str)
+      when /Norwegian/i      then Norwegian.new(md,doc_lang,trans_str)
+      when /Icelandic/i      then Icelandic.new(md,doc_lang,trans_str)
+      when /Dutch/i          then Dutch.new(md,doc_lang,trans_str)
+      when /Estonian/i       then Estonian.new(md,doc_lang,trans_str)
+      when /Hungarian/i      then Hungarian.new(md,doc_lang,trans_str)
+      when /Polish/i         then Polish.new(md,doc_lang,trans_str)
+      when /Romanian/i       then Romanian.new(md,doc_lang,trans_str)
+      when /Russian/i        then Russian.new(md,doc_lang,trans_str)
+      when /Greek/i          then Greek.new(md,doc_lang,trans_str)
+      when /Ukranian/i       then Ukranian.new(md,doc_lang,trans_str)
+      when /Turkish/i        then Turkish.new(md,doc_lang,trans_str)
+      when /Slovenian/i      then Slovenian.new(md,doc_lang,trans_str)
+      when /Croatian/i       then Croatian.new(md,doc_lang,trans_str)
+      when /Slovak(?:ian)?/i then Slovak.new(md,doc_lang,trans_str)
+      when /Czech/i          then Czech.new(md,doc_lang,trans_str)
+      when /Bulgarian/i      then Bulgarian.new(md,doc_lang,trans_str)
+      else                        English.new(md,doc_lang,trans_str)
       end
     end
     def filename
@@ -279,38 +280,38 @@ module SiSU_Translate
     end
     def language_list
       case @trans_str
-      when /American/i;                  'American English'                    # tag depreciated, see iso 639-2
-      when /English/i;                   'English'
-      when /French/i;                    'français'
-      when /German/i;                    'Deutsch'
-      when /Italian/i;                   'Italiano'
-      when /Spanish/i;                   'español'
-      when /Portuguese Brazil|Brazilian(?: Portuguese)?/i;
-                                         'Brazilian Português'                 # tag depreciated, see iso 639-2
-      when /Portuguese/i;                'Português'
-      when /Swedish/i;                   'svenska'
-      when /Danish/i;                    'dansk'
-      when /Finnish/i;                   'suomi'
-      when /Norwegian/i;                 'norsk'
-      when /Icelandic/i;                 'Icelandic'
-      when /Dutch/i;                     'Nederlands'
-      when /Estonian/i;                  'Estonian'
-      when /Hungarian/i;                 'Hungarian'
-      when /Polish/i;                    'polski'
-      when /Romanian/i;                  'română'
-      when /Russian/i;                   'Русский (Russkij)'
-      when /Greek/i;                     'Ελληνικά (Ellinika)'
-      when /Ukranian/i;                  'українська (ukrajins\'ka)'
-      when /Turkish/i;                   'Türkçe'
-      when /Slovenian/i;                 'Slovenian'
-      when /Croatian/i;                  'Croatian'
-      when /Slovak(?:ian)?/i;            'slovensky'            #slovensky ?
-      when /Czech/i;                     'česky'
-      when /Bulgarian/i;                 'Български (Bəlgarski)'
-      when /Japanese/i;                  '日本語 (Nihongo)'
-      when /Korean/i;                    '한국어 (Hangul)'
-      #when /Catalan/i;                   'català'
-      else                               'English'
+      when /American/i       then 'American English'                    # tag depreciated, see iso 639-2
+      when /English/i        then 'English'
+      when /French/i         then 'français'
+      when /German/i         then 'Deutsch'
+      when /Italian/i        then 'Italiano'
+      when /Spanish/i        then 'español'
+      when /Portuguese Brazil|Brazilian(?: Portuguese)?/i
+                                  'Brazilian Português'                 # tag depreciated, see iso 639-2
+      when /Portuguese/i     then 'Português'
+      when /Swedish/i        then 'svenska'
+      when /Danish/i         then 'dansk'
+      when /Finnish/i        then 'suomi'
+      when /Norwegian/i      then 'norsk'
+      when /Icelandic/i      then 'Icelandic'
+      when /Dutch/i          then 'Nederlands'
+      when /Estonian/i       then 'Estonian'
+      when /Hungarian/i      then 'Hungarian'
+      when /Polish/i         then 'polski'
+      when /Romanian/i       then 'română'
+      when /Russian/i        then 'Русский (Russkij)'
+      when /Greek/i          then 'Ελληνικά (Ellinika)'
+      when /Ukranian/i       then 'українська (ukrajins\'ka)'
+      when /Turkish/i        then 'Türkçe'
+      when /Slovenian/i      then 'Slovenian'
+      when /Croatian/i       then 'Croatian'
+      when /Slovak(?:ian)?/i then 'slovensky'            #slovensky ?
+      when /Czech/i          then 'česky'
+      when /Bulgarian/i      then 'Български (Bəlgarski)'
+      when /Japanese/i       then '日本語 (Nihongo)'
+      when /Korean/i         then '한국어 (Hangul)'
+     #when /Catalan/i        then 'català'
+      else                         'English'
       end
       #check on 中文  and عربي
     end
@@ -498,34 +499,34 @@ module SiSU_Translate
     end
     def language_list_translated
       case @trans_str
-      when /American/i;                  'American English'                    # tag depreciated, see iso 639-2
-      when /English/i;                   'English'
-      when /French/i;                    'French'
-      when /German/i;                    'German'
-      when /Italian/i;                   'Italian'
-      when /Spanish/i;                   'Spanish'
-      when /Portuguese Brazil|Brazilian(?: Portuguese)?/i;
-                                         'Brazilian Portuguese'                # tag depreciated, see iso 639-2
-      when /Portuguese/i;                'Portuguese'
-      when /Swedish/i;                   'Swedish'
-      when /Danish/i;                    'Danish'
-      when /Finnish/i;                   'Finnish'
-      when /Norwegian/i;                 'Norwegian'
-      when /Icelandic/i;                 'Icelandic'
-      when /Dutch/i;                     'Dutch'
-      when /Estonian/i;                  'Estonian'
-      when /Hungarian/i;                 'Hungarian'
-      when /Polish/i;                    'Polish'
-      when /Romanian/i;                  'Romanian'
-      when /Russian/i;                   'Russian'
-      when /Greek/i;                     'Greek'
-      when /Ukranian/i;                  'Ukranian'
-      when /Turkish/i;                   'Turkish'
-      when /Slovenian/i;                 'Slovenian'
-      when /Croatian/i;                  'Croatian'
-      when /Slovak(?:ian)?/i;            'Slovakian'
-      when /Czech/i;                     'Czech'
-      when /Bulgarian/i;                 'Bulgarian'
+      when /American/i       then 'American English'                    # tag depreciated, see iso 639-2
+      when /English/i        then 'English'
+      when /French/i         then 'French'
+      when /German/i         then 'German'
+      when /Italian/i        then 'Italian'
+      when /Spanish/i        then 'Spanish'
+      when /Portuguese Brazil|Brazilian(?: Portuguese)?/i
+                                  'Brazilian Portuguese'                # tag depreciated, see iso 639-2
+      when /Portuguese/i     then 'Portuguese'
+      when /Swedish/i        then 'Swedish'
+      when /Danish/i         then 'Danish'
+      when /Finnish/i        then 'Finnish'
+      when /Norwegian/i      then 'Norwegian'
+      when /Icelandic/i      then 'Icelandic'
+      when /Dutch/i          then 'Dutch'
+      when /Estonian/i       then 'Estonian'
+      when /Hungarian/i      then 'Hungarian'
+      when /Polish/i         then 'Polish'
+      when /Romanian/i       then 'Romanian'
+      when /Russian/i        then 'Russian'
+      when /Greek/i          then 'Greek'
+      when /Ukranian/i       then 'Ukranian'
+      when /Turkish/i        then 'Turkish'
+      when /Slovenian/i      then 'Slovenian'
+      when /Croatian/i       then 'Croatian'
+      when /Slovak(?:ian)?/i then 'Slovakian'
+      when /Czech/i          then 'Czech'
+      when /Bulgarian/i      then 'Bulgarian'
       else @trans_str
       end
     end
@@ -713,34 +714,34 @@ module SiSU_Translate
     end
     def language_list_translated
       case @trans_str
-      when /American/i;                  'Anglais americain'                   # tag depreciated, see iso 639-2
-      when /English/i;                   'Anglais'
-      when /French/i;                    'Français'
-      when /German/i;                    'Allemand'
-      when /Italian/i;                   'Italien'
-      when /Spanish/i;                   'Espagnol'
-      when /Portuguese Brazil|Brazilian(?: Portuguese)?/i;
-                                         'Portugais brésilien'                 # tag depreciated, see iso 639-2
-      when /Portuguese/i;                'Portugais'
-      when /Swedish/i;                   'Suédois'
-      when /Danish/i;                    'Danois'
-      when /Finnish/i;                   'Finnois'
-      when /Norwegian/i;                 'Norvégien'
-      when /Icelandic/i;                 'Islandais'
-      when /Dutch/i;                     'Néerlandais'
-      when /Estonian/i;                  'Estonien'
-      when /Hungarian/i;                 'Hongrois'
-      when /Polish/i;                    'Polonais'
-      when /Romanian/i;                  'Roumain'
-      when /Russian/i;                   'Russe'
-      when /Greek/i;                     'Grec'
-      when /Ukranian/i;                  'Ukrainien'
-      when /Turkish/i;                   'Turc'
-      when /Slovenian/i;                 'Slovène'
-      when /Croatian/i;                  'Croate'
-      when /Slovak(?:ian)?/i;            'Slovaque'
-      when /Czech/i;                     'Tcheque'
-      when /Bulgarian/i;                 'Bulgare'
+      when /American/i       then 'Anglais americain'                   # tag depreciated, see iso 639-2
+      when /English/i        then 'Anglais'
+      when /French/i         then 'Français'
+      when /German/i         then 'Allemand'
+      when /Italian/i        then 'Italien'
+      when /Spanish/i        then 'Espagnol'
+      when /Portuguese Brazil|Brazilian(?: Portuguese)?/i
+                                  'Portugais brésilien'                 # tag depreciated, see iso 639-2
+      when /Portuguese/i     then 'Portugais'
+      when /Swedish/i        then 'Suédois'
+      when /Danish/i         then 'Danois'
+      when /Finnish/i        then 'Finnois'
+      when /Norwegian/i      then 'Norvégien'
+      when /Icelandic/i      then 'Islandais'
+      when /Dutch/i          then 'Néerlandais'
+      when /Estonian/i       then 'Estonien'
+      when /Hungarian/i      then 'Hongrois'
+      when /Polish/i         then 'Polonais'
+      when /Romanian/i       then 'Roumain'
+      when /Russian/i        then 'Russe'
+      when /Greek/i          then 'Grec'
+      when /Ukranian/i       then 'Ukrainien'
+      when /Turkish/i        then 'Turc'
+      when /Slovenian/i      then 'Slovène'
+      when /Croatian/i       then 'Croate'
+      when /Slovak(?:ian)?/i then 'Slovaque'
+      when /Czech/i          then 'Tcheque'
+      when /Bulgarian/i      then 'Bulgare'
       else @trans_str
       end
     end
@@ -925,34 +926,34 @@ module SiSU_Translate
     end
     def language_list_translated
       case @trans_str
-      when /American/i;                  'Amerikanisch-Englisch'               # tag depreciated, see iso 639-2
-      when /English/i;                   'Englisch'
-      when /French/i;                    'Französisch'
-      when /German/i;                    'Deutsch'
-      when /Italian/i;                   'Italienisch'
-      when /Spanish/i;                   'Spanisch'
-      when /Portuguese Brazil|Brazilian(?: Portuguese)?/i;
-                                         'Brasilianisch-Portugiesisch'         # tag depreciated, see iso 639-2
-      when /Portuguese/i;                'Portugiesisch'
-      when /Swedish/i;                   'Schwedisch'
-      when /Danish/i;                    'Dänisch'
-      when /Finnish/i;                   'Finnisch'
-      when /Norwegian/i;                 'Norwegisch'
-      when /Icelandic/i;                 'Isländisch'
-      when /Dutch/i;                     'Niederländisch'
-      when /Estonian/i;                  'Estnisch'
-      when /Hungarian/i;                 'Ungarisch'
-      when /Polish/i;                    'Polnisch'
-      when /Romanian/i;                  'Rumänisch'
-      when /Russian/i;                   'Russisch'
-      when /Greek/i;                     'Griechisch'
-      when /Ukranian/i;                  'Ukrainisch'
-      when /Turkish/i;                   'Türkisch'
-      when /Slovenian/i;                 'Slovenisch'
-      when /Croatian/i;                  'Kroatisch'
-      when /Slovak(?:ian)?/i;            'Slovakisch'
-      when /Czech/i;                     'Tschechisch'
-      when /Bulgarian/i;                 'Bulgarisch'
+      when /American/i       then 'Amerikanisch-Englisch'               # tag depreciated, see iso 639-2
+      when /English/i        then 'Englisch'
+      when /French/i         then 'Französisch'
+      when /German/i         then 'Deutsch'
+      when /Italian/i        then 'Italienisch'
+      when /Spanish/i        then 'Spanisch'
+      when /Portuguese Brazil|Brazilian(?: Portuguese)?/i
+                                  'Brasilianisch-Portugiesisch'         # tag depreciated, see iso 639-2
+      when /Portuguese/i     then 'Portugiesisch'
+      when /Swedish/i        then 'Schwedisch'
+      when /Danish/i         then 'Dänisch'
+      when /Finnish/i        then 'Finnisch'
+      when /Norwegian/i      then 'Norwegisch'
+      when /Icelandic/i      then 'Isländisch'
+      when /Dutch/i          then 'Niederländisch'
+      when /Estonian/i       then 'Estnisch'
+      when /Hungarian/i      then 'Ungarisch'
+      when /Polish/i         then 'Polnisch'
+      when /Romanian/i       then 'Rumänisch'
+      when /Russian/i        then 'Russisch'
+      when /Greek/i          then 'Griechisch'
+      when /Ukranian/i       then 'Ukrainisch'
+      when /Turkish/i        then 'Türkisch'
+      when /Slovenian/i      then 'Slovenisch'
+      when /Croatian/i       then 'Kroatisch'
+      when /Slovak(?:ian)?/i then 'Slovakisch'
+      when /Czech/i          then 'Tschechisch'
+      when /Bulgarian/i      then 'Bulgarisch'
       else @trans_str
       end
     end
@@ -1137,34 +1138,34 @@ module SiSU_Translate
     end
     def language_list_translated
       case @trans_str
-      when /American/i;                  'Inglés Americano'                     # tag depreciated, see iso 639-2
-      when /English/i;                   'Inglés'
-      when /French/i;                    'Francés'
-      when /German/i;                    'Alemán'
-      when /Italian/i;                   'Italiano'
-      when /Spanish/i;                   'Español'
-      when /Portuguese Brazil|Brazilian(?: Portuguese)?/i;
-                                         'Portugués de Brasil'                  # tag depreciated, see iso 639-2
-      when /Portuguese/i;                'Portugués'
-      when /Swedish/i;                   'Sueco'
-      when /Danish/i;                    'Danés'
-      when /Finnish/i;                   'Finés'
-      when /Norwegian/i;                 'Noruego'
-      when /Icelandic/i;                 'Islandés'
-      when /Dutch/i;                     'Holandés'
-      when /Estonian/i;                  'Estonio'
-      when /Hungarian/i;                 'Húngaro'
-      when /Polish/i;                    'Polaco'
-      when /Romanian/i;                  'Rumano'
-      when /Russian/i;                   'Ruso'
-      when /Greek/i;                     'Griego'
-      when /Ukranian/i;                  'Ucraniano'
-      when /Turkish/i;                   'Turco'
-      when /Slovenian/i;                 'Eslovaco'
-      when /Croatian/i;                  'Croata'
-      when /Slovak(?:ian)?/i;            'Eslovaco'
-      when /Czech/i;                     'Checo'
-      when /Bulgarian/i;                 'Búlgaro'
+      when /American/i       then 'Inglés Americano'                     # tag depreciated, see iso 639-2
+      when /English/i        then 'Inglés'
+      when /French/i         then 'Francés'
+      when /German/i         then 'Alemán'
+      when /Italian/i        then 'Italiano'
+      when /Spanish/i        then 'Español'
+      when /Portuguese Brazil|Brazilian(?: Portuguese)?/i
+                                  'Portugués de Brasil'                  # tag depreciated, see iso 639-2
+      when /Portuguese/i     then 'Portugués'
+      when /Swedish/i        then 'Sueco'
+      when /Danish/i         then 'Danés'
+      when /Finnish/i        then 'Finés'
+      when /Norwegian/i      then 'Noruego'
+      when /Icelandic/i      then 'Islandés'
+      when /Dutch/i          then 'Holandés'
+      when /Estonian/i       then 'Estonio'
+      when /Hungarian/i      then 'Húngaro'
+      when /Polish/i         then 'Polaco'
+      when /Romanian/i       then 'Rumano'
+      when /Russian/i        then 'Ruso'
+      when /Greek/i          then 'Griego'
+      when /Ukranian/i       then 'Ucraniano'
+      when /Turkish/i        then 'Turco'
+      when /Slovenian/i      then 'Eslovaco'
+      when /Croatian/i       then 'Croata'
+      when /Slovak(?:ian)?/i then 'Eslovaco'
+      when /Czech/i          then 'Checo'
+      when /Bulgarian/i      then 'Búlgaro'
       else @trans_str
       end
     end
@@ -1349,34 +1350,34 @@ module SiSU_Translate
     end
     def language_list_translated
       case @trans_str
-      when /American/i;                  'Inglese USA'                         # tag depreciated, see iso 639-2
-      when /English/i;                   'Inglese'
-      when /French/i;                    'Francese'
-      when /German/i;                    'Tedesco'
-      when /Italian/i;                   'Italiano'
-      when /Spanish/i;                   'Spagnolo'
-      when /Portuguese Brazil|Brazilian(?: Portuguese)?/i;
-                                         'Portoguese (Brasile)'                # tag depreciated, see iso 639-2
-      when /Portuguese/i;                'Portoguese'
-      when /Swedish/i;                   'Svedese'
-      when /Danish/i;                    'Danese'
-      when /Finnish/i;                   'Finlandese'
-      when /Norwegian/i;                 'Norvegese'
-      when /Icelandic/i;                 'Islandese'
-      when /Dutch/i;                     'Olandese'
-      when /Estonian/i;                  'Estone'
-      when /Hungarian/i;                 'Ungherese'
-      when /Polish/i;                    'Polacco'
-      when /Romanian/i;                  'Romeno'
-      when /Russian/i;                   'Russo'
-      when /Greek/i;                     'Greco'
-      when /Ukranian/i;                  'Ucraino'
-      when /Turkish/i;                   'Turco'
-      when /Slovenian/i;                 'Sloveno'
-      when /Croatian/i;                  'Croato'
-      when /Slovak(?:ian)?/i;            'Slovacco'
-      when /Czech/i;                     'Ceco'
-      when /Bulgarian/i;                 'Bulgaro'
+      when /American/i       then 'Inglese USA'                         # tag depreciated, see iso 639-2
+      when /English/i        then 'Inglese'
+      when /French/i         then 'Francese'
+      when /German/i         then 'Tedesco'
+      when /Italian/i        then 'Italiano'
+      when /Spanish/i        then 'Spagnolo'
+      when /Portuguese Brazil|Brazilian(?: Portuguese)?/i
+                                  'Portoguese (Brasile)'                # tag depreciated, see iso 639-2
+      when /Portuguese/i     then 'Portoguese'
+      when /Swedish/i        then 'Svedese'
+      when /Danish/i         then 'Danese'
+      when /Finnish/i        then 'Finlandese'
+      when /Norwegian/i      then 'Norvegese'
+      when /Icelandic/i      then 'Islandese'
+      when /Dutch/i          then 'Olandese'
+      when /Estonian/i       then 'Estone'
+      when /Hungarian/i      then 'Ungherese'
+      when /Polish/i         then 'Polacco'
+      when /Romanian/i       then 'Romeno'
+      when /Russian/i        then 'Russo'
+      when /Greek/i          then 'Greco'
+      when /Ukranian/i       then 'Ucraino'
+      when /Turkish/i        then 'Turco'
+      when /Slovenian/i      then 'Sloveno'
+      when /Croatian/i       then 'Croato'
+      when /Slovak(?:ian)?/i then 'Slovacco'
+      when /Czech/i          then 'Ceco'
+      when /Bulgarian/i      then 'Bulgaro'
       else @trans_str
       end
     end
@@ -1561,34 +1562,34 @@ module SiSU_Translate
     end
     def language_list_translated
       case @trans_str
-      when /American/i;                  'Amerikanenglanti'                    # tag depreciated, see iso 639-2
-      when /English/i;                   'Englanti'
-      when /French/i;                    'Ranska'
-      when /German/i;                    'Saksa'
-      when /Italian/i;                   'Italia'
-      when /Spanish/i;                   'Espanja'
-      when /Portuguese Brazil|Brazilian(?: Portuguese)?/i;
-                                         'Brasilian portugali'                 # tag depreciated, see iso 639-2
-      when /Portuguese/i;                'Portugali'
-      when /Swedish/i;                   'Ruotsi'
-      when /Danish/i;                    'Tanska'
-      when /Finnish/i;                   'Suomi'
-      when /Norwegian/i;                 'Norja'
-      when /Icelandic/i;                 'Islanti'
-      when /Dutch/i;                     'Hollanti'
-      when /Estonian/i;                  'Viro'
-      when /Hungarian/i;                 'Unkari'
-      when /Polish/i;                    'Puola'
-      when /Romanian/i;                  'Romania'
-      when /Russian/i;                   'Venäjä'
-      when /Greek/i;                     'Kreikka'
-      when /Ukranian/i;                  'Ukraina'
-      when /Turkish/i;                   'Turkki'
-      when /Slovenian/i;                 'Slovenia'
-      when /Croatian/i;                  'Kroatia'
-      when /Slovak(?:ian)?/i;            'Slovakki'
-      when /Czech/i;                     'Tsekki'
-      when /Bulgarian/i;                 'Bulgaria'
+      when /American/i       then 'Amerikanenglanti'                    # tag depreciated, see iso 639-2
+      when /English/i        then 'Englanti'
+      when /French/i         then 'Ranska'
+      when /German/i         then 'Saksa'
+      when /Italian/i        then 'Italia'
+      when /Spanish/i        then 'Espanja'
+      when /Portuguese Brazil|Brazilian(?: Portuguese)?/i
+                                  'Brasilian portugali'                 # tag depreciated, see iso 639-2
+      when /Portuguese/i     then 'Portugali'
+      when /Swedish/i        then 'Ruotsi'
+      when /Danish/i         then 'Tanska'
+      when /Finnish/i        then 'Suomi'
+      when /Norwegian/i      then 'Norja'
+      when /Icelandic/i      then 'Islanti'
+      when /Dutch/i          then 'Hollanti'
+      when /Estonian/i       then 'Viro'
+      when /Hungarian/i      then 'Unkari'
+      when /Polish/i         then 'Puola'
+      when /Romanian/i       then 'Romania'
+      when /Russian/i        then 'Venäjä'
+      when /Greek/i          then 'Kreikka'
+      when /Ukranian/i       then 'Ukraina'
+      when /Turkish/i        then 'Turkki'
+      when /Slovenian/i      then 'Slovenia'
+      when /Croatian/i       then 'Kroatia'
+      when /Slovak(?:ian)?/i then 'Slovakki'
+      when /Czech/i          then 'Tsekki'
+      when /Bulgarian/i      then 'Bulgaria'
       else @trans_str
       end
     end
