@@ -73,35 +73,67 @@ module SiSU_Remote
       @remote=SiSU_Env::InfoRemote.new(opt)
     end
     def rsync
-      SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],'Remote placement ->',@put).dark_grey_title_hi unless @opt.act[:quiet][:set]==:on
+      SiSU_Screen::Ansi.new(
+        @opt.act[:color_state][:set],
+        'Remote placement ->',
+        @put
+      ).dark_grey_title_hi unless @opt.act[:quiet][:set]==:on
       @remote.rsync.document
     end
     def rsync_base
-      SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],'Remote placement ->','rsync').dark_grey_title_hi unless @opt.act[:quiet][:set]==:on
+      SiSU_Screen::Ansi.new(
+        @opt.act[:color_state][:set],
+        'Remote placement ->',
+        'rsync'
+      ).dark_grey_title_hi unless @opt.act[:quiet][:set]==:on
       @remote.rsync.site_base
     end
     def rsync_base_sync
-      SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],'Remote placement ->','rsync and sync').dark_grey_title_hi unless @opt.act[:quiet][:set]==:on
+      SiSU_Screen::Ansi.new(
+        @opt.act[:color_state][:set],
+        'Remote placement ->',
+        'rsync and sync'
+      ).dark_grey_title_hi unless @opt.act[:quiet][:set]==:on
       @remote.rsync.site_base_sync
     end
     def rsync_sitemaps
-      SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],'Remote placement sitemaps ->','rsync').dark_grey_title_hi unless @opt.act[:quiet][:set]==:on
+      SiSU_Screen::Ansi.new(
+        @opt.act[:color_state][:set],
+        'Remote placement sitemaps ->',
+        'rsync'
+      ).dark_grey_title_hi unless @opt.act[:quiet][:set]==:on
       @remote.rsync_sitemaps
     end
     def rsync_harvest
-      SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],'Remote placement metadata harvest ->','rsync_harvest').dark_grey_title_hi unless @opt.act[:quiet][:set]==:on
+      SiSU_Screen::Ansi.new(
+        @opt.act[:color_state][:set],
+        'Remote placement metadata harvest ->',
+        'rsync_harvest'
+      ).dark_grey_title_hi unless @opt.act[:quiet][:set]==:on
       @remote.rsync.site_harvest
     end
     def scp
-      SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],'Remote placement ->',@put).dark_grey_title_hi unless @opt.act[:quiet][:set]==:on
+      SiSU_Screen::Ansi.new(
+        @opt.act[:color_state][:set],
+        'Remote placement ->',
+        @put
+      ).dark_grey_title_hi unless @opt.act[:quiet][:set]==:on
       @remote.scp.document
     end
     def scp_base
-      SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],'Remote placement of base site ->','excluding images').dark_grey_title_hi unless @opt.act[:quiet][:set]==:on
+      SiSU_Screen::Ansi.new(
+        @opt.act[:color_state][:set],
+        'Remote placement of base site ->',
+        'excluding images'
+      ).dark_grey_title_hi unless @opt.act[:quiet][:set]==:on
       @remote.scp.site_base
     end
     def scp_base_all
-      SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],'Remote placement ->','complete').dark_grey_title_hi unless @opt.act[:quiet][:set]==:on
+      SiSU_Screen::Ansi.new(
+        @opt.act[:color_state][:set],
+        'Remote placement ->',
+        'complete'
+      ).dark_grey_title_hi unless @opt.act[:quiet][:set]==:on
       @remote.scp.site_base_all
     end
   end
@@ -109,7 +141,11 @@ module SiSU_Remote
     def initialize(opt,get_s)
       @opt,@get_s=opt,get_s
       @msg,@msgs='',nil
-      @tell=lambda { SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],@msg,"#{@msgs.inspect if @msgs}") }
+      @tell=lambda {
+        SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],
+        @msg,
+        "#{@msgs.inspect if @msgs}")
+      }
     end
     def fns
       begin
@@ -118,7 +154,7 @@ module SiSU_Remote
       rescue LoadError
         SiSU_Utils::CodeMarker.new(__LINE__,__FILE__,:fuchsia).error('open-uri or pp NOT FOUND (LoadError)')
       end
-      require_relative 'composite'                      # composite.rb
+      require_relative 'ao_composite'                   # ao_composite.rb
       @rgx_image=/(?:^|[^_\\])\{\s*(\S+?\.(?:png|jpg|gif))/
       threads=[]
       for requested_page in @get_s
