@@ -100,11 +100,20 @@ module SiSU_Rexml
             xmlfile=IO.readlines(@fnap,'').join
             begin
               @xmldoc=REXML::Document.new xmlfile
-              SiSU_Screen::Ansi.new(@md.opt.act[:color_state][:set],'invert','REXML',"XML document #{@fnap} loaded").colorize unless @md.opt.act[:quiet][:set]==:on
+              SiSU_Screen::Ansi.new(
+                @md.opt.act[:color_state][:set],
+                'invert',
+                'REXML',
+                "XML document #{@fnap} loaded"
+              ).colorize unless @md.opt.act[:quiet][:set]==:on
               if (@opt.act[:verbose][:set]==:on \
               || @opt.act[:verbose_plus][:set]==:on)
                 @xmldoc.elements.each(@e_head) do |e|
-                  SiSU_Screen::Ansi.new(@md.opt.act[:color_state][:set],'brown',e).colorize unless @md.opt.act[:quiet][:set]==:on
+                  SiSU_Screen::Ansi.new(
+                    @md.opt.act[:color_state][:set],
+                    'brown',
+                    e
+                  ).colorize unless @md.opt.act[:quiet][:set]==:on
                 end
               end
             rescue REXML::ParseException
@@ -112,7 +121,12 @@ module SiSU_Rexml
             end
           end
         else
-          SiSU_Screen::Ansi.new(@md.opt.act[:color_state][:set],'fuchsia',"File Not Found #{xmlfile}",'requested XML processing skipped').colorize unless @md.opt.act[:quiet][:set]==:on
+          SiSU_Screen::Ansi.new(
+            @md.opt.act[:color_state][:set],
+            'fuchsia',
+            "File Not Found #{xmlfile}",
+            'requested XML processing skipped'
+          ).colorize unless @md.opt.act[:quiet][:set]==:on
           exit
         end
       rescue
