@@ -207,20 +207,32 @@ module SiSU_TextRepresentation
         @t_o,@s=x,x.obj.dup
       end
       @env ||=SiSU_Env::InfoEnv.new(@md.fns)
-      @sha_ =((@env.digest.type =='sha256') ? true : false)
+      @sha_ = @env.digest(@md.opt).type
       begin
-        @sha_ ? (require 'digest/sha2') : (require 'digest/md5')
+        case @sha_
+        when :sha512
+          require 'digest/sha2'
+        when :sha256
+          require 'digest/sha2'
+        when :md5
+          require 'digest/md5'
+        end
       rescue LoadError
         SiSU_Utils::CodeMarker.new(__LINE__,__FILE__,:fuchsia).error((@sha_ ? 'digest/sha2' : 'digest/md5') + ' NOT FOUND')
       end
     end
     def digest(txt)
       d=nil
-      if @sha_
+      case @sha_
+      when :sha512
+        for hash_class in [ Digest::SHA512 ]
+          d=hash_class.hexdigest(txt)
+        end
+      when :sha256
         for hash_class in [ Digest::SHA256 ]
           d=hash_class.hexdigest(txt)
         end
-      else
+      when :md5
         for hash_class in [ Digest::MD5 ]
           d=hash_class.hexdigest(txt)
         end
@@ -267,7 +279,12 @@ module SiSU_TextRepresentation
              elsif FileTest.file?("#{@env.path.image_source_include}/#{i}")
                @env.path.image_source_include
              else
-               SiSU_Screen::Ansi.new(@md.opt.act[:color_state][:set],"ERROR - image:", %{"#{i}" missing}, "search locations: #{@env.path.image_source_include_local}, #{@env.path.image_source_include_remote} and #{@env.path.image_source_include}").error2 unless @md.opt.act[:quiet][:set]==:on
+               SiSU_Screen::Ansi.new(
+                 @md.opt.act[:color_state][:set],
+                 "ERROR - image:",
+                 %{"#{i}" missing},
+                 "search locations: #{@env.path.image_source_include_local}, #{@env.path.image_source_include_remote} and #{@env.path.image_source_include}"
+               ).error2 unless @md.opt.act[:quiet][:set]==:on
                nil
              end
              img_type = /\S+\.(png|jpg|gif)/.match(i)[1]
