@@ -297,6 +297,57 @@ module SiSU_Metadata
       end
       meta
     end
+    def metadata_alt
+      meta=[]
+      if @display_heading
+        @tag,@inf=%{<b><u>Document Metadata</u></b>},''
+        meta << self.meta_para
+      end
+      if defined? @md.title.main \
+      and @md.title.main=~/\S+/
+        @tag='title'
+        @inf=@md.title.main
+        meta << self.meta_para
+      end
+      if defined? @md.title.sub \
+      and @md.title.sub=~/\S+/
+        @tag='subtitle'
+        @inf=@md.title.sub
+        meta << self.meta_para
+      end
+      if defined? @md.creator.author \
+      and @md.creator.author=~/\S+/
+        @tag='author'
+        @inf=@md.creator.author
+        meta << self.meta_para
+      end
+      if defined? @md.creator.translator \
+      and @md.creator.translator=~/\S+/
+        @tag='translator'
+        @inf=@md.creator.translator
+        meta << self.meta_para
+      end
+      if defined? @md.creator.illustrator \
+      and @md.creator.illustrator=~/\S+/
+        @tag='illustrator'
+        @inf=@md.creator.illustrator
+        meta << self.meta_para
+      end
+      if defined? @md.rights.copyright.text \
+      and @md.rights.copyright.text=~/\S+/
+        @tag='copyright'
+        @inf=@md.rights.copyright.text # year & holder
+        @inf=@inf.gsub(/(?:Copyright|\(C\))+\s*/,'')
+        meta << self.meta_para
+      end
+      if defined? @md.rights.license \
+      and @md.rights.license=~/\S+/
+        @tag='license'
+        @inf=@md.rights.license
+        meta << self.meta_para
+      end
+      meta
+    end
     def processing_tags
       def make
         def language
@@ -735,6 +786,13 @@ module SiSU_Metadata
         end
         @s
       end
+      def br
+        if @s \
+        and @s.is_a?(String)
+          @s=@s.gsub(/(?:#{Mx[:br_line]}|\\\\)+/,'<br />')
+        end
+        @s
+      end
       def utf8
         if @s \
         and @s.is_a?(String)
@@ -749,9 +807,25 @@ module SiSU_Metadata
       end
       self
     end
+    def xml_docbook
+      def meta_para
+        inf_xml=char_enc(@inf).utf8
+        inf_xml=char_enc(inf_xml).br
+        <<WOK
+#{Ax[:tab]}<#{@tag}>
+#{Ax[:tab]*2}#{inf_xml}
+#{Ax[:tab]}</#{@tag}>
+WOK
+      end
+      def metadata
+        SiSU_Metadata::Summary.new(@md).metadata_alt
+      end
+      self
+    end
     def xml_sax
       def meta_para
         inf_xml=char_enc(@inf).utf8
+        inf_xml=char_enc(inf_xml).br
         <<WOK
 <metadata>
 #{Ax[:tab]}<meta>#{@tag.capitalize}:</meta>
@@ -769,6 +843,7 @@ WOK
     def xml_dom
       def meta_para
         inf_xml=char_enc(@inf).utf8
+        inf_xml=char_enc(inf_xml).br
         <<WOK
 #{Ax[:tab]}<header>
 #{Ax[:tab]*2}<meta>#{@tag.capitalize}:</meta>
@@ -786,6 +861,7 @@ WOK
     def xhtml_scroll
       def meta_para
         inf_xml=char_enc(@inf).utf8
+        inf_xml=char_enc(inf_xml).br
         <<WOK
 #{Ax[:tab]}<metadata>
 #{Ax[:tab]}<meta>#{@tag.capitalize}:</meta>
@@ -805,6 +881,7 @@ WOK
       def meta_para
         inf_xml=char_enc(@inf).amp
         inf_xml=char_enc(inf_xml).utf8
+        inf_xml=char_enc(inf_xml).br
         %{<p class="norm">
   <b>#{@tag}</b>: #{inf_xml}
 </p>}
@@ -886,6 +963,8 @@ WOK
     def initialize(md)
       @md=md
       @br="\\\\\n"
+      @make=SiSU_Env::ProcessingSettings.new(md)
+      @o_str ||=SiSU_Env::ProcessingSettings.new(md).output_dir_structure
     end
     def meta_para(tag,inf,sc=true)
       inf=((inf.is_a?(String) && sc) ? spec_char(inf) : inf)
@@ -906,9 +985,12 @@ WOK
       l=SiSU_Env::StandardiseLanguage.new(@md.opt.lng).language
       language=l[:n]
       tr=SiSU_Translate::Source.new(@md,language)
-      tag="Document Manifest @"
-      inf="#{@br}#{@md.file.output_path.manifest.url}/#{@md.file.base_filename.manifest}"
-      meta << meta_para(tag,inf)
+      if @make.build.links_to_manifest? \
+      and not @o_str.dump_or_redirect?
+        tag="Document Manifest @"
+        inf="#{@br}#{@md.file.output_path.manifest.url}/#{@md.file.base_filename.manifest}"
+        meta << meta_para(tag,inf)
+      end
       if defined? @md.title.full \
       and @md.title.full=~/\S+/
         tag,inf=tr.full_title,@md.title.full
