@@ -92,7 +92,11 @@ module SiSU_Sitemaps
           @sitemap_idx_fn='sitemapindex.xml'
           @env=SiSU_Env::InfoEnv.new
           output_idx(sitemap_index)
-          SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],"sitemap index:","#{@env.path.output}/#{@sitemap_idx_fn}").result unless @opt.act[:quiet][:set]==:on
+          SiSU_Screen::Ansi.new(
+            @opt.act[:color_state][:set],
+            'sitemap index:',
+            "#{@env.path.output}/#{@sitemap_idx_fn}"
+          ).result unless @opt.act[:quiet][:set]==:on
         end
       rescue
         SiSU_Errors::Rescued.new($!,$@,@opt.cmd,@opt.fns).location do
@@ -104,7 +108,10 @@ module SiSU_Sitemaps
     def make_file(path,filename)
       (File.writable?("#{path}/.")) \
       ? (File.new("#{path}/#{filename}",'w+'))
-      : (SiSU_Screen::Ansi.new('',"is the file or directory writable?, could not create #{filename}").warn)
+      : (SiSU_Screen::Ansi.new(
+           '',
+           "is the file or directory writable?, could not create #{filename}"
+         ).warn)
     end
     def output_map(sitemap)
       path=@md.file.output_path.sitemaps.dir
