@@ -75,11 +75,20 @@ module SiSU_Markup
         (@opt.act[:verbose][:set]==:on \
         || @opt.act[:verbose_plus][:set]==:on \
         || @opt.act[:maintenance][:set]==:on) \
-        ? SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],'Share document markup text source',@opt.fns).cyan_hi_blue
-        : SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],'Share document markup text source',@opt.fns).cyan_title_hi
+        ? SiSU_Screen::Ansi.new(
+            @opt.act[:color_state][:set],
+            'Share document markup text source',
+            @opt.fns
+          ).cyan_hi_blue
+        : SiSU_Screen::Ansi.new(
+            @opt.act[:color_state][:set],
+            'Share document markup text source',
+            @opt.fns
+          ).cyan_title_hi
       end
       if FileTest.directory?(@path_pod[:fnb])
-        FileUtils::mkdir_p(@file.output_path.src.dir) unless FileTest.directory?(@file.output_path.src.dir)
+        FileUtils::mkdir_p(@file.output_path.src.dir) \
+          unless FileTest.directory?(@file.output_path.src.dir)
         v=(@opt.act[:maintenance][:set]==:on) \
         ? 'v' : ''
         system(%{
@@ -94,7 +103,10 @@ module SiSU_Markup
         if (@opt.act[:verbose][:set]==:on \
         || @opt.act[:verbose_plus][:set]==:on \
         || @opt.act[:maintenance][:set]==:on)
-          SiSU_Screen::Ansi.new('',"#{@opt.fno} not available").blue_tab
+          SiSU_Screen::Ansi.new(
+            '',
+            "#{@opt.fno} not available"
+          ).blue_tab
         end
       end
     end
