@@ -75,13 +75,22 @@ module SiSU_Doc
         (@opt.act[:verbose][:set]==:on \
         || @opt.act[:verbose_plus][:set]==:on \
         || @opt.act[:maintenance][:set]==:on) \
-        ? SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],'Assemble source for sisu document',"#{@opt.fns} -> file://#{pthinfo}").cyan_hi_blue
-        : SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],'Assemble source for sisu document',pthinfo).cyan_title_hi
+        ? SiSU_Screen::Ansi.new(
+            @opt.act[:color_state][:set],
+            'Assemble source for sisu document',
+            "#{@opt.fns} -> file://#{pthinfo}"
+          ).cyan_hi_blue
+        : SiSU_Screen::Ansi.new(
+            @opt.act[:color_state][:set],
+            'Assemble source for sisu document',
+            pthinfo
+          ).cyan_title_hi
       end
     end
     def sisupod_tar_xz
       begin
-        FileUtils::mkdir_p(@file.output_path.sisupod.dir) unless FileTest.directory?(@file.output_path.sisupod.dir)
+        FileUtils::mkdir_p(@file.output_path.sisupod.dir) \
+          unless FileTest.directory?(@file.output_path.sisupod.dir)
         tree=((@opt.act[:verbose][:set]==:on \
         || @opt.act[:verbose_plus][:set]==:on \
         || @opt.act[:maintenance][:set]==:on) \
