@@ -62,8 +62,8 @@
 =end
 module SiSU_TextUtils
   class Wrap
-    def initialize(para='',n_char_max=76,n_indent=0,n_hang=nil)
-      @para,@n_char_max,@n_indent=para,n_char_max,n_indent
+    def initialize(para='',n_char_max=76,n_indent=0,n_hang=nil,post='')
+      @para,@n_char_max,@n_indent,@post,=para,n_char_max,n_indent,post
       @n_char_max_extend = n_char_max
       @n_hang=n_hang ? n_hang : @n_indent
     end
@@ -110,7 +110,10 @@ module SiSU_TextUtils
         end
         @oldword=word if word =~/\S+/
       end
-      spaces_hang + out.join(spaces_indent)
+      post=(@post.empty?) \
+      ? ''
+      : "\n" + (' '*@n_indent) +@post
+      spaces_hang + out.join(spaces_indent) + post
     end
     def line_wrap_indent1
       @n_indent,@n_hang=2,2
