@@ -123,7 +123,9 @@ module SiSU_Utils
       h
     end
     def message(msg='')
-      @message=(msg.empty?) ? '' : " #{msg}"
+      @message=(msg.nil? || msg.empty?) \
+      ? ''
+      : ' ' + msg
     end
     def set(v=nil,x=nil)
       v=var(v,x)
@@ -133,6 +135,18 @@ module SiSU_Utils
     def mark(v=nil,x=nil)
       puts set(v,x)
     end
+    def ok(v=nil,x=nil)
+      if (v.is_a?(Symbol) \
+      and x.is_a?(String))
+        x= '*OK* ' + x
+      elsif v.is_a?(String)
+        v='*OK* ' + v
+        x=nil
+      else
+        v,x='*OK*',nil
+      end
+      puts set(v,x)
+    end
     def warn(v=nil,x=nil)
       if (v.is_a?(Symbol) \
       and x.is_a?(String))
@@ -143,7 +157,7 @@ module SiSU_Utils
       else
         v,x='*WARN*',nil
       end
-      STDERR.puts set(v,x)
+      puts set(v,x)
     end
     def error(v=nil,x=nil)
       if (v.is_a?(Symbol) \
@@ -162,8 +176,22 @@ module SiSU_Utils
     def initialize(dir=Dir.pwd)
       @dir=dir
     end
-    def base_markup
-      (/(\S+?)(?:\/(?:#{Px[:lng_lst_rgx]}))?$/).match(Dir.pwd)[1]
+    def base_markup(call_path=nil)
+      call_path = call_path \
+      ? call_path \
+      : Dir.pwd
+      (/(\S+?)(?:\/(?:#{Px[:lng_lst_rgx]}))?$/).match(call_path)[1]
+    end
+    def base_markup_stub
+      m=/.+\/(?:src\/)?(\S+)/im
+      base_markup[m,1]
+    end
+    def image_src
+      if base_markup =~/sisupod\/doc[\/]?$/
+        base_markup.gsub(/\/doc[\/]?$/,'/image')
+      elsif FileTest.directory?("#{base_markup}/_sisu/image")
+        "#{base_markup}/_sisu/image"
+      end
     end
     def bmd
       base_markup
@@ -183,6 +211,7 @@ SiSU_Utils::CodeMarker.new(__LINE__,__FILE__,:green).mark({ m: %{
 SiSU_Utils::CodeMarker.new(__LINE__,__FILE__,:green).mark(%{ code: #{@@flag['code']}, open --> "#{t_o}" }) \
 if t_o=~/^```/m
 SiSU_Utils::CodeMarker.new(__LINE__,__FILE__,:green).mark("open -->")
+SiSU_Utils::CodeMarker.new(__LINE__,__FILE__,:fuchsia).mark("open -->")
 SiSU_Utils::CodeMarker.new(__LINE__,__FILE__).mark("open -->",:green)
 SiSU_Utils::CodeMarker.new(__LINE__,__FILE__).mark(:green,"open -->")
 SiSU_Utils::CodeMarker.new(__LINE__,__FILE__).mark("open -->")
