@@ -86,10 +86,18 @@ module SiSU_Wikispeak
         || @opt.act[:maintenance][:set]==:on) \
         ? "#{@env.program.text_editor} #{path}/#{@md.fnb}/#{@md.fn[:wiki]}"
         : ''
-        SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],'Wikispeak',tool).green_hi_blue unless @opt.act[:quiet][:set]==:on
+        SiSU_Screen::Ansi.new(
+          @opt.act[:color_state][:set],
+          'Wikispeak',
+          tool
+        ).green_hi_blue unless @opt.act[:quiet][:set]==:on
         if (@opt.act[:verbose_plus][:set]==:on \
         || @opt.act[:maintenance][:set]==:on)
-          SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],@opt.fns,"#{@env.path.output_tell}/#{@md.fnb}/#{@md.fn[:wiki]}").flow
+          SiSU_Screen::Ansi.new(
+            @opt.act[:color_state][:set],
+            @opt.fns,
+            "#{@env.path.output_tell}/#{@md.fnb}/#{@md.fn[:wiki]}"
+          ).flow
         end
         @ao_array=SiSU_AO::Source.new(@opt).get # ao file drawn here
         SiSU_Wikispeak::Source::Scroll.new(@ao_array,@md).songsheet
