@@ -95,11 +95,23 @@ module SiSU_XHTML
           (@opt.act[:verbose][:set]==:on \
           || @opt.act[:verbose_plus][:set]==:on \
           || @opt.act[:maintenance][:set]==:on) \
-          ? SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],'XHTML',tool).green_hi_blue
-          : SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],'XHTML',tool).green_title_hi
+          ? SiSU_Screen::Ansi.new(
+              @opt.act[:color_state][:set],
+              'XHTML',
+              tool
+            ).green_hi_blue
+          : SiSU_Screen::Ansi.new(
+              @opt.act[:color_state][:set],
+              'XHTML',
+              tool
+            ).green_title_hi
           if (@opt.act[:verbose_plus][:set]==:on \
           || @opt.act[:maintenance][:set]==:on)
-            SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],@opt.fns,"/#{@md.file.output_path.xhtml.dir}/#{@md.file.base_filename.xhtml}").flow
+            SiSU_Screen::Ansi.new(
+              @opt.act[:color_state][:set],
+              @opt.fns,
+              "/#{@md.file.output_path.xhtml.dir}/#{@md.file.base_filename.xhtml}"
+            ).flow
           end
         end
         SiSU_XHTML::Source::Songsheet.new(@particulars).song
@@ -108,7 +120,8 @@ module SiSU_XHTML
           __LINE__.to_s + ':' + __FILE__
         end
       ensure
-        SiSU_Env::CreateSite.new(@opt.cmd).cp_css
+        SiSU_Env::CreateSite.new(@opt).cp_css
+        Dir.chdir(@opt.f_pth[:pth])
       end
     end
     private
@@ -428,8 +441,18 @@ WOK
           if (@md.opt.act[:verbose_plus][:set]==:on \
           || @md.opt.act[:maintenance][:set]==:on)
             unless @md.opt.act[:quiet][:set]==:on
-              SiSU_Screen::Ansi.new(@md.opt.act[:color_state][:set],'invert','Using XML Tidy','check document structure').colorize
-              tell=SiSU_Screen::Ansi.new(@md.opt.act[:color_state][:set],'invert','','')
+              SiSU_Screen::Ansi.new(
+                @md.opt.act[:color_state][:set],
+                'invert',
+                'Using XML Tidy',
+                'check document structure'
+              ).colorize
+              tell=SiSU_Screen::Ansi.new(
+                     @md.opt.act[:color_state][:set],
+                     'invert',
+                     '',
+                     ''
+                   )
               tell.grey_open
             end
             tidyfile='/dev/null' #don't want one or screen output, check for alternative flags
