@@ -84,7 +84,11 @@ module SiSU_XHTML_EPUB2
       @particulars=SiSU_Particulars::CombinedSingleton.instance.get_all(opt)
     end
     def read
-      songsheet
+      begin
+        songsheet
+      ensure
+        Dir.chdir(@opt.f_pth[:pth])
+      end
     end
     def songsheet
       begin
@@ -100,11 +104,23 @@ module SiSU_XHTML_EPUB2
           (@opt.act[:verbose][:set]==:on \
           || @opt.act[:verbose_plus][:set]==:on \
           || @opt.act[:maintenance][:set]==:on) \
-          ? SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],'EPUB',tool).green_hi_blue
-          : SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],'EPUB',tool).green_title_hi
+          ? SiSU_Screen::Ansi.new(
+              @opt.act[:color_state][:set],
+              'EPUB',
+              tool
+            ).green_hi_blue
+          : SiSU_Screen::Ansi.new(
+              @opt.act[:color_state][:set],
+              'EPUB',
+              tool
+            ).green_title_hi
           if (@opt.act[:verbose_plus][:set]==:on \
           || @opt.act[:maintenance][:set]==:on)
-            SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],@opt.fns,"#{@md.file.output_path.epub.dir}/#{@md.file.base_filename.epub}").flow
+            SiSU_Screen::Ansi.new(
+              @opt.act[:color_state][:set],
+              @opt.fns,
+              "#{@md.file.output_path.epub.dir}/#{@md.file.base_filename.epub}"
+            ).flow
           end
         end
         @env.processing_path.epub_bld #(@md)
@@ -206,7 +222,10 @@ module SiSU_XHTML_EPUB2
         if (@md.opt.act[:verbose][:set]==:on \
         || @md.opt.act[:verbose_plus][:set]==:on \
         || @md.opt.act[:maintenance][:set]==:on)
-          SiSU_Screen::Ansi.new(@md.opt.act[:color_state][:set],'Toc').txt_grey
+          SiSU_Screen::Ansi.new(
+            @md.opt.act[:color_state][:set],
+            'Toc'
+          ).txt_grey
         end
         toc=nil
         @@firstseg=nil
@@ -587,7 +606,10 @@ module SiSU_XHTML_EPUB2
         if (@md.opt.act[:verbose][:set]==:on \
         || @md.opt.act[:verbose_plus][:set]==:on \
         || @md.opt.act[:maintenance][:set]==:on)
-          SiSU_Screen::Ansi.new(@md.opt.act[:color_state][:set],'Scroll & Segtoc').txt_grey
+          SiSU_Screen::Ansi.new(
+            @md.opt.act[:color_state][:set],
+            'Scroll & Segtoc'
+          ).txt_grey
         end
         format_head_toc=SiSU_XHTML_EPUB2_Format::HeadToc.new(@md)
         dochead=format_head_toc.head
