@@ -83,10 +83,16 @@ module SiSU_XHTML_EPUB2_Concordance
           if @md.wc_words < wordmax
             SiSU_XHTML_EPUB2_Concordance::Source::Words.new(@particulars).songsheet
           else
-            SiSU_Screen::Ansi.new(@md.opt.act[:color_state][:set],"*WARN* concordance skipped, large document has over #{wordmax} words (#{@md.wc_words})").warn unless @md.opt.act[:quiet][:set]==:on
+            SiSU_Screen::Ansi.new(
+              @md.opt.act[:color_state][:set],
+              "*WARN* concordance skipped, large document has over #{wordmax} words (#{@md.wc_words})"
+            ).warn unless @md.opt.act[:quiet][:set]==:on
           end
         else
-          SiSU_Screen::Ansi.new(@md.opt.act[:color_state][:set],"*WARN* wc (word count) is off, concordance will be processed for all files including those over the max set size of: #{wordmax} words").warn unless @md.opt.act[:quiet][:set]==:on
+          SiSU_Screen::Ansi.new(
+            @md.opt.act[:color_state][:set],
+            "*WARN* wc (word count) is off, concordance will be processed for all files including those over the max set size of: #{wordmax} words"
+          ).warn unless @md.opt.act[:quiet][:set]==:on
           SiSU_XHTML_EPUB2_Concordance::Source::Words.new(@particulars).songsheet
         end
       rescue
