@@ -80,6 +80,7 @@ module SiSU_XHTML_EPUB2_Seg
           filename_seg << @seg[:heading_endnotes] << @seg[:headings] << %{\n<div class="content">\n} << @seg[:endnote_all] << '</div>'
         elsif @type=='idx'
           @seg[:headings]=[]
+          txt_obj={ txt: 'Index', ocn_display: ''}
           format_seg=SiSU_XHTML_EPUB2_Format::FormatSeg.new(@md,txt_obj)
           @seg[:headings] << format_seg.title_heading1
           filename_seg << @seg[:heading_idx] << @seg[:headings] << %{\n<div class="content">\n} << @seg[:idx] << '</div>'
@@ -177,7 +178,10 @@ WOK
       if (@md.opt.act[:verbose][:set]==:on \
       || @md.opt.act[:verbose_plus][:set]==:on \
       || @md.opt.act[:maintenance][:set]==:on)
-        SiSU_Screen::Ansi.new(@md.opt.act[:color_state][:set],@@seg_name.length)
+        SiSU_Screen::Ansi.new(
+          @md.opt.act[:color_state][:set],
+          @@seg_name.length
+        )
       end
       SiSU_Particulars::CombinedSingleton.instance.get_map_nametags(@md).nametags_map #p map_nametags
       data.each do |dob|
