@@ -126,7 +126,10 @@ module SiSU_XHTML_EPUB2_Tune
         if (@md.opt.act[:verbose][:set]==:on \
         || @md.opt.act[:verbose_plus][:set]==:on \
         || @md.opt.act[:maintenance][:set]==:on)
-          SiSU_Screen::Ansi.new(@md.opt.act[:color_state][:set],'Tune').txt_grey
+          SiSU_Screen::Ansi.new(
+            @md.opt.act[:color_state][:set],
+            'Tune'
+          ).txt_grey
         end
         data=SiSU_XHTML_EPUB2_Tune::Tune.new(@data,@md).amp_angle_brackets
         data=SiSU_XHTML_EPUB2_Tune::Tune.new(data,@md).endnotes_html
