@@ -86,6 +86,7 @@ module SiSU_XML_Fictionbook
           __LINE__.to_s + ':' + __FILE__
         end
       ensure
+        Dir.chdir(@opt.f_pth[:pth])
       end
     end
     private
@@ -99,11 +100,23 @@ module SiSU_XML_Fictionbook
         (@opt.act[:verbose][:set]==:on \
         || @opt.act[:verbose_plus][:set]==:on \
         || @opt.act[:maintenance][:set]==:on) \
-        ? SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],'Fictionbook',tool).green_hi_blue
-        : SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],'Fictionbook',tool).green_title_hi
+        ? SiSU_Screen::Ansi.new(
+            @opt.act[:color_state][:set],
+            'Fictionbook',
+            tool
+          ).green_hi_blue
+        : SiSU_Screen::Ansi.new(
+            @opt.act[:color_state][:set],
+            'Fictionbook',
+            tool
+          ).green_title_hi
         if (@opt.act[:verbose_plus][:set]==:on \
         || @opt.act[:maintenance][:set]==:on)
-          SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],@opt.fns,"#{@md.file.output_path.xml_fictionbook.dir}/#{@md.file.base_filename.xml_fictionbook}").flow
+          SiSU_Screen::Ansi.new(
+            @opt.act[:color_state][:set],
+            @opt.fns,
+            "#{@md.file.output_path.xml_fictionbook.dir}/#{@md.file.base_filename.xml_fictionbook}"
+          ).flow
         end
       end
     end
@@ -126,8 +139,8 @@ module SiSU_XML_Fictionbook
         data=markup_text(data)
         structure_build_collapsed(data,endnotes,images_base64)
       end
-      def space
-        '  '
+      def spaces
+        Ax[:spaces]
       end
       def tags
         # collapsed -->
@@ -277,8 +290,8 @@ module SiSU_XML_Fictionbook
         WOK
       end
       def output(o,comment='')
-         puts o.lc == 0..6 \
-         ? "#{space*o.lc}<#{o.lc}>[#{o.ocn}] #{o.ln} #{o.obj}</#{o.lc}>#{comment}"
+         puts o.lc == (0..6) \
+         ? "#{spaces*o.lc}<#{o.lc}>[#{o.ocn}] #{o.ln} #{o.obj}</#{o.lc}>#{comment}"
          : "<#{o.lc}>[#{o.ocn}] #{o.ln} #{o.obj}</#{o.lc}>#{comment}"
       end
       def structure_collapsed(data)
@@ -304,17 +317,22 @@ module SiSU_XML_Fictionbook
         doc_position=:head
         filename_fictionbook.puts head
         data.each_with_index do |o,i|
-          ocn=(defined? o.ocn and not o.ocn.nil?) ? "\n#{Dx[:ocn_o]}#{o.ocn}#{Dx[:ocn_c]}" : ''
+          ocn=if @make.build.ocn?
+            (defined? o.ocn and not o.ocn.nil?) \
+            ? "\n#{Dx[:ocn_o]}#{o.ocn}#{Dx[:ocn_c]}"
+            : ''
+          else ''
+          end
           if  o.is ==:heading
             unless doc_position==:head
               filename_fictionbook.puts structure_build_tag_close(o.lc,h)
             end
             doc_position=:body_and_tail
-            filename_fictionbook.puts %{#{space*o.lc}<#{tags.fictionbook[o.lc]}>
-#{space*o.lc}<title>
+            filename_fictionbook.puts %{#{spaces*o.lc}<#{tags.fictionbook[o.lc]}>
+#{spaces*o.lc}<title>
 }
             filename_fictionbook.puts SiSU_TextUtils::Wrap.new("<p>#{o.obj}#{ocn}</p>",80,(o.lc*2+2)).line_wrap
-            filename_fictionbook.puts %{#{space*o.lc}</title>}
+            filename_fictionbook.puts %{#{spaces*o.lc}</title>}
             h=o.lc
           elsif  o.is ==:heading_insert \
           and o.obj =~/Endnotes/ \
@@ -333,40 +351,40 @@ module SiSU_XML_Fictionbook
         x=[]
         case h
         when 0
-          x << "#{space*0}</#{tags.fictionbook[0]}>" if (lc <= 0)
+          x << "#{spaces*0}</#{tags.fictionbook[0]}>" if (lc <= 0)
         when 1
-          x << "#{space*1}</#{tags.fictionbook[1]}>" if (lc <= 1)
-          x << "#{space*0}</#{tags.fictionbook[0]}>" if (lc <= 0)
+          x << "#{spaces*1}</#{tags.fictionbook[1]}>" if (lc <= 1)
+          x << "#{spaces*0}</#{tags.fictionbook[0]}>" if (lc <= 0)
         when 2
-          x << "#{space*2}</#{tags.fictionbook[2]}>" if (lc <= 2)
-          x << "#{space*1}</#{tags.fictionbook[1]}>" if (lc <= 1)
-          x << "#{space*0}</#{tags.fictionbook[0]}>" if (lc <= 0)
+          x << "#{spaces*2}</#{tags.fictionbook[2]}>" if (lc <= 2)
+          x << "#{spaces*1}</#{tags.fictionbook[1]}>" if (lc <= 1)
+          x << "#{spaces*0}</#{tags.fictionbook[0]}>" if (lc <= 0)
         when 3
-          x << "#{space*3}</#{tags.fictionbook[3]}>" if (lc <= 3)
-          x << "#{space*2}</#{tags.fictionbook[2]}>" if (lc <= 2)
-          x << "#{space*1}</#{tags.fictionbook[1]}>" if (lc <= 1)
-          x << "#{space*0}</#{tags.fictionbook[0]}>" if (lc <= 0)
+          x << "#{spaces*3}</#{tags.fictionbook[3]}>" if (lc <= 3)
+          x << "#{spaces*2}</#{tags.fictionbook[2]}>" if (lc <= 2)
+          x << "#{spaces*1}</#{tags.fictionbook[1]}>" if (lc <= 1)
+          x << "#{spaces*0}</#{tags.fictionbook[0]}>" if (lc <= 0)
         when 4
-          x << "#{space*4}</#{tags.fictionbook[4]}>" if (lc <= 4)
-          x << "#{space*3}</#{tags.fictionbook[3]}>" if (lc <= 3)
-          x << "#{space*2}</#{tags.fictionbook[2]}>" if (lc <= 2)
-          x << "#{space*1}</#{tags.fictionbook[1]}>" if (lc <= 1)
-          x << "#{space*0}</#{tags.fictionbook[0]}>" if (lc <= 0)
+          x << "#{spaces*4}</#{tags.fictionbook[4]}>" if (lc <= 4)
+          x << "#{spaces*3}</#{tags.fictionbook[3]}>" if (lc <= 3)
+          x << "#{spaces*2}</#{tags.fictionbook[2]}>" if (lc <= 2)
+          x << "#{spaces*1}</#{tags.fictionbook[1]}>" if (lc <= 1)
+          x << "#{spaces*0}</#{tags.fictionbook[0]}>" if (lc <= 0)
         when 5
-          x << "#{space*5}</#{tags.fictionbook[5]}>" if (lc <= 5)
-          x << "#{space*4}</#{tags.fictionbook[4]}>" if (lc <= 4)
-          x << "#{space*3}</#{tags.fictionbook[3]}>" if (lc <= 3)
-          x << "#{space*2}</#{tags.fictionbook[2]}>" if (lc <= 2)
-          x << "#{space*1}</#{tags.fictionbook[1]}>" if (lc <= 1)
-          x << "#{space*0}</#{tags.fictionbook[0]}>" if (lc <= 0)
+          x << "#{spaces*5}</#{tags.fictionbook[5]}>" if (lc <= 5)
+          x << "#{spaces*4}</#{tags.fictionbook[4]}>" if (lc <= 4)
+          x << "#{spaces*3}</#{tags.fictionbook[3]}>" if (lc <= 3)
+          x << "#{spaces*2}</#{tags.fictionbook[2]}>" if (lc <= 2)
+          x << "#{spaces*1}</#{tags.fictionbook[1]}>" if (lc <= 1)
+          x << "#{spaces*0}</#{tags.fictionbook[0]}>" if (lc <= 0)
         when 6
-          x << "#{space*6}</#{tags.fictionbook[6]}>" if (lc <= 6)
-          x << "#{space*5}</#{tags.fictionbook[5]}>" if (lc <= 5)
-          x << "#{space*4}</#{tags.fictionbook[4]}>" if (lc <= 4)
-          x << "#{space*3}</#{tags.fictionbook[3]}>" if (lc <= 3)
-          x << "#{space*2}</#{tags.fictionbook[2]}>" if (lc <= 2)
-          x << "#{space*1}</#{tags.fictionbook[1]}>" if (lc <= 1)
-          x << "#{space*0}</#{tags.fictionbook[0]}>" if (lc <= 0)
+          x << "#{spaces*6}</#{tags.fictionbook[6]}>" if (lc <= 6)
+          x << "#{spaces*5}</#{tags.fictionbook[5]}>" if (lc <= 5)
+          x << "#{spaces*4}</#{tags.fictionbook[4]}>" if (lc <= 4)
+          x << "#{spaces*3}</#{tags.fictionbook[3]}>" if (lc <= 3)
+          x << "#{spaces*2}</#{tags.fictionbook[2]}>" if (lc <= 2)
+          x << "#{spaces*1}</#{tags.fictionbook[1]}>" if (lc <= 1)
+          x << "#{spaces*0}</#{tags.fictionbook[0]}>" if (lc <= 0)
         end
         x.join("\n")
       end
