@@ -73,13 +73,20 @@ module SiSU_Zap
       z=SiSU_Env::CleanOutput.new(@opt)
       if SiSU_Env::InfoSettings.new.permission?('zap')
         unless @opt.act[:quiet][:set]==:on
-          tell=SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],"Clean files related to processing #{@opt.cmd} ->","#{@opt.fns} -> #{zap_path}")
+          tell=SiSU_Screen::Ansi.new(
+            @opt.act[:color_state][:set],
+            "Clean files related to processing #{@opt.cmd} ->",
+            "#{@opt.fns} -> #{zap_path}"
+          )
           tell.warn
         end
         z.zap.remove_output
       else
         unless @opt.act[:quiet][:set]==:on
-          tell=SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],'use of -Z (zap) has not enabled in sisurc.yml')
+          tell=SiSU_Screen::Ansi.new(
+            @opt.act[:color_state][:set],
+            'use of -Z (zap) has not enabled in sisurc.yml'
+          )
           tell.warn
         end
       end
