@@ -69,8 +69,11 @@ module SiSU_DbColumns
       @md=md
       @db=SiSU_Env::InfoDb.new #watch
       @lang ||=SiSU_i18n::Languages.new
-      if defined? md.opt.mod \
-      and md.opt.mod.inspect=~/import|update/ \
+      if defined? md.opt.act \
+      and ((md.opt.act[:psql_import][:set]==:on \
+      || md.opt.act[:psql_update][:set]==:on) \
+      or (md.opt.act[:sqlite_import][:set]==:on \
+      || md.opt.act[:sqlite_update][:set]==:on)) \
       and FileTest.exist?(md.fns)
         txt_arr=IO.readlines(md.fns,'')
         src=txt_arr.join("\n")
@@ -1843,7 +1846,7 @@ module SiSU_DbColumns
       end
       def src_fingerprint
         def name
-          'src_fingerprint' #hash/digest, sha256 or md5
+          'src_fingerprint' #hash/digest, sha512, sha256 or md5
         end
         def create_column
           "#{name}                VARCHAR(#{Db[:col_digest]}) NULL,"
@@ -1851,7 +1854,7 @@ module SiSU_DbColumns
         end
         def column_comment
           %{COMMENT ON COLUMN metadata_and_text.#{name}
-            IS 'sisu markup source text fingerprint, hash digest sha256 (or md5)';}
+            IS 'sisu markup source text fingerprint, hash digest sha512, sha256 or md5';}
         end
         def tuple
           if defined? @md.dgst \
@@ -1920,7 +1923,10 @@ module SiSU_DbColumns
            IS 'sisu markup source text (if shared)';}
         end
         def tuple
-          if @md.opt.mod.inspect=~/import|update/ \
+          if ((@md.opt.act[:psql_import][:set]==:on \
+          || @md.opt.act[:psql_update][:set]==:on) \
+          or (@md.opt.act[:sqlite_import][:set]==:on \
+          || @md.opt.act[:sqlite_update][:set]==:on)) \
           and FileTest.exist?(@md.fns)
             ["#{name}, ","'#{@sisutxt}', "]
           else ['','']
@@ -1944,7 +1950,10 @@ module SiSU_DbColumns
             IS 'document full text clean, searchable';}
         end
         def tuple
-          if @md.opt.mod.inspect=~/import|update/ \
+          if ((@md.opt.act[:psql_import][:set]==:on \
+          || @md.opt.act[:psql_update][:set]==:on) \
+          or (@md.opt.act[:sqlite_import][:set]==:on \
+          || @md.opt.act[:sqlite_update][:set]==:on)) \
           and  FileTest.exist?(@md.fns)
             ["#{name}, ","'#{@fulltext}', "]
           else ['','']
