@@ -68,7 +68,7 @@ module SiSU_HTML_Seg
   class Output
     def initialize(md,outputfile,seg,minitoc,type='')
       @md,@output_seg_file,@seg,@minitoc,@type=md,outputfile,seg,minitoc,type
-      @title_banner_=SiSU_Env::CreateSite.new(@md.opt.cmd).html_seg_title_banner?
+      @title_banner_=SiSU_Env::CreateSite.new(@md.opt).html_seg_title_banner?
       @file=SiSU_Env::FileOp.new(@md)
       @make=SiSU_Env::ProcessingSettings.new(@md)
       @cl=(@make.build.html_minitoc?) \
@@ -166,7 +166,7 @@ module SiSU_HTML_Seg
       else @cl='content'
       end
       if @md
-        @title_banner_=SiSU_Env::CreateSite.new(@md.opt.cmd).html_seg_title_banner?
+        @title_banner_=SiSU_Env::CreateSite.new(@md.opt).html_seg_title_banner?
       end
     end
     def songsheet
@@ -210,7 +210,10 @@ module SiSU_HTML_Seg
       if (@md.opt.act[:verbose][:set]==:on \
       || @md.opt.act[:verbose_plus][:set]==:on \
       || @md.opt.act[:maintenance][:set]==:on)
-        SiSU_Screen::Ansi.new(@md.opt.act[:color_state][:set],@@seg_name.length).segmented
+        SiSU_Screen::Ansi.new(
+          @md.opt.act[:color_state][:set],
+          @@seg_name.length
+        ).segmented
       end
       map_nametags=SiSU_Particulars::CombinedSingleton.instance.get_map_nametags(@md).nametags_map #p map_nametags
       data.each do |dob|
