@@ -77,7 +77,11 @@ module SiSU_Param_Make
         STDERR.puts "#{n} is #{s.class}: programming error, String expected #{__FILE__}:#{__LINE__}"
         s
       else
-        SiSU_Screen::Ansi.new('v',"*WARN* #{n} length #{s.length} exceeds set db field length #{l}, metadata dropped",@opt.fns).warn unless @opt.act[:quiet][:set]==:on
+        SiSU_Screen::Ansi.new(
+          'v',
+          "*WARN* #{n} length #{s.length} exceeds set db field length #{l}, metadata dropped",
+          @opt.fns
+        ).warn unless @opt.act[:quiet][:set]==:on
         nil
       end
     end
