@@ -65,7 +65,7 @@ module SiSU_Po4a
   require_relative 'ao'                                 # ao.rb
   require_relative 'sysenv'                             # sysenv.rb
     include SiSU_Env
-  require_relative 'composite'                          # composite.rb
+  require_relative 'ao_composite'                       # ao_composite.rb
   require_relative 'shared_metadata'                    # shared_metadata.rb
   require_relative 'po4a_set'                           # po4a_set.rb
   include SiSU_Param
@@ -121,7 +121,11 @@ module SiSU_Po4a
             if (@opt.act[:verbose][:set]==:on \
             || @opt.act[:verbose_plus][:set]==:on \
             || @opt.act[:maintenance][:set]==:on)
-              SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],@opt.fns,"#{path}/#{md.fnb}/#{md.fn[:plain]}").flow
+              SiSU_Screen::Ansi.new(
+                @opt.act[:color_state][:set],
+                @opt.fns,
+                "#{path}/#{md.fnb}/#{md.fn[:plain]}"
+              ).flow
             end
           end
           if @opt.fns =~/\S+?~#{@lang_regx}\.ss[mti]/ \
