@@ -80,7 +80,7 @@ module SiSU_QRcode
     end
     def read
       begin
-        @env=SiSU_Env::InfoEnv.new(@opt.fns)
+        @env=SiSU_Env::InfoEnv.new(@opt.fns,@opt)
         @md=SiSU_Param::Parameters.new(@opt).get
         xbrowser=@env.program.web_browser
         browser=@env.program.console_web_browser
@@ -89,12 +89,23 @@ module SiSU_QRcode
           (@opt.act[:verbose][:set]==:on \
           || @opt.act[:verbose_plus][:set]==:on \
           || @opt.act[:maintenance][:set]==:on) \
-          ? SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],'QR code',"#{xbrowser} #{url_html}").green_hi_blue
-          : SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],'QR code',"[#{@opt.f_pth[:lng_is]}] #{@opt.fns}").green_title_hi
+          ? SiSU_Screen::Ansi.new(
+              @opt.act[:color_state][:set],
+              'QR code',
+              "#{xbrowser} #{url_html}"
+            ).green_hi_blue
+          : SiSU_Screen::Ansi.new(
+              @opt.act[:color_state][:set],
+              'QR code',
+              "[#{@opt.f_pth[:lng_is]}] #{@opt.fns}"
+            ).green_title_hi
           if (@opt.act[:verbose][:set]==:on \
           || @opt.act[:verbose_plus][:set]==:on \
           || @opt.act[:maintenance][:set]==:on)
-            SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],"#{browser} #{url_html}").grey_tab
+            SiSU_Screen::Ansi.new(
+              @opt.act[:color_state][:set],
+              "#{browser} #{url_html}"
+            ).grey_tab
           end
         end
         data=SiSU_HTML::Source::HTML_Environment.new(@particulars).tuned_file_instructions
@@ -111,12 +122,12 @@ module SiSU_QRcode
       def initialize(md)
         @manifest={ txt: [], txt_title: [] }
         @md,@fns=md,md.fns
-        @env=SiSU_Env::InfoEnv.new(@md.fns)
+        @env=SiSU_Env::InfoEnv.new(@md.fns,@md.opt)
         @fnb=@md.fnb
         @base_url="#{@env.url.root}/#{@fnb}"
         @f=SiSU_Env::FileOp.new(@md)
         @base_path=@f.output_path.manifest.dir
-        @@dg ||=SiSU_Env::InfoEnv.new.digest.type
+        @@dg ||=SiSU_Env::InfoEnv.new.digest(@md.opt).type
         @dg=@@dg
         l=SiSU_Env::StandardiseLanguage.new(@md.opt.lng).language
         @language=l[:n]
@@ -124,6 +135,9 @@ module SiSU_QRcode
         @brace_url=SiSU_Viz::Defaults.new.url_decoration
         @f.make_path(@f.output_path.qrcode.dir)
       end
+      def spaces
+        Ax[:spaces]
+      end
       def output_metadata
         fn=@f.base_filename.manifest_txt
         mn=''
@@ -167,13 +181,21 @@ WOK
       end
       def summarize_sources(id,file,pth,rel,url)
         sys=SiSU_Env::SystemCall.new
-        dgst=(@dg =~/^sha(?:2|256)$/) \
-        ? (sys.sha256("#{pth}/#{file}"))
-        : (sys.md5("#{pth}/#{file}"))
+        dgst=case @dg
+        when :sha512
+          (sys.sha516("#{pth}/#{file}")) #check
+        when :md5
+          (sys.md5("#{pth}/#{file}"))
+        else
+          (sys.sha256("#{pth}/#{file}"))
+        end
         if (@md.opt.act[:verbose][:set]==:on \
         || @md.opt.act[:verbose_plus][:set]==:on \
         || @md.opt.act[:maintenance][:set]==:on)
-          SiSU_Screen::Ansi.new(@md.opt.cmd,"#{dgst[1]} #{file}").warn
+          SiSU_Screen::Ansi.new(
+            @md.opt.cmd,
+            "#{dgst[1]} #{file}"
+          ).warn
         end
         size=(File.size("#{pth}/#{file}")/1024.00).to_s
         kb=/([0-9]+\.[0-9]{0,1})/m.match(size)[1]
@@ -661,14 +683,13 @@ WOK
         if defined? @md.topic_register_array \
         and @md.topic_register_array.length > 0
           @manifest[:txt] << %{#{@translate.topic_register}:\n}
-@sp='  '
           @md.topic_register_array.each do |t|
             t.each_with_index do |st,i|
               if st.is_a?(Array)
                 st.each do |v|
-                  @manifest[:txt] << %{#{@sp*i}#{v}\n}
+                  @manifest[:txt] << %{#{spaces*i}#{v}\n}
                 end
-              else @manifest[:txt] << %{#{@sp*i}#{st}\n}
+              else @manifest[:txt] << %{#{spaces*i}#{st}\n}
               end
             end
           end
