@@ -89,10 +89,19 @@ module SiSU_SimpleXML_ModelSax
       begin
         @md=@particulars.md #bug, relies on info persistence, assumes -m has previously been run
         @env=@particulars.env
-        SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],'invert','XML SAX',"#{@md.fns} -> #{@md.fn[:sxs]}").colorize unless @opt.act[:quiet][:set]==:on
+        SiSU_Screen::Ansi.new(
+          @opt.act[:color_state][:set],
+          'invert',
+          'XML SAX',
+          "#{@md.fns} -> #{@md.fn[:sxs]}"
+        ).colorize unless @opt.act[:quiet][:set]==:on
         if (@opt.act[:verbose_plus][:set]==:on \
         || @opt.act[:maintenance][:set]==:on)
-          SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],@opt.fns,"#{Dir.pwd}/#{@md.fn[:sxs]}").flow
+          SiSU_Screen::Ansi.new(
+            @opt.act[:color_state][:set],
+            @opt.fns,
+            "#{Dir.pwd}/#{@md.fn[:sxs]}"
+          ).flow
         end
         unless @@fns==@opt.fns
           @@fns=@opt.fns
@@ -445,8 +454,18 @@ WOK
         if @prog.tidy !=false #note values can be other than true
           if (@md.opt.act[:verbose_plus][:set]==:on \
           || @md.opt.act[:maintenance][:set]==:on)
-            SiSU_Screen::Ansi.new(@md.opt.act[:color_state][:set],'invert','Using XML Tidy','check document structure').colorize unless @md.opt.act[:quiet][:set]==:on
-            SiSU_Screen::Ansi.new(@md.opt.act[:color_state][:set],'','','check document structure')
+            SiSU_Screen::Ansi.new(
+              @md.opt.act[:color_state][:set],
+              'invert',
+              'Using XML Tidy',
+              'check document structure'
+            ).colorize unless @md.opt.act[:quiet][:set]==:on
+            SiSU_Screen::Ansi.new(
+              @md.opt.act[:color_state][:set],
+              '',
+              '',
+              'check document structure'
+            )
             tell.grey_open unless @md.opt.act[:quiet][:set]==:on
             tidyfile='/dev/null' #don't want one or screen output, check for alternative flags
             tidy =SiSU_Env::SystemCall.new("#{Dir.pwd}/#{@md.fn[:sxs]}",tidyfile)
