@@ -114,21 +114,37 @@ module SiSU_TeX
       end
     end
     def read
-      song
+      begin
+        song
+      ensure
+        Dir.chdir(@opt.f_pth[:pth])
+      end
     end
     def song
       begin
         @md=@particulars.md
-        SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],'LaTeX/PDF',"[#{@opt.f_pth[:lng_is]}] #{@opt.fno}").green_title_hi unless @opt.act[:quiet][:set]==:on
+        SiSU_Screen::Ansi.new(
+          @opt.act[:color_state][:set],
+          'LaTeX/PDF',
+          "[#{@opt.f_pth[:lng_is]}] #{@opt.fno}"
+        ).green_title_hi unless @opt.act[:quiet][:set]==:on
         if (@opt.act[:verbose][:set]==:on \
         || @opt.act[:verbose_plus][:set]==:on \
         || @opt.act[:maintenance][:set]==:on)
           @env.url.output_tell
           if @md.opt.act[:pdf_l][:set]==:on
-            SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],@opt.fns,"#{@env.program.pdf_viewer} #{@md.file.output_path.pdf.dir}/#{@md.file.base_filename.pdf_l}#{@md.papersize_array[0]}.pdf").flow
+            SiSU_Screen::Ansi.new(
+              @opt.act[:color_state][:set],
+              @opt.fns,
+              "#{@env.program.pdf_viewer} #{@md.file.output_path.pdf.dir}/#{@md.file.base_filename.pdf_l}#{@md.papersize_array[0]}.pdf"
+            ).flow
           end
           if @md.opt.act[:pdf_p][:set]==:on
-            SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],@opt.fns,"#{@opt.fns} #{@env.program.pdf_viewer} #{@md.file.output_path.pdf.dir}/#{@md.file.base_filename.pdf_p}#{@md.papersize_array[0]}.pdf").flow
+            SiSU_Screen::Ansi.new(
+              @opt.act[:color_state][:set],
+              @opt.fns,
+              "#{@opt.fns} #{@env.program.pdf_viewer} #{@md.file.output_path.pdf.dir}/#{@md.file.base_filename.pdf_p}#{@md.papersize_array[0]}.pdf"
+            ).flow
           end
         end
         @md=@particulars.md
@@ -183,7 +199,10 @@ module SiSU_TeX
           if (@md.opt.act[:verbose][:set]==:on \
           || @md.opt.act[:verbose_plus][:set]==:on \
           || @md.opt.act[:maintenance][:set]==:on)
-            SiSU_Screen::Ansi.new(@md.opt.act[:color_state][:set],"#{papersize} portrait ->").dark_grey_title_hi
+            SiSU_Screen::Ansi.new(
+              @md.opt.act[:color_state][:set],
+              "#{papersize} portrait ->"
+            ).dark_grey_title_hi
           end
           cmd=SiSU_Env::SystemCall.new("#{tex_fn_base}.tex",'',@md.opt.cmd)
           tell.grey_open if @md.opt.cmd =~/[MVv]/
@@ -197,7 +216,10 @@ module SiSU_TeX
           if (@md.opt.act[:verbose][:set]==:on \
           || @md.opt.act[:verbose_plus][:set]==:on \
           || @md.opt.act[:maintenance][:set]==:on)
-            SiSU_Screen::Ansi.new(@md.opt.act[:color_state][:set],"#{papersize} landscape ->").dark_grey_title_hi
+            SiSU_Screen::Ansi.new(
+              @md.opt.act[:color_state][:set],
+              "#{papersize} landscape ->"
+            ).dark_grey_title_hi
           end
           cmd=SiSU_Env::SystemCall.new("#{tex_fn_base}.landscape.tex",'',@md.opt.cmd)
           if (@md.opt.act[:verbose][:set]==:on \
@@ -253,7 +275,11 @@ module SiSU_TeX
         if (@md.opt.act[:verbose][:set]==:on \
         || @md.opt.act[:verbose_plus][:set]==:on \
         || @md.opt.act[:maintenance][:set]==:on)
-          SiSU_Screen::Ansi.new(@md.opt.act[:color_state][:set],@@n_lpdf,'processed (SiSU LaTeX to pdf - using pdfetex aka. pdftex or pdflatex)').generic_number
+          SiSU_Screen::Ansi.new(
+            @md.opt.act[:color_state][:set],
+            @@n_lpdf,
+            'processed (SiSU LaTeX to pdf - using pdfetex aka. pdftex or pdflatex)'
+          ).generic_number
         end
       end
       def latexrun_selective
@@ -323,7 +349,10 @@ module SiSU_TeX
               end
             end
           else
-            SiSU_Screen::Ansi.new(@md.opt.act[:color_state][:set],"*WARN* FILE NOT FOUND: << #{@md.fns} >> - requested latex system processing skipped").warn
+            SiSU_Screen::Ansi.new(
+              @md.opt.act[:color_state][:set],
+              "*WARN* FILE NOT FOUND: << #{@md.fns} >> - requested latex system processing skipped"
+            ).warn
           end
           lst=Dir["*.{aux,log,out}"]
           lst.each {|file| File.unlink(file)} if lst
@@ -378,7 +407,10 @@ module SiSU_TeX
           if (@md.opt.act[:verbose][:set]==:on \
           || @md.opt.act[:verbose_plus][:set]==:on \
           || @md.opt.act[:maintenance][:set]==:on)
-            SiSU_Screen::Ansi.new(@md.opt.act[:color_state][:set],txt_gen).txt_grey
+            SiSU_Screen::Ansi.new(
+              @md.opt.act[:color_state][:set],
+              txt_gen
+            ).txt_grey
           end
           if defined? @md.rights.all \
           and not @md.rights.all.empty?
@@ -594,20 +626,26 @@ module SiSU_TeX
           case dob.is
           when :heading
             case dob.ln
-            when 1..3
-              tst.heading_major
+            when 0
+              tst.title_level_A
+            when 1
+              tst.section_heading_level_B
+            when 2
+              tst.section_heading_level_C
+            when 3
+              tst.section_heading_level_D
             when 4
-              tst.level4
+              tst.heading_level_1
             when 5
-              tst.level5
+              tst.heading_level_2
             when 6
-              tst.level6
+              tst.heading_level_3
             else dob
             end
           when :heading_insert
             br="\n\\\\\n"
             if dob.name=='book_index'
-              h=tst.heading_major
+              h=tst.section_heading_level_B
               heading="\\clearpage\n" + h.tmp
               idx_arr=[]
               idx=SiSU_Particulars::CombinedSingleton.instance.get_idx_raw(@md.opt).raw_idx
@@ -628,10 +666,10 @@ module SiSU_TeX
               dob.tmp={ l: l, p: p }
             elsif dob.ln==2 \
             and dob.obj=~/Metadata\b/
-              tst.heading_major
+              tst.section_heading_level_B
             elsif dob.ln==4 \
             and dob.obj=~/Metadata\b/
-              h=tst.level4
+              h=tst.heading_level_1
               metadata=SiSU_Metadata::TeX_Metadata.new(@md).metadata_tex
               dob.tmp=h.tmp + ' ' + '\begin{scriptsize}' + metadata.join(br) + '\end{scriptsize}'
             else dob.tmp='' # dob.tmp={ l: '', p: '' }
@@ -746,12 +784,12 @@ module SiSU_TeX
         title=@md.title.full.gsub(/#{Mx[:br_line]}|#{Mx[:br_nl]}|#{Mx[:br_paragraph]}|\\\\/,' - ') #no line splitting in heading neither html nor latex
         @md.papersize_array.each do |ps|
           if @md.opt.act[:pdf_p][:set]==:on
-            txt_obj={ txt: "#{home}: - #{title}", paper_size: ps, orientation: 'portrait' }
+            txt_obj={ txt: "#{home}: - #{title}", paper_size: ps, orientation: :portrait }
             orient_portrait=SiSU_TeX_Pdf::FormatHead.new(@md,txt_obj)
             @@tex_head[ps][:p]=orient_portrait.document_head_with_orientation(@codeblock_box)
           end
           if @md.opt.act[:pdf_l][:set]==:on
-            txt_obj={ txt: "#{home}: - #{title}", paper_size: ps, orientation: 'landscape' }
+            txt_obj={ txt: "#{home}: - #{title}", paper_size: ps, orientation: :landscape }
             orient_landscape=SiSU_TeX_Pdf::FormatHead.new(@md,txt_obj)
             @@tex_head[ps][:l]=orient_landscape.document_head_with_orientation(@codeblock_box)
           end
@@ -843,30 +881,30 @@ module SiSU_TeX
 \\renewcommand{\\contentsname}{#{@translate.contents}}
 \\tableofcontents
           WOK
-          toc_pb={ l: @tex_ml.newpage('landscape'), p: @tex_ml.newpage('portrait') }
+          toc_pb={ l: @tex_ml.newpage(:landscape), p: @tex_ml.newpage(:portrait) }
         else
           toc=''
           toc_pb={ l: '', p: '' }
         end
         if @md.opt.act[:pdf_l][:set]==:on
           x[:l] =<<-WOK
-#{@tex_ml.newpage('landscape')}
+#{@tex_ml.newpage(:landscape)}
 \\pagestyle{fancy}
 #{toc}#{toc_pb[:l]}
 \\pagenumbering{arabic}
 #{@tex_ml.paraskip_normal}
-#{@tex_ml.newpage('landscape')}
+#{@tex_ml.newpage(:landscape)}
           WOK
         end
         if @md.opt.act[:pdf_p][:set]==:on
           x[:p] =<<-WOK
-#{@tex_ml.newpage('portrait')}
+#{@tex_ml.newpage(:portrait)}
 \\pagestyle{fancy}
 #{toc}#{toc_pb[:p]}
-#{@tex_ml.newpage('portrait')}
+#{@tex_ml.newpage(:portrait)}
 \\pagenumbering{arabic}
 #{@tex_ml.paraskip_normal}
-#{@tex_ml.newpage('portrait')}
+#{@tex_ml.newpage(:portrait)}
           WOK
         end
         @tex_file << x
