@@ -90,11 +90,23 @@ module SiSU_Txt_AsciiDoc
           (@opt.act[:verbose][:set]==:on \
           || @opt.act[:verbose_plus][:set]==:on \
           || @opt.act[:maintenance][:set]==:on) \
-          ? SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],'AsciiDoc (plaintext utf-8)',tool).green_hi_blue
-          : SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],'AsciiDoc (plaintext utf-8)',tool).green_title_hi
+          ? SiSU_Screen::Ansi.new(
+              @opt.act[:color_state][:set],
+              'AsciiDoc (plaintext utf-8)',
+              tool
+            ).green_hi_blue
+          : SiSU_Screen::Ansi.new(
+              @opt.act[:color_state][:set],
+              'AsciiDoc (plaintext utf-8)',
+              tool
+            ).green_title_hi
           if (@opt.act[:verbose_plus][:set]==:on \
           || @opt.act[:maintenance][:set]==:on)
-            SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],@opt.fns,"#{md.file.output_path.asciidoc.dir}/#{md.file.base_filename.asciidoc}").flow
+            SiSU_Screen::Ansi.new(
+              @opt.act[:color_state][:set],
+              @opt.fns,
+              "#{md.file.output_path.asciidoc.dir}/#{md.file.base_filename.asciidoc}"
+            ).flow
           end
         end
         ao_array=SiSU_AO::Source.new(@opt).get # ao file drawn here
