@@ -91,11 +91,23 @@ module SiSU_Txt_Plain
           (@opt.act[:verbose][:set]==:on \
           || @opt.act[:verbose_plus][:set]==:on \
           || @opt.act[:maintenance][:set]==:on) \
-          ? SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],'Plaintext',tool).green_hi_blue
-          : SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],'Plaintext',tool).green_title_hi
+          ? SiSU_Screen::Ansi.new(
+              @opt.act[:color_state][:set],
+              'Plaintext',
+              tool
+            ).green_hi_blue
+          : SiSU_Screen::Ansi.new(
+              @opt.act[:color_state][:set],
+              'Plaintext',
+              tool
+            ).green_title_hi
           if (@opt.act[:verbose_plus][:set]==:on \
           || @opt.act[:maintenance][:set]==:on)
-            SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],@opt.fns,"#{md.file.output_path.txt.dir}/#{md.file.base_filename.txt}").flow
+            SiSU_Screen::Ansi.new(
+              @opt.act[:color_state][:set],
+              @opt.fns,
+              "#{md.file.output_path.txt.dir}/#{md.file.base_filename.txt}"
+            ).flow
           end
         end
         ao_array=SiSU_AO::Source.new(@opt).get # ao file drawn here
@@ -384,7 +396,10 @@ WOK
           when 1 then wrapped.upcase << break_line << decorate.heading_underscore.l1*times + p_num << break_line*2
           when 2 then wrapped.upcase << break_line << decorate.heading_underscore.l2*times + p_num << break_line*2
           when 3 then wrapped.upcase << break_line << decorate.heading_underscore.l3*times + p_num << break_line*2
-          when 4 then wrapped.upcase << break_line << decorate.heading_underscore.l4*times + p_num << break_line*2
+          when 4
+            unless dob.use_ == :dummy
+              wrapped.upcase << break_line << decorate.heading_underscore.l4*times + p_num << break_line*2
+            end
           when 5 then wrapped.upcase << break_line << decorate.heading_underscore.l5*times + p_num << break_line*2
           when 6 then wrapped.upcase << break_line << decorate.heading_underscore.l6*times + p_num << break_line*2
           end
