@@ -107,7 +107,7 @@ module SiSU_Urls
         'I --texinfo (Info file)'=>'info',
         'i --manpage (manpage)'=>'manpage',
         'm --ao (Document Abstraction)'=>'ao',
-        'N --hash-digests (Digests md5/sha256)'=>@fn[:digest],
+        'N --hash-digests (Digests sha512/sha256/md5)'=>@fn[:digest],
         'o --odt (ODF:ODT - Open Document)'=>@fn[:odf],
         'p --pdf (PDF landscape)'=>@fn[:pdf_l],
         'p --pdf (PDF portrait)'=>@fn[:pdf_p],
@@ -144,121 +144,256 @@ module SiSU_Urls
     def show
       def source
         def src(x,y)
-          SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],"[#{@opt.f_pth[:lng_is]}] -#{x}","#{@prog.text_editor} #{@md.file.output_path.src.dir}/#{y}").result
+          SiSU_Screen::Ansi.new(
+            @opt.act[:color_state][:set],
+            "[#{@opt.f_pth[:lng_is]}] -#{x}",
+            "#{@prog.text_editor} #{@md.file.output_path.src.dir}/#{y}"
+          ).result
         end
         def pod(x,y)
-          SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],"[#{@opt.f_pth[:lng_is]}] -#{x}","#{@prog.web_browser} file://#{@md.file.output_path.sisupod.dir}/#{y}").result
+          SiSU_Screen::Ansi.new(
+            @opt.act[:color_state][:set],
+            "[#{@opt.f_pth[:lng_is]}] -#{x}",
+            "#{@prog.web_browser} file://#{@md.file.output_path.sisupod.dir}/#{y}"
+          ).result
         end
         self
       end
       def generic(x,y)
-        SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],"[#{@opt.f_pth[:lng_is]}] -#{x}","#{@prog.web_browser} #{@env.url.output_tell}/#{@fnb}/#{y}").result
+        SiSU_Screen::Ansi.new(
+          @opt.act[:color_state][:set],
+          "[#{@opt.f_pth[:lng_is]}] -#{x}",
+          "#{@prog.web_browser} #{@env.url.output_tell}/#{@fnb}/#{y}"
+        ).result
       end
       def meta(x,y)
-        SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],"[#{@opt.f_pth[:lng_is]}] -#{x}","#{@prog.text_editor} ~#{y}/#{@fnb}.#{y}").result
+        SiSU_Screen::Ansi.new(
+          @opt.act[:color_state][:set],
+          "[#{@opt.f_pth[:lng_is]}] -#{x}",
+          "#{@prog.text_editor} ~#{y}/#{@fnb}.#{y}"
+        ).result
       end
       def text(x)
-        SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],"[#{@opt.f_pth[:lng_is]}] -#{x}","#{@prog.web_browser} file://#{@md.file.output_path.txt.dir}/#{@md.file.base_filename.txt}").result
+        SiSU_Screen::Ansi.new(
+          @opt.act[:color_state][:set],
+          "[#{@opt.f_pth[:lng_is]}] -#{x}",
+          "#{@prog.web_browser} file://#{@md.file.output_path.txt.dir}/#{@md.file.base_filename.txt}"
+        ).result
       end
       def textile(x)
-        SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],"[#{@opt.f_pth[:lng_is]}] -#{x}","#{@prog.web_browser} file://#{@md.file.output_path.textile.dir}/#{@md.file.base_filename.textile}").result
+        SiSU_Screen::Ansi.new(
+          @opt.act[:color_state][:set],
+          "[#{@opt.f_pth[:lng_is]}] -#{x}",
+          "#{@prog.web_browser} file://#{@md.file.output_path.textile.dir}/#{@md.file.base_filename.textile}"
+        ).result
       end
       def asciidoc(x)
-        SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],"[#{@opt.f_pth[:lng_is]}] -#{x}","#{@prog.web_browser} file://#{@md.file.output_path.asciidoc.dir}/#{@md.file.base_filename.asciidoc}").result
+        SiSU_Screen::Ansi.new(
+          @opt.act[:color_state][:set],
+          "[#{@opt.f_pth[:lng_is]}] -#{x}",
+          "#{@prog.web_browser} file://#{@md.file.output_path.asciidoc.dir}/#{@md.file.base_filename.asciidoc}"
+        ).result
       end
       def markdown(x)
-        SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],"[#{@opt.f_pth[:lng_is]}] -#{x}","#{@prog.web_browser} file://#{@md.file.output_path.markdown.dir}/#{@md.file.base_filename.markdown}").result
+        SiSU_Screen::Ansi.new(
+          @opt.act[:color_state][:set],
+          "[#{@opt.f_pth[:lng_is]}] -#{x}",
+          "#{@prog.web_browser} file://#{@md.file.output_path.markdown.dir}/#{@md.file.base_filename.markdown}"
+        ).result
       end
       def rst(x)
-        SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],"[#{@opt.f_pth[:lng_is]}] -#{x}","#{@prog.web_browser} file://#{@md.file.output_path.rst.dir}/#{@md.file.base_filename.rst}").result
+        SiSU_Screen::Ansi.new(
+          @opt.act[:color_state][:set],
+          "[#{@opt.f_pth[:lng_is]}] -#{x}",
+          "#{@prog.web_browser} file://#{@md.file.output_path.rst.dir}/#{@md.file.base_filename.rst}"
+        ).result
       end
       def epub(x)
-        SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],"[#{@opt.f_pth[:lng_is]}] -#{x}","#{@prog.epub_viewer} #{@md.file.output_path.epub.dir}/#{@md.file.base_filename.epub}").result
+        SiSU_Screen::Ansi.new(
+          @opt.act[:color_state][:set],
+          "[#{@opt.f_pth[:lng_is]}] -#{x}",
+          "#{@prog.epub_viewer} #{@md.file.output_path.epub.dir}/#{@md.file.base_filename.epub}"
+        ).result
       end
       def html
         def scroll(x)
-          SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],"[#{@opt.f_pth[:lng_is]}] -#{x}","#{@prog.web_browser} file://#{@md.file.output_path.html_scroll.dir}/#{@md.file.base_filename.html_scroll}").result
+          SiSU_Screen::Ansi.new(
+            @opt.act[:color_state][:set],
+            "[#{@opt.f_pth[:lng_is]}] -#{x}",
+            "#{@prog.web_browser} file://#{@md.file.output_path.html_scroll.dir}/#{@md.file.base_filename.html_scroll}"
+          ).result
         end
         def toc(x)
-          SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],"[#{@opt.f_pth[:lng_is]}] -#{x}","#{@prog.web_browser} file://#{@md.file.output_path.html_seg.dir}/#{@md.file.base_filename.html_segtoc}").result
+          SiSU_Screen::Ansi.new(
+            @opt.act[:color_state][:set],
+            "[#{@opt.f_pth[:lng_is]}] -#{x}",
+            "#{@prog.web_browser} file://#{@md.file.output_path.html_seg.dir}/#{@md.file.base_filename.html_segtoc}"
+          ).result
         end
         def concordance(x)
-          SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],"[#{@opt.f_pth[:lng_is]}] -#{x}","#{@prog.web_browser} file://#{@md.file.output_path.html_concordance.dir}/#{@md.file.base_filename.html_concordance}").result
+          SiSU_Screen::Ansi.new(
+            @opt.act[:color_state][:set],
+            "[#{@opt.f_pth[:lng_is]}] -#{x}",
+            "#{@prog.web_browser} file://#{@md.file.output_path.html_concordance.dir}/#{@md.file.base_filename.html_concordance}"
+          ).result
         end
         def manifest(x)
-          SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],"[#{@opt.f_pth[:lng_is]}] -#{x}","#{@prog.web_browser} file://#{@md.file.output_path.manifest.dir}/#{@md.file.base_filename.manifest}").result
+          SiSU_Screen::Ansi.new(
+            @opt.act[:color_state][:set],
+            "[#{@opt.f_pth[:lng_is]}] -#{x}",
+            "#{@prog.web_browser} file://#{@md.file.output_path.manifest.dir}/#{@md.file.base_filename.manifest}"
+          ).result
         end
         self
       end
       def qrcode(x)
-        SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],"[#{@opt.f_pth[:lng_is]}] -#{x}","#{@prog.web_browser} file://#{@md.file.output_path.manifest.dir}/#{@md.file.base_filename.manifest}").result
+        SiSU_Screen::Ansi.new(
+          @opt.act[:color_state][:set],
+          "[#{@opt.f_pth[:lng_is]}] -#{x}",
+          "#{@prog.web_browser} file://#{@md.file.output_path.manifest.dir}/#{@md.file.base_filename.manifest}"
+        ).result
       end
       def odt(x)
-        SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],"[#{@opt.f_pth[:lng_is]}] -#{x}","#{@prog.odf_viewer} file://#{@md.file.output_path.odt.dir}/#{@md.file.base_filename.odt}").result
+        SiSU_Screen::Ansi.new(
+          @opt.act[:color_state][:set],
+          "[#{@opt.f_pth[:lng_is]}] -#{x}",
+          "#{@prog.odf_viewer} file://#{@md.file.output_path.odt.dir}/#{@md.file.base_filename.odt}"
+        ).result
       end
       def pdf
         def portrait(x)
-          SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],"[#{@opt.f_pth[:lng_is]}] -#{x}","#{@prog.pdf_viewer} #{@md.file.output_path.pdf.dir}/#{@md.file.base_filename.pdf_p}#{@md.papersize_array[0]}.pdf").result
+          SiSU_Screen::Ansi.new(
+            @opt.act[:color_state][:set],
+            "[#{@opt.f_pth[:lng_is]}] -#{x}",
+            "#{@prog.pdf_viewer} #{@md.file.output_path.pdf.dir}/#{@md.file.base_filename.pdf_p}#{@md.papersize_array[0]}.pdf"
+          ).result
         end
         def landscape(x)
-          SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],"[#{@opt.f_pth[:lng_is]}] -#{x}","#{@prog.pdf_viewer} #{@md.file.output_path.pdf.dir}/#{@md.file.base_filename.pdf_l}#{@md.papersize_array[0]}.pdf").result
+          SiSU_Screen::Ansi.new(
+            @opt.act[:color_state][:set],
+            "[#{@opt.f_pth[:lng_is]}] -#{x}",
+            "#{@prog.pdf_viewer} #{@md.file.output_path.pdf.dir}/#{@md.file.base_filename.pdf_l}#{@md.papersize_array[0]}.pdf"
+          ).result
         end
         self
       end
       def manpage(x)
-        SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],"[#{@opt.f_pth[:lng_is]}] -#{x}","#{@prog.manpage_viewer} #{@md.file.output_path.manpage.dir}/#{@md.file.base_filename.manpage}").result
+        SiSU_Screen::Ansi.new(
+          @opt.act[:color_state][:set],
+          "[#{@opt.f_pth[:lng_is]}] -#{x}",
+          "#{@prog.manpage_viewer} #{@md.file.output_path.manpage.dir}/#{@md.file.base_filename.manpage}"
+        ).result
       end
       def pinfo(x,y)
-        SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],"[#{@opt.f_pth[:lng_is]}] -#{x}","cd #{@md.file.output_path.texinfo.dir} && #{@env.program.texinfo} #{@md.file.base_filename.info}; cd -").result
+        SiSU_Screen::Ansi.new(
+          @opt.act[:color_state][:set],
+          "[#{@opt.f_pth[:lng_is]}] -#{x}",
+          "cd #{@md.file.output_path.texinfo.dir} && #{@env.program.texinfo} #{@md.file.base_filename.info}; cd -"
+        ).result
       end
       def po4a
         def po(x,y)
-          SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],"-#{x}","#{@prog.text_editor} #{@md.file.output_path.po.dir}/#{y}").result
+          SiSU_Screen::Ansi.new(
+            @opt.act[:color_state][:set],
+            "-#{x}",
+            "#{@prog.text_editor} #{@md.file.output_path.po.dir}/#{y}"
+          ).result
         end
         def pot(x,y)
-          SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],"-#{x}","#{@prog.text_editor} #{@md.file.output_path.pot.dir}/#{y}").result
+          SiSU_Screen::Ansi.new(
+            @opt.act[:color_state][:set],
+            "-#{x}",
+            "#{@prog.text_editor} #{@md.file.output_path.pot.dir}/#{y}"
+          ).result
         end
         self
       end
       def xhtml(x)
-        SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],"[#{@opt.f_pth[:lng_is]}] -#{x}","#{@prog.web_browser} file://#{@md.file.output_path.xhtml.dir}/#{@md.file.base_filename.xhtml}").result
+        SiSU_Screen::Ansi.new(
+          @opt.act[:color_state][:set],
+          "[#{@opt.f_pth[:lng_is]}] -#{x}",
+          "#{@prog.web_browser} file://#{@md.file.output_path.xhtml.dir}/#{@md.file.base_filename.xhtml}"
+        ).result
       end
       def xml
         def sax(x)
-          SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],"[#{@opt.f_pth[:lng_is]}] -#{x}","#{@prog.web_browser} file://#{@md.file.output_path.xml_sax.dir}/#{@md.file.base_filename.xml_sax}").result
+          SiSU_Screen::Ansi.new(
+            @opt.act[:color_state][:set],
+            "[#{@opt.f_pth[:lng_is]}] -#{x}",
+            "#{@prog.web_browser} file://#{@md.file.output_path.xml_sax.dir}/#{@md.file.base_filename.xml_sax}"
+          ).result
         end
         def dom(x)
-          SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],"[#{@opt.f_pth[:lng_is]}] -#{x}","#{@prog.web_browser} file://#{@md.file.output_path.xml_dom.dir}/#{@md.file.base_filename.xml_dom}").result
+          SiSU_Screen::Ansi.new(
+            @opt.act[:color_state][:set],"[#{@opt.f_pth[:lng_is]}] -#{x}",
+            "#{@prog.web_browser} file://#{@md.file.output_path.xml_dom.dir}/#{@md.file.base_filename.xml_dom}"
+          ).result
         end
         def docbook_book(x)
-          SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],"[#{@opt.f_pth[:lng_is]}] -#{x}","#{@prog.web_browser} file://#{@md.file.output_path.xml_docbook_book.dir}/#{@md.file.base_filename.xml_docbook_book}").result
+          SiSU_Screen::Ansi.new(
+            @opt.act[:color_state][:set],
+            "[#{@opt.f_pth[:lng_is]}] -#{x}",
+            "#{@prog.web_browser} file://#{@md.file.output_path.xml_docbook_book.dir}/#{@md.file.base_filename.xml_docbook_book}"
+          ).result
         end
         def fictionbook(x)
-          SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],"[#{@opt.f_pth[:lng_is]}] -#{x}","#{@prog.web_browser} file://#{@md.file.output_path.xml_fictionbook.dir}/#{@md.file.base_filename.xml_fictionbook}").result
+          SiSU_Screen::Ansi.new(
+            @opt.act[:color_state][:set],
+            "[#{@opt.f_pth[:lng_is]}] -#{x}",
+            "#{@prog.web_browser} file://#{@md.file.output_path.xml_fictionbook.dir}/#{@md.file.base_filename.xml_fictionbook}"
+          ).result
         end
         def scaffold_structure_sisu(x)
-          SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],"[#{@opt.f_pth[:lng_is]}] -#{x}","#{@prog.web_browser} file://#{@md.file.output_path.xml_scaffold_structure_sisu.dir}/#{@md.file.base_filename.xml_scaffold_structure_sisu}").result
+          SiSU_Screen::Ansi.new(
+            @opt.act[:color_state][:set],
+            "[#{@opt.f_pth[:lng_is]}] -#{x}",
+            "#{@prog.web_browser} file://#{@md.file.output_path.xml_scaffold_structure_sisu.dir}/#{@md.file.base_filename.xml_scaffold_structure_sisu}"
+          ).result
         end
         def scaffold_structure_collapse(x)
-          SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],"[#{@opt.f_pth[:lng_is]}] -#{x}","#{@prog.web_browser} file://#{@md.file.output_path.xml_scaffold_structure_collapse.dir}/#{@md.file.base_filename.xml_scaffold_structure_collapse}").result
+          SiSU_Screen::Ansi.new(
+            @opt.act[:color_state][:set],
+            "[#{@opt.f_pth[:lng_is]}] -#{x}",
+            "#{@prog.web_browser} file://#{@md.file.output_path.xml_scaffold_structure_collapse.dir}/#{@md.file.base_filename.xml_scaffold_structure_collapse}"
+          ).result
         end
         def sitemap(x) #BROKEN
-          SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],"[#{@opt.f_pth[:lng_is]}] -#{x}","#{@prog.web_browser} file://#{@md.file.output_path.sitemaps.dir}/#{@md.file.base_filename.sitemap}").result
+          SiSU_Screen::Ansi.new(
+            @opt.act[:color_state][:set],
+            "[#{@opt.f_pth[:lng_is]}] -#{x}",
+            "#{@prog.web_browser} file://#{@md.file.output_path.sitemaps.dir}/#{@md.file.base_filename.sitemap}"
+          ).result
         end
         self
       end
       def hash_digest(x)
-        SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],"[#{@opt.f_pth[:lng_is]}] -#{x}","#{@prog.web_browser} file://#{@md.file.output_path.hash_digest.dir}/#{@md.file.base_filename.hash_digest}").result
+        SiSU_Screen::Ansi.new(
+          @opt.act[:color_state][:set],
+          "[#{@opt.f_pth[:lng_is]}] -#{x}",
+          "#{@prog.web_browser} file://#{@md.file.output_path.hash_digest.dir}/#{@md.file.base_filename.hash_digest}"
+        ).result
       end
       def db
         def psql(x,y)
-          SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],"[#{@opt.f_pth[:lng_is]}] -#{x} DBI psql","#{@pwd_stub}::#{@opt.fns}",y).result
+          SiSU_Screen::Ansi.new(
+            @opt.act[:color_state][:set],
+            "[#{@opt.f_pth[:lng_is]}] -#{x} DBI psql","#{@pwd_stub}::#{@opt.fns}",
+            y
+          ).result
         end
         def sqlite(x,y)
-          SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],"[#{@opt.f_pth[:lng_is]}] -#{x} DBI sqlite","sqlite3 #{@env.path.webserv}/#{@md.opt.f_pth[:pth_stub]}/sisu_sqlite.db").result
+          SiSU_Screen::Ansi.new(
+            @opt.act[:color_state][:set],
+            "[#{@opt.f_pth[:lng_is]}] -#{x} DBI sqlite",
+            "sqlite3 #{@env.path.webserv}/#{@md.opt.f_pth[:pth_stub]}/sisu_sqlite.db"
+          ).result
         end
         def sqlite_discrete(x,y)
-          SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],"[#{@opt.f_pth[:lng_is]}] -#{x}","sqlite3 #{@md.file.output_path.sqlite_discrete.dir}/#{@md.file.base_filename.sqlite_discrete}").result
+          SiSU_Screen::Ansi.new(
+            @opt.act[:color_state][:set],
+            "[#{@opt.f_pth[:lng_is]}] -#{x}",
+            "sqlite3 #{@md.file.output_path.sqlite_discrete.dir}/#{@md.file.base_filename.sqlite_discrete}"
+          ).result
         end
         self
       end
@@ -274,13 +409,21 @@ module SiSU_Urls
         if x =~/^m/ \
         and @opt.cmd=~/m/ \
         and x=~/^[#{opt.cmd}]/
-          SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],"-#{x}","#{@prog.text_editor} #{@env.processing_path.ao}/#{@opt.fns}.meta").maintenance
+          SiSU_Screen::Ansi.new(
+            @opt.act[:color_state][:set],
+            "-#{x}",
+            "#{@prog.text_editor} #{@env.processing_path.ao}/#{@opt.fns}.meta"
+          ).maintenance
         end
         if x=~/^([hw])/ \
         and @opt.cmd=~/[hw]/ \
         and x=~/^[#{@opt.cmd}]/ \
         and x !~/segmented/
-          SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],"-#{x}","#{@prog.text_editor} #{@env.processing_path.tune}/#{@md.fns}.tune").maintenance
+          SiSU_Screen::Ansi.new(
+            @opt.act[:color_state][:set],
+            "-#{x}",
+            "#{@prog.text_editor} #{@env.processing_path.tune}/#{@md.fns}.tune"
+          ).maintenance
         end
         if x=~/^p/ \
         and @opt.cmd=~/p/ \
@@ -289,8 +432,17 @@ module SiSU_Urls
           fns=@opt.fns.gsub(/~/,'-')
           unless @opt.cmd =~/q/
             tell=if x =~/landscape/
-              SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],"-#{x}","#{@prog.text_editor} #{@env.processing_path.tex}/#{fns}.landscape.tex")
-            else SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],"-#{x}","#{@prog.text_editor} #{@env.processing_path.tex}/#{fns}.tex")
+              SiSU_Screen::Ansi.new(
+                @opt.act[:color_state][:set],
+                "-#{x}",
+                "#{@prog.text_editor} #{@env.processing_path.tex}/#{fns}.landscape.tex"
+              )
+            else
+              SiSU_Screen::Ansi.new(
+                @opt.act[:color_state][:set],
+                "-#{x}",
+                "#{@prog.text_editor} #{@env.processing_path.tex}/#{fns}.tex"
+              )
             end
             tell.maintenance
           end
@@ -303,25 +455,45 @@ module SiSU_Urls
         if x=~/^e/ \
         and @opt.cmd=~/e/ \
         and x=~/^[#{@opt.cmd}]/
-          SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],"-#{x}","#{@prog.text_editor} #{@env.processing_path.epub}/#{Ep[:d_oebps]}/toc.xhtml").maintenance
+          SiSU_Screen::Ansi.new(
+            @opt.act[:color_state][:set],
+            "-#{x}",
+            "#{@prog.text_editor} #{@env.processing_path.epub}/#{Ep[:d_oebps]}/toc.xhtml"
+          ).maintenance
         end
         if x=~/^o/ \
         and @opt.cmd=~/o/ \
         and x=~/^[#{@opt.cmd}]/
-          SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],"-#{x}","#{@prog.text_editor} #{@env.processing_path.odf}/#{@opt.fns}/odt/content.xml").maintenance
+          SiSU_Screen::Ansi.new(
+            @opt.act[:color_state][:set],
+            "-#{x}",
+            "#{@prog.text_editor} #{@env.processing_path.odf}/#{@opt.fns}/odt/content.xml"
+          ).maintenance
         end
       end
     end
     def urls_select
       unless @opt.cmd =~/q/
-        i1="[#{@opt.f_pth[:lng_is]}]"
-        i2="file://#{@md.file.output_path.manifest.dir}/#{@md.file.base_filename.manifest}"
+        i1='[' + @opt.f_pth[:lng_is] + ']'
+        i2='file://' \
+        + @md.file.output_path.manifest.dir + '/' \
+        + @md.file.base_filename.manifest
         (@opt.act[:verbose][:set]==:on \
         || @opt.act[:verbose_plus][:set]==:on \
         || @opt.act[:maintenance][:set]==:on) \
-        ? SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],'URLs').green_title_hi
-        : SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],'URL (output manifest)',i1, i2).grey_title_grey_blue
-        SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],@opt.fns,"#{@md.file.output_path.manifest.dir}/#{@md.file.base_filename.manifest}").flow if @opt.cmd =~/[MVv]/
+        ? SiSU_Screen::Ansi.new(
+            @opt.act[:color_state][:set],
+            'URLs'
+          ).green_title_hi
+        : SiSU_Screen::Ansi.new(
+            @opt.act[:color_state][:set],
+            'URL (output manifest)',
+            i1, i2
+          ).grey_title_grey_blue
+        SiSU_Screen::Ansi.new(
+          @opt.act[:color_state][:set],
+          i1, i2,
+        ).flow if @opt.cmd =~/[MVv]/
       end
       m=/.+\/(?:src\/)?(\S+)/im # m=/.+?\/(?:src\/)?([^\/]+)$/im # m=/.+\/(\S+)/m
       @pwd_stub="#{@env.url.output_tell}"[m,1]
@@ -486,7 +658,11 @@ module SiSU_Urls
     end
     def urls_all
       i="(output manifest) [#{@opt.f_pth[:lng_is]}] #{@env.url.output_tell}/#{@fnb}/sisu_manifest.html"
-      SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],'URLs',i).grey_title_hi
+      SiSU_Screen::Ansi.new(
+        @opt.act[:color_state][:set],
+        'URLs',
+        i
+      ).grey_title_hi
       @u.each do |x,y|
         case x
         when /^m/
