@@ -96,11 +96,23 @@ module SiSU_XML_DOM
           (@opt.act[:verbose][:set]==:on \
           || @opt.act[:verbose_plus][:set]==:on \
           || @opt.act[:maintenance][:set]==:on) \
-          ? SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],'XML DOM',tool).green_hi_blue
-          : SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],'XML DOM',tool).green_title_hi
+          ? SiSU_Screen::Ansi.new(
+              @opt.act[:color_state][:set],
+              'XML DOM',
+              tool
+            ).green_hi_blue
+          : SiSU_Screen::Ansi.new(
+              @opt.act[:color_state][:set],
+              'XML DOM',
+              tool
+            ).green_title_hi
           if (@opt.act[:verbose_plus][:set]==:on \
           || @opt.act[:maintenance][:set]==:on)
-            SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],@opt.fns,"file://#{@md.file.output_path.xml_dom.dir}/#{@md.file.base_filename.xml_dom}").flow
+            SiSU_Screen::Ansi.new(
+              @opt.act[:color_state][:set],
+              @opt.fns,
+              "file://#{@md.file.output_path.xml_dom.dir}/#{@md.file.base_filename.xml_dom}"
+            ).flow
           end
         end
         SiSU_XML_DOM::Source::Songsheet.new(@particulars).songsheet
@@ -109,7 +121,8 @@ module SiSU_XML_DOM
           __LINE__.to_s + ':' + __FILE__
         end
       ensure
-        SiSU_Env::CreateSite.new(@opt.cmd).cp_css
+        SiSU_Env::CreateSite.new(@opt).cp_css
+        Dir.chdir(@opt.f_pth[:pth])
       end
     end
     private
@@ -545,8 +558,18 @@ WOK
         if @prog.tidy !=false
           if (@md.opt.act[:verbose_plus][:set]==:on \
           || @md.opt.act[:maintenance][:set]==:on)
-            SiSU_Screen::Ansi.new(@md.opt.act[:color_state][:set],'invert','Using XML Tidy','check document structure').colorize unless @md.opt.act[:quiet][:set]==:on
-            tell=SiSU_Screen::Ansi.new(@md.opt.act[:color_state][:set],'invert','','')
+            SiSU_Screen::Ansi.new(
+              @md.opt.act[:color_state][:set],
+              'invert',
+              'Using XML Tidy',
+              'check document structure'
+            ).colorize unless @md.opt.act[:quiet][:set]==:on
+            tell=SiSU_Screen::Ansi.new(
+                   @md.opt.act[:color_state][:set],
+                   'invert',
+                   '',
+                   ''
+                 )
             tell.grey_open unless @md.opt.act[:quiet][:set]==:on
             tidyfile='/dev/null' #don't want one or screen output, check for alternative flags
             tidy=SiSU_Env::SystemCall.new(@file,tidyfile)
