@@ -95,11 +95,23 @@ module SiSU_XML_SAX
           (@opt.act[:verbose][:set]==:on \
           || @opt.act[:verbose_plus][:set]==:on \
           || @opt.act[:maintenance][:set]==:on) \
-          ? SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],'XML SAX',tool).green_hi_blue
-          : SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],'XML SAX',tool).green_title_hi
+          ? SiSU_Screen::Ansi.new(
+              @opt.act[:color_state][:set],
+              'XML SAX',
+              tool
+            ).green_hi_blue
+          : SiSU_Screen::Ansi.new(
+              @opt.act[:color_state][:set],
+              'XML SAX',
+              tool
+            ).green_title_hi
           if (@opt.act[:verbose_plus][:set]==:on \
           || @opt.act[:maintenance][:set]==:on)
-            SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],@opt.fns,"file://#{@md.file.output_path.xml_sax.dir}/#{@md.file.base_filename.xml_sax}").flow
+            SiSU_Screen::Ansi.new(
+              @opt.act[:color_state][:set],
+              @opt.fns,
+              "file://#{@md.file.output_path.xml_sax.dir}/#{@md.file.base_filename.xml_sax}"
+            ).flow
           end
         end
         SiSU_XML_SAX::Source::Songsheet.new(@particulars).song
@@ -109,7 +121,8 @@ module SiSU_XML_SAX
         end
       ensure
         #file closed in songsheet
-        SiSU_Env::CreateSite.new(@opt.cmd).cp_css
+        SiSU_Env::CreateSite.new(@opt).cp_css
+        Dir.chdir(@opt.f_pth[:pth])
       end
     end
     private
@@ -469,8 +482,18 @@ WOK
           if (@md.opt.act[:verbose_plus][:set]==:on \
           || @md.opt.act[:maintenance][:set]==:on)
             unless @md.opt.act[:quiet][:set]==:on
-              SiSU_Screen::Ansi.new(@md.opt.act[:color_state][:set],'invert','Using XML Tidy','check document structure').colorize
-              tell=SiSU_Screen::Ansi.new(@md.opt.act[:color_state][:set],'invert','','')
+              SiSU_Screen::Ansi.new(
+                @md.opt.act[:color_state][:set],
+                'invert',
+                'Using XML Tidy',
+                'check document structure'
+              ).colorize
+              tell=SiSU_Screen::Ansi.new(
+                     @md.opt.act[:color_state][:set],
+                     'invert',
+                     '',
+                     ''
+                 )
               tell.grey_open
             end
             tidyfile='/dev/null' #don't want one or screen output, check for alternative flags
